@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * module_manager.cc
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,9 +45,6 @@
 
 #include "gui/debug_glib_null.h"
 
-#ifdef DEBUG
-static const gchar *f_message = "backend/module_manager.cc line #%d \"%s\" = %s\n";
-#endif
 using namespace sword;
 using std::cout;
 using std::cin;
@@ -59,6 +56,11 @@ static InstallMgr *installMgr = NULL;
 static ModMap::iterator it;
 static ModMap::iterator end;
 
+// separate iterator/end pair for listing sources' modules.
+// avoids being overused by other areas of mod.mgr use.
+static ModMap::iterator list_it;
+static ModMap::iterator list_end;
+
 /******************************************************************************
  * Name
  *   preStatus
@@ -80,7 +82,6 @@ void GSStatusReporter::preStatus(long totalBytes,
 				 long completedBytes,
 				 const char *message)
 {
-	GS_print((f_message,83,"message",message));
 	update_install_status(totalBytes, completedBytes, message);
 }
 
@@ -164,8 +165,8 @@ MOD_MGR *backend_module_mgr_get_next_module(void)
 	MOD_MGR *mod_info = NULL;
 	SWModule *module;
 
-	if (it != end) {
-		module = it->second;
+	if (list_it != list_end) {
+		module = list_it->second;
 		mod_info = g_new(MOD_MGR, 1);
 		gchar *name = module->Name();
 
@@ -201,8 +202,12 @@ MOD_MGR *backend_module_mgr_get_next_module(void)
 			mod_info->is_devotional = (feature && !strcmp(feature, "DailyDevotion"));
 
 			char *category = (char *)module->getConfigEntry("Category");
-			mod_info->is_maps   = (category && !strcmp(category, "Maps"));
-			mod_info->is_images = (category && !strcmp(category, "Images"));
+			mod_info->is_maps     = (category && !strcmp(category, "Maps"));
+			mod_info->is_images   = (category && !strcmp(category, "Images"));
+			mod_info->is_glossary = (category && !strcmp(category, "Glossaries"));
+			mod_info->is_cult =
+			    (category &&
+			     !strcmp(category, "Cults / Unorthodox / Questionable Material"));
 
 			mod_info->old_version =
 			    backend_mod_mgr_get_config_entry(name, "Version");
@@ -211,7 +216,7 @@ MOD_MGR *backend_module_mgr_get_next_module(void)
 			mod_info->description = module->Description();
 			mod_info->locked =
 			    ((module->getConfigEntry("CipherKey")) ? 1 : 0);
-			it++;
+			list_it++;
 			return (MOD_MGR *) mod_info;
 		}
 	}
@@ -244,8 +249,8 @@ void backend_module_mgr_remote_list_modules_init(const char *sourceName)
 			sourceName);
 		backend_shut_down_module_mgr();
 	}
-	it = source->second->getMgr()->Modules.begin();
-	end = source->second->getMgr()->Modules.end();
+	list_it = source->second->getMgr()->Modules.begin();
+	list_end = source->second->getMgr()->Modules.end();
 }
 
 
@@ -268,12 +273,12 @@ void backend_module_mgr_remote_list_modules_init(const char *sourceName)
 void backend_module_mgr_list_local_modules_init(bool for_install)
 {
         if (for_install){
-                it = list_mgr->Modules.begin();
-                end = list_mgr->Modules.end();
+                list_it = list_mgr->Modules.begin();
+                list_end = list_mgr->Modules.end();
         }
         else{
-                it = mgr->Modules.begin();
-                end = mgr->Modules.end();
+                list_it = mgr->Modules.begin();
+                list_end = mgr->Modules.end();
         }
 }
 
@@ -411,16 +416,12 @@ GList *backend_module_mgr_list_remote_sources(void)
 	const gchar *envhomedir = g_getenv(HOMEVAR);
 	SWBuf baseDir = (envhomedir) ? envhomedir : ".";
 	baseDir += "/" DOTSWORD "/InstallMgr";
-#ifdef SWORD_MULTIVERSE
 	InstallMgr *inst_mgr = new InstallMgr(baseDir,
 					      (StatusReporter *)0,
 					      (SWBuf)"ftp",
 					      (SWBuf)"xiphos@xiphos.org"
 					      );
 	inst_mgr->setUserDisclaimerConfirmed(true);
-#else
-	InstallMgr *inst_mgr = new InstallMgr(baseDir);
-#endif
 
 	for (InstallSourceMap::iterator it =
 	     inst_mgr->sources.begin();
@@ -430,15 +431,9 @@ GList *backend_module_mgr_list_remote_sources(void)
 		mms->type = g_strdup(it->second->type);
 		mms->source = g_strdup(it->second->source);
 		mms->directory = g_strdup(it->second->directory);
-#ifdef SWORD_MULTIVERSE
 		mms->user = g_strdup(it->second->u);
 		mms->pass = g_strdup(it->second->p);
 		mms->uid = g_strdup(it->second->uid);
-#else
-		mms->user = g_strdup("");
-		mms->pass = g_strdup("");
-		mms->uid = g_strdup("");
-#endif
 		retval = g_list_append(retval, (MOD_MGR_SOURCE *) mms);
 	}
 	delete inst_mgr;
@@ -488,15 +483,9 @@ GList *backend_module_mgr_list_local_sources(void)
 			mms->type = is->type;
 			mms->source = is->source;
 			mms->directory = is->directory;
-#ifdef SWORD_MULTIVERSE
 			mms->user = is->u;
 			mms->pass = is->p;
 			mms->uid = is->uid;
-#else
-			mms->user = g_strdup("");
-			mms->pass = g_strdup("");
-			mms->uid = g_strdup("");
-#endif
 			retval = g_list_append(retval,(MOD_MGR_SOURCE*) mms);
 			sourceBegin++;
 		}
@@ -582,7 +571,6 @@ void backend_init_module_mgr_config(void)
 int
 backend_init_module_mgr_config_extras()
 {
-#ifdef SWORD_MULTIVERSE
 	bool needNewInstallMgr = (installMgr == NULL);
 	int retval;
 
@@ -596,30 +584,6 @@ backend_init_module_mgr_config_extras()
 		backend_shut_down_module_mgr();
 	}
 	return retval;
-#else
-	// also the beta repo.
-	backend_module_mgr_add_source("FTPSource",
-				      "FTP",
-				      "CrossWire Beta",
-				      "www.crosswire.org",
-				      "/pub/sword/betaraw",
-				      NULL, NULL, NULL);
-	// new concept: we are our own first-class source.
-	backend_module_mgr_add_source("FTPSource",
-				      "FTP",
-				      "Xiphos",
-				      "ftp.xiphos.org",
-				      ".",
-				      NULL, NULL, NULL);
-	// NET @ bible.org.
-	backend_module_mgr_add_source("FTPSource",
-				      "FTP",
-				      "Bible.org",
-				      "ftp.bible.org",
-				      "/sword",
-				      NULL, NULL, NULL);
-	return 0;
-#endif /* !SWORD_MULTIVERSE */
 }
 
 /******************************************************************************
@@ -671,9 +635,7 @@ void backend_module_mgr_clear_config(void)
 
 void backend_module_mgr_reread_config(void)
 {
-#ifdef SWORD_MULTIVERSE
 	installMgr->readInstallConf();
-#endif
 }
 
 
@@ -720,11 +682,9 @@ void backend_module_mgr_add_source(const char * vtype,
 	is.caption = caption;
 	is.source = source;
 	is.directory = directory;
-#ifdef SWORD_MULTIVERSE
 	is.u = user;
 	is.p = pass;
 	is.uid = uid;
-#endif
 	config.Sections["Sources"].insert(ConfigEntMap::value_type(vtype,
 		is.getConfEnt().c_str()));
 	config.Save();
@@ -784,16 +744,11 @@ void backend_init_module_mgr(const char *dir,
 
 	if (installMgr)
 		delete installMgr;
-#ifdef SWORD_MULTIVERSE
 	installMgr = new InstallMgr(baseDir,
 				    statusReporter,
 				    (SWBuf)"ftp",
 				    (SWBuf)"xiphos@xiphos.org");
 	installMgr->setUserDisclaimerConfirmed(true);
-#else
-	installMgr = new InstallMgr(baseDir, statusReporter);
-#endif
-
 }
 
 /******************************************************************************
