@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * sword_main.cc -
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,8 @@
 #include <config.h>
 #endif
 
+#include <set>
+
 #include <swmgr.h>
 #include <swmodule.h>
 #include <localemgr.h>
@@ -256,9 +258,8 @@ int BackEnd::has_global_option(char * module_name, char * option)
 {
 	SWModule *mod;
 	ModMap::iterator it;
-	//-- iterate through the modules until we find modName
+
 	it = main_mgr->Modules.find(module_name);
-	//-- if we find the module
 	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
 		return mod->getConfig().has("GlobalOptionFilter", option);
@@ -272,12 +273,10 @@ char *BackEnd::get_config_entry(char * module_name, char * entry)
 		return NULL;
 	SWModule *mod;
 	ModMap::iterator it;
-	//-- iterate through the modules until we find modName
+
 	it = main_mgr->Modules.find(module_name);
-	//-- if we find the module
 	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
-		//GS_message(("get_config_entry: %s",mod->getConfigEntry(entry)));
 		return g_strdup((char *) mod->getConfigEntry(entry));
 	} else
 		return NULL;
@@ -302,9 +301,8 @@ char *BackEnd::get_render_text(const char *module_name, const char *key)
 {
 	SWModule *mod;
 	ModMap::iterator it;
-	//-- iterate through the modules until we find modName
+
 	it = main_mgr->Modules.find(module_name);
-	//-- if we find the module
 	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
 		mod->setKey(key);
@@ -317,9 +315,8 @@ char *BackEnd::get_raw_text(const char *module_name, const char *key)
 {
 	SWModule *mod;
 	ModMap::iterator it;
-	//-- iterate through the modules until we find modName
+
 	it = main_mgr->Modules.find(module_name);
-	//-- if we find the module
 	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
 		mod->setKey(key);
@@ -332,9 +329,8 @@ char *BackEnd::render_this_text(const char * module_name, const char * text)
 {
 	SWModule *mod;
 	ModMap::iterator it;
-	//-- iterate through the modules until we find modName
+
 	it = main_mgr->Modules.find(module_name);
-	//-- if we find the module
 	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
 		return strdup((char *) mod->RenderText(text));
@@ -346,9 +342,8 @@ char *BackEnd::get_strip_text_from_string(const char * module_name, const char *
 {
 	SWModule *mod;
 	ModMap::iterator it;
-	//-- iterate through the modules until we find modName
+
 	it = main_mgr->Modules.find(module_name);
-	//-- if we find the module
 	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
 		return strdup((char *) mod->StripText(string));
@@ -359,9 +354,8 @@ char *BackEnd::get_strip_text(const char *module_name, const char *key)
 {
 	SWModule *mod;
 	ModMap::iterator it;
-	//-- iterate through the modules until we find modName
+
 	it = main_mgr->Modules.find(module_name);
-	//-- if we find the module
 	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
 		mod->setKey(key);
@@ -390,11 +384,7 @@ char *BackEnd::key_get_book(const char *key)
 	vkey.AutoNormalize(1);
 	vkey = key;
 
-#ifdef SWORD_MULTIVERSE
 	return strdup((char*)vkey.getBookName());
-#else
-	return strdup((char*)vkey.books[vkey.Testament() - 1][vkey.Book() -1].name);
-#endif
 }
 
 
@@ -420,13 +410,7 @@ unsigned int BackEnd::key_chapter_count(const char *key)
 	vkey.AutoNormalize(1);
 	vkey = key;
 
-#ifdef SWORD_MULTIVERSE
 	return (vkey.getChapterMax());
-#else
-	char testament = vkey.Testament() ;
-	char book = vkey.Book();
-	return (vkey.books[testament-1][book-1].chapmax);
-#endif
 }
 
 
@@ -436,14 +420,7 @@ unsigned int BackEnd::key_verse_count(const char *key)
 	vkey.AutoNormalize(1);
 	vkey = key;
 
-#ifdef SWORD_MULTIVERSE
 	return (vkey.getVerseMax());
-#else
-	char testament = vkey.Testament() ;
-	char book = vkey.Book();
-	int chapter = vkey.Chapter();
-	return (vkey.books[testament-1][book-1].versemax[chapter-1]);
-#endif
 }
 
 
@@ -484,15 +461,37 @@ void BackEnd::delete_entry(void)
 const char *BackEnd::module_get_language(const char *module_name)
 {
 	ModMap::iterator it;
-	//-- iterate through the modules until we find modName
 	it = main_mgr->Modules.find(module_name);
-	//-- if we find the module
 	if (it != main_mgr->Modules.end())
 		return main_get_language_map((*it).second->Lang());
 	return "unknown";
 }
 
 
+char **BackEnd::get_module_language_list(void)
+{
+	char **retval;
+	int i;
+
+	std::set < SWBuf > module_languages;
+	std::set < SWBuf > ::iterator  ml_it;
+
+	// create a set of unique language names in use by modules.
+	ModMap::iterator it;
+	for (it = main_mgr->Modules.begin(); it != main_mgr->Modules.end(); it++)
+		module_languages.insert((*it).second->Lang());
+
+	// construct a list of char* from the uniquified set.
+	retval = g_new0(char *, module_languages.size() + 1);
+	for (i = 0, ml_it = module_languages.begin();
+	     ml_it != module_languages.end();
+	     ++i, ++ml_it) {
+	    retval[i] = g_strdup(ml_it->c_str());
+	}
+	return retval;
+}
+
+
 int BackEnd::is_module(const char *mod_name)
 {
 	if (mod_name == NULL)
@@ -510,9 +509,8 @@ int BackEnd::module_type(const char *mod_name)
 	ModMap::iterator it;
 	if ((!mod_name) || (strlen(mod_name) < 2))
 		return -1;
-	//-- iterate through the modules until we find modName
+
 	it = main_mgr->Modules.find(mod_name);
-	//-- if we find the module
 	if (it != main_mgr->Modules.end()) {
 
 		if (!strcmp((*it).second->Type(), TEXT_MODS)) {
@@ -545,9 +543,8 @@ char *BackEnd::module_description(char *mod_name)
 
 	if ((!mod_name) || (strlen(mod_name) < 2))
 		return NULL;
-	//-- iterate through the modules until we find modName
+
 	it = main_mgr->Modules.find(mod_name);
-	//-- if we find the module
 	if (it != main_mgr->Modules.end()) {
 		return (*it).second->Description();
 	}
@@ -682,7 +679,6 @@ int BackEnd::set_module_key(const char *module_name, const char *key)
 	display_mod = main_mgr->Modules[module_name];
 
 	if (display_mod) {
-		GS_message((f_message,878,"key",key));
 		display_mod->setKey(key);
 		return 1;
 	}
@@ -732,6 +728,12 @@ unsigned long BackEnd::treekey_set_key(char * key)
 }
 void BackEnd::set_treekey(unsigned long offset)
 {
+	if (!display_mod) {
+		gui_generic_warning(_("Xiphos failure: \"can't happen\", display_mod: null"
+				      "\nPlease report this. sword_main.cc:set_treekey"
+				      "\nWhat were you doing when this occurred?"));
+		return;
+	}
 	if (tree_key)
 		delete tree_key;
 	tree_key = (TreeKeyIdx *) display_mod->CreateKey();
@@ -751,9 +753,8 @@ unsigned long BackEnd::get_treekey_offset_from_key(const char * module_name, con
         SWModule *mod;
 	ModMap::iterator it;
 	unsigned long retval = 0;
-	//-- iterate through the modules until we find modName
+
 	it = main_mgr->Modules.find(module_name);
-	//-- if we find the module
 	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
 		TreeKeyIdx *tree_key_idx = (TreeKeyIdx *) mod->CreateKey();
@@ -809,7 +810,6 @@ char *BackEnd::treekey_get_local_name(unsigned long offset)
 {
         if (tree_key) {
                 tree_key->setOffset(offset);
-                //-- returned value must be freed by calling function
                 return strdup((char *) tree_key->getLocalName());
         }
         return NULL;
