@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * link_dialog.c - dialog for inserting a link
  *
- * Copyright (C) 2005-2009 Xiphos Developer Team
+ * Copyright (C) 2005-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -81,11 +81,11 @@ void button_ok_clicked_cb(GtkObject *object, EDITOR *e)
 		encoded_verse = main_url_encode(verse_str);
 
 	g_string_printf(str,
-			(((GTK_TOGGLE_BUTTON(linkage_verse_list)->active) &&
+			(((gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(linkage_verse_list))) &&
 			  ((type == -1) ||
 			   (type == TEXT_TYPE) ||
 			   (type == COMMENTARY_TYPE)))
-			 ? "<a href=\"xiphos.url?action=showRef&type=scripRef&module=%s&value=%s\">%s</a>"
+			 ? "<a href=\"passagestudy.jsp?action=showRef&type=scripRef&module=%s&value=%s\">%s</a>"
 			 : "<a href=\"sword://%s/%s\">%s</a>"),
 			(encoded_mod   ? encoded_mod   : ""),
 			(encoded_verse ? encoded_verse : ""),
