@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * html-editor.c - the html editor
  *
- * Copyright (C) 2005-2009 Xiphos Developer Team
+ * Copyright (C) 2005-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -95,13 +95,6 @@ handle_error (GError **error)
 static
 void do_exit(EDITOR * e)
 {
-	GS_message(("do_exit"));
-//	GS_message((((char*)e->filename ? e->filename : "no filename")));
-//	GS_message(((char*)e->module ? e->module : "no module"));
-//	GS_message(((char*)e->key ? e->key : "no key"));
-
-	if (e->studypad)
-		settings.studypad_dialog_exist = FALSE;
 	if (e->filename) {
 		g_free(e->filename);
 	}
@@ -113,7 +106,6 @@ void do_exit(EDITOR * e)
 	}
 	if (e->window)
 		gtk_widget_destroy(e->window);
-		//GS_message(("e->widow still exist!"));
 	g_free(e);
 }
 
@@ -471,7 +463,6 @@ save_dialog (GtkhtmlEditor *editor, EDITOR * e)
 
 		new_filename = gtk_file_chooser_get_filename (
 			GTK_FILE_CHOOSER (dialog));
-		//GS_message (("\nnew_filename: %s\n",new_filename));
 		gtkhtml_editor_set_filename (editor, new_filename);
 
 		if (e->filename)
@@ -530,7 +521,7 @@ view_source_dialog (GtkhtmlEditor *editor,
 	gtk_scrolled_window_set_shadow_type (
 		GTK_SCROLLED_WINDOW (scrolled_window), GTK_SHADOW_IN);
 	gtk_box_pack_start (
-		GTK_BOX (GTK_DIALOG (dialog)->vbox),
+		GTK_BOX (gtk_dialog_get_content_area(GTK_DIALOG (dialog))),
 		scrolled_window, TRUE, TRUE, 0);
 
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
@@ -1091,7 +1082,6 @@ gboolean editor_is_dirty(EDITOR * e)
 void editor_save_book(EDITOR * e)
 {
 	if (editor_is_dirty(e)) {
-		GS_message(("editor_is_dirty"));
 		_save_book(e);
 	}
 }
@@ -1197,7 +1187,6 @@ editor_load_note(EDITOR * e, const gchar * module_name,
 	title = g_strdup_printf("%s - %s", e->module, e->key);
 	text = main_get_raw_text((gchar *) e->module, (gchar *) e->key);
 	if (strlen(text)) {
-		//GS_message(("\n\n\neditor_load_note:\n%s\n\n\n", text));
 		gtkhtml_editor_set_text_html (GTKHTML_EDITOR(e->window),
 					      text,
 					      strlen(text));
@@ -1361,7 +1350,6 @@ gint _create_new(const gchar * filename, const gchar * key, gint editor_type)
 			editor->filename = g_strdup(filename);
 			_load_file(editor, g_strdup(filename));
 		}
-		settings.studypad_dialog_exist = TRUE;
 		break;
 	case NOTE_EDITOR:
 		editor->studypad = FALSE;
@@ -1460,7 +1448,7 @@ gint editor_create_new(const gchar * filename, const gchar * key, gint editor_ty
 					g_free(e->filename);
 				e->filename = g_strdup(filename);
 				gtk_widget_show(e->window);
-				gdk_window_raise(GTK_WIDGET(e->window)->window);
+				gdk_window_raise(gtk_widget_get_parent_window(GTK_WIDGET(e->window)));
 
 				_load_file(e, g_strdup(filename));
 				return 1;
@@ -1476,7 +1464,7 @@ gint editor_create_new(const gchar * filename, const gchar * key, gint editor_ty
 				g_free(e->key);
 			e->key = g_strdup(key);
 			gtk_widget_show(e->window);
-			gdk_window_raise(GTK_WIDGET(e->window)->window);
+			gdk_window_raise(gtk_widget_get_parent_window(GTK_WIDGET(e->window)));
 
 			editor_load_note(e, NULL, NULL);
 
@@ -1492,7 +1480,7 @@ gint editor_create_new(const gchar * filename, const gchar * key, gint editor_ty
 				g_free(e->key);
 			e->key = g_strdup(key);
 			gtk_widget_show(e->window);
-			gdk_window_raise(GTK_WIDGET(e->window)->window);
+			gdk_window_raise(gtk_widget_get_parent_window(GTK_WIDGET(e->window)));
 
 			editor_load_book(e);
 
