@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * about_modules.c - Sword modules about dialog
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -197,7 +197,7 @@ gui_create_about_modules(void)
 				    304);
 	gtk_window_set_resizable(GTK_WINDOW(dialog_about_mods), TRUE);
 
-	dialog_vbox28 = GTK_DIALOG(dialog_about_mods)->vbox;
+	dialog_vbox28 = gtk_dialog_get_content_area(GTK_DIALOG(dialog_about_mods));
 	g_object_set_data(G_OBJECT(dialog_about_mods),
 			  "dialog_vbox28", dialog_vbox28);
 	gtk_widget_show(dialog_vbox28);
@@ -211,7 +211,7 @@ gui_create_about_modules(void)
 	gtk_widget_show(hbox21);
 	gtk_box_pack_start(GTK_BOX(vbox25), hbox21, FALSE, TRUE, 0);
 
-	pixmap = pixmap_finder("sword3.png");
+	pixmap = pixmap_finder("sword.png");
 	gtk_widget_show(pixmap);
 	gtk_box_pack_start(GTK_BOX(hbox21), pixmap, TRUE, TRUE, 0);
 
@@ -248,7 +248,7 @@ gui_create_about_modules(void)
 				NULL);
 #endif
 	dialog_action_area28 =
-	    GTK_DIALOG(dialog_about_mods)->action_area;
+                gtk_dialog_get_action_area(GTK_DIALOG(dialog_about_mods));
 	g_object_set_data(G_OBJECT(dialog_about_mods),
 			  "dialog_action_area28",
 			  dialog_action_area28);
@@ -266,8 +266,11 @@ gui_create_about_modules(void)
 	button = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
 	gtk_widget_show(button);
 	gtk_container_add(GTK_CONTAINER(hbuttonbox7), button);
+#ifdef HAVE_GTK_218
+        gtk_widget_set_can_default(button, TRUE);
+#else
 	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
-
+#endif
 	g_signal_connect(GTK_OBJECT(button), "clicked",
 			   G_CALLBACK(about_modules_ok), NULL);
 	return dialog_about_mods;
@@ -317,7 +320,7 @@ about_module_display(GString * str,
 			if ((text[1] == 'p') &&
 			    (text[2] == 'a') &&
 			    (text[3] == 'r')) {
-				str = g_string_append(str, (tooltip ? "\n" : "<br>\n"));
+				str = g_string_append(str, (tooltip ? "\n" : "<br/>\n"));
 				text += 3;
 				continue;
 			}
@@ -376,9 +379,9 @@ gui_core_display_about_dialog(gchar * desc,
 	static const char *html_end = "</body></html>";
 
 	g_string_printf(description,
-			"<center><font color=\"#000fcf\"><b>%s</b></font><hr>%s %s</center><br>",
+			"<center><font color=\"#000fcf\"><b>%s</b></font><hr/>%s %s</center><br/>",
 			(desc ? desc : "No module present"),
-			(version ? "<br>Sword module version" : ""),
+			(version ? "<br/>Sword module version" : ""),
 			(version ? version : ""));
 	aboutbox = gui_create_about_modules();
 	gtk_widget_show(aboutbox);
