@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * bibletext.c - gui for Bible text modules
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,13 +43,11 @@
 #include "gui/bookmark_dialog.h"
 #include "gui/bookmarks_treeview.h"
 #include "gui/export_dialog.h"
-#include "gui/shortcutbar_main.h"
 #include "gui/sidebar.h"
 #include "gui/cipher_key_dialog.h"
 #include "gui/main_menu.h"
 #include "gui/main_window.h"
 #include "gui/menu_popup.h"
-#include "gui/shortcutbar_search.h"
 #include "gui/dialog.h"
 #include "gui/font_dialog.h"
 #include "gui/dictlex.h"
