@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * bibletext_dialog.c - view Bible text module in a dialog
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -222,34 +222,12 @@ static void dialog_url(GtkHTML *html,
 				++url_buf;	/* remove T */
 				if (*url_buf == 'G') {
 					++url_buf;	/* remove G */
-					if (settings.havethayer) {
-						buf1 = g_strdup(url);
-						show_in_statusbar(vt->
-								  statusbar,
-								  buf1,
-								  "Thayer");
-						g_free(buf1);
-						return;
-					}
-
-					else
-						return;
+					return;
 				}
 
 				if (*url_buf == 'H') {
 					++url_buf;	/* remove H */
-					if (settings.havebdb) {
-						buf1 = g_strdup(url);
-						show_in_statusbar(vt->
-								  statusbar,
-								  buf1,
-								  "BDB");
-						g_free(buf1);
-						return;
-					}
-
-					else
-						return;
+					return;
 				}
 			}
 
@@ -257,18 +235,8 @@ static void dialog_url(GtkHTML *html,
 				++url_buf;	/* remove G */
 				buf1 = g_strdup(url_buf);
 				if (atoi(buf1) > 5624) {
-					if (settings.havethayer) {
-						show_in_statusbar(vt->
-								  statusbar,
-								  buf1,
-								  "Thayer");
-						g_free(buf1);
-						return;
-					} else
-						return;
-
+					return;
 				}
-
 				else {
 					show_in_statusbar(vt->statusbar,
 							  buf1,
@@ -283,19 +251,8 @@ static void dialog_url(GtkHTML *html,
 				++url_buf;	/* remove H */
 				buf1 = g_strdup(url);
 				if (atoi(buf1) > 8674) {
-					if (settings.havebdb) {
-						show_in_statusbar(vt->
-								  statusbar,
-								  buf1,
-								  "BDB");
-						g_free(buf1);
-						return;
-					}
-
-					else
-						return;
+					return;
 				}
-
 				else {
 					show_in_statusbar(vt->statusbar,
 							  buf1,
@@ -410,7 +367,7 @@ void gui_bible_dialog_sync_toggled(GtkToggleButton *button,
 {
 	if (c == NULL)
 		c = cur_vt;
-	if (button->active) {
+	if (gtk_toggle_button_get_active(button)) {
 		sync_with_main(c);
 		c->sync = TRUE;
 	} else
