@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * bookmarks_treeview.c - gui for bookmarks using treeview
  *
- * Copyright (C) 2003-2009 Xiphos Developer Team
+ * Copyright (C) 2003-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -531,7 +531,7 @@ static void load_xml_bookmarks(GtkTreeView * tree, GtkTreeIter * iter)
 	GString *str;
 	const xmlChar *file;
 
-	str = g_string_new(settings.swbmDir);
+	str = g_string_new(NULL);
 	g_string_printf(str, "%s/bookmarks.xml", settings.swbmDir);
 	file = (const xmlChar *) str->str;
 	gui_parse_bookmarks(tree, file, iter);
@@ -823,8 +823,7 @@ static gboolean button_release_event(GtkWidget * widget,
 			gtk_widget_set_sensitive(menu.remove, TRUE);
 		}
 
-		gtk_widget_set_sensitive(menu.bibletime,
-					 settings.have_bibletime);
+		gtk_widget_set_sensitive(menu.bibletime, TRUE);
 		gtk_widget_set_sensitive(menu.edit, TRUE);
 		gtk_widget_set_sensitive(menu.delete, TRUE);
 		is_selected = TRUE;
@@ -847,22 +846,19 @@ static gboolean button_release_event(GtkWidget * widget,
 		if (!settings.browsing)
 			gtk_widget_hide(menu.in_tab);
 
-		if (GTK_CHECK_MENU_ITEM(menu.reorder)->active) {
+		if (gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menu.reorder))) {
 			gtk_widget_set_sensitive(menu.in_tab, FALSE);
 			gtk_widget_set_sensitive(menu.in_dialog, FALSE);
 			gtk_widget_set_sensitive(menu.new, FALSE);
 			gtk_widget_set_sensitive(menu.insert, FALSE);
 			gtk_widget_set_sensitive(menu.edit, FALSE);
 			gtk_widget_set_sensitive(menu.delete, FALSE);
-			gtk_widget_set_sensitive(menu.bibletime, FALSE);
+			gtk_widget_set_sensitive(menu.bibletime, TRUE);
 			gtk_widget_set_sensitive(menu.remove, FALSE);
 			//gtk_widget_set_sensitive(menu.remove, FALSE);
-			//gtk_widget_set_sensitive(menu.restore, FALSE);
 			return TRUE;
 		} else {
-			gtk_widget_set_sensitive(menu.bibletime,
-						 settings.
-						 have_bibletime);
+			gtk_widget_set_sensitive(menu.bibletime, TRUE);
 			return FALSE;
 		}
 		break;
@@ -874,7 +870,7 @@ static gboolean button_release_event(GtkWidget * widget,
 			if (!strcmp(module,"studypad"))
 				url =
 				    g_strdup_printf
-				    ("xiphos.url?action=showStudypad&"
+				    ("passagestudy.jsp?action=showStudypad&"
 				     "type=9&value=%s&module=%s",
 				     main_url_encode(key),
 				     main_url_encode(module));
@@ -882,7 +878,7 @@ static gboolean button_release_event(GtkWidget * widget,
 			else
 				url =
 				    g_strdup_printf
-				    ("xiphos.url?action=showBookmark&"
+				    ("passagestudy.jsp?action=showBookmark&"
 				     "type=%s&value=%s&module=%s",
 				     (button_one) ? "currentTab" : "newTab",
 				     main_url_encode(key),
