@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * cipher_key_dialog.c  - asks for key to unlock sword module
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -51,29 +51,28 @@
  *   gboolean
  */
 
-gchar *gui_add_cipher_key(gchar *mod_name, gchar *cipher_old)
+gchar *gui_add_cipher_key(const char *mod_name, gchar *cipher_old)
 {
 	gchar *retval = NULL;
-	gint test;
 	GS_DIALOG *info;
 
 	info = gui_new_dialog();
 	info->stock_icon = GTK_STOCK_DIALOG_WARNING;
-	info->label_top = _("Cipher Key?");
+	info->label_top = g_strdup_printf(_("Cipher key for module %s"), mod_name);
 	info->label_middle = _("for:");
-	info->label_bottom = mod_name;
+	info->label_bottom = (char*)mod_name;
 	info->text1 = g_strdup(cipher_old);
-	info->label1 = _("Enter Cipher Key: ");
+	info->label1 = _("Enter Key: ");
 	info->ok = TRUE;
 	info->cancel = TRUE;
 	/*** open dialog ***/
-	test = gui_gs_dialog(info);
-	if (test == GS_OK) {
+	if (gui_gs_dialog(info) == GS_OK) {
 		main_set_module_unlocked(mod_name, info->text1);
 		main_save_module_key(mod_name, info->text1);
 		main_update_module_lists();
 		retval = g_strdup(info->text1);
 	}
+	g_free(info->label_top);
 	g_free(info->text1);
 	g_free(info);
 	return retval;
