@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * commentary_dialog.c - dialog for a commentary module
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -90,7 +90,6 @@ static void on_dialog_destroy(GtkObject *object,
 	if (!dialog_freed)
 		main_free_on_destroy(d);
 	dialog_freed = FALSE;
-	settings.percomm_dialog_exist = FALSE;
 }
 
 
@@ -416,7 +415,7 @@ void gui_commentary_dialog_sync_toggled(GtkToggleButton * button,
 {
 	if (d == NULL)
 		d = cur_d;
-	if (button->active) {
+	if (gtk_toggle_button_get_active(button)) {
 		sync_with_main(d);
 		d->sync = TRUE;
 	} else
