@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * dialog.c -
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -123,7 +123,6 @@ static void get_entry_text(GS_DIALOG * info)
 
 static void on_dialog_response(GtkDialog * dialog, gint response_id, GS_DIALOG * info)
 {
-	GS_warning(("%d", response_id));
 	switch (response_id) {
 	case GTK_RESPONSE_OK:
 		retval = GS_OK;
@@ -187,7 +186,7 @@ static GtkWidget *create_dialog_alert(GS_DIALOG * info)
 	//gtk_window_set_resizable(GTK_WINDOW(dialog_alert), FALSE);
 	gtk_dialog_set_has_separator(GTK_DIALOG(dialog_alert), FALSE);
 
-	dialog_vbox2 = GTK_DIALOG(dialog_alert)->vbox;
+	dialog_vbox2 = gtk_dialog_get_content_area(GTK_DIALOG(dialog_alert));
 	gtk_widget_show(dialog_vbox2);
 
 	hbox3 = gtk_hbox_new(FALSE, 12);
@@ -238,7 +237,7 @@ static GtkWidget *create_dialog_alert(GS_DIALOG * info)
 		gtk_misc_set_alignment(GTK_MISC(label10), 0, 0.5);
 	}
 
-	dialog_action_area2 = GTK_DIALOG(dialog_alert)->action_area;
+	dialog_action_area2 = gtk_dialog_get_action_area(GTK_DIALOG(dialog_alert));
 	gtk_widget_show(dialog_action_area2);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area2),
 				  GTK_BUTTONBOX_END);
@@ -313,7 +312,7 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 	gtk_window_set_resizable(GTK_WINDOW(dialog_request), FALSE);
 	gtk_dialog_set_has_separator(GTK_DIALOG(dialog_request), FALSE);
 
-	dialog_vbox3 = GTK_DIALOG(dialog_request)->vbox;
+	dialog_vbox3 = gtk_dialog_get_content_area(GTK_DIALOG(dialog_request));
 	gtk_widget_show(dialog_vbox3);
 
 	hbox4 = gtk_hbox_new(FALSE, 12);
@@ -487,7 +486,7 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 				 G_CALLBACK(on_dialog_enter), info);
 	}
 
-	dialog_action_area3 = GTK_DIALOG(dialog_request)->action_area;
+	dialog_action_area3 = gtk_dialog_get_action_area(GTK_DIALOG(dialog_request));
 	gtk_widget_show(dialog_action_area3);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area3),
 				  GTK_BUTTONBOX_END);
@@ -534,28 +533,6 @@ GS_DIALOG *gui_new_dialog(void)
 {
 	standard_info = g_new0(GS_DIALOG, 1);
 
-	standard_info->stock_icon = NULL;
-	standard_info->dialog = NULL;
-	standard_info->title = NULL;
-	standard_info->text1 = NULL;
-	standard_info->text2 = NULL;
-	standard_info->text3 = NULL;
-	standard_info->text4 = NULL;
-	standard_info->text5 = NULL;
-	standard_info->text6 = NULL;
-	standard_info->label_top = NULL;
-	standard_info->label_middle = NULL;
-	standard_info->label1 = NULL;
-	standard_info->label2 = NULL;
-	standard_info->label3 = NULL;
-	standard_info->label4 = NULL;
-	standard_info->label5 = NULL;
-	standard_info->label6 = NULL;
-	standard_info->label_bottom = NULL;
-	standard_info->ok = FALSE;
-	standard_info->cancel = FALSE;
-	standard_info->yes = FALSE;
-	standard_info->no = FALSE;
 	/* set entrys to null */
 	entry1 = NULL;
 	entry2 = NULL;
