@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * _dictlex.c - gui for commentary modules
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,11 +41,9 @@
 #include "gui/bookmarks_treeview.h"
 #include "gui/xiphos.h"
 #include "gui/cipher_key_dialog.h"
-#include "gui/shortcutbar_main.h"
 #include "gui/dictlex_dialog.h"
 #include "gui/main_window.h"
 #include "gui/menu_popup.h"
-#include "gui/shortcutbar_search.h"
 #include "gui/sidebar.h"
 #include "gui/find_dialog.h"
 #include "gui/font_dialog.h"
@@ -307,7 +305,7 @@ static gint html_button_released(GtkWidget * html,
 				key = g_strdelimit(key, "*", ' ');
 				key = g_strstrip(key);
 				url = g_strdup_printf(
-					"xiphos.url?action=showModInfo&value=1&module=%s",
+					"passagestudy.jsp?action=showModInfo&value=1&module=%s",
 					key);
 				main_url_handler(url,TRUE);
 				g_free((gchar*)url);
