@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * gbs.c - generic book support - the gui
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,11 +47,9 @@
 #include "gui/xiphos.h"
 #include "gui/cipher_key_dialog.h"
 #include "gui/find_dialog.h"
-#include "gui/shortcutbar_main.h"
 #include "gui/sidebar.h"
 #include "gui/bookmarks.h"
 #include "gui/main_window.h"
-#include "gui/shortcutbar_search.h"
 #include "gui/font_dialog.h"
 #include "gui/widgets.h"
 #include "gui/navbar_book.h"
@@ -150,7 +148,7 @@ static gboolean on_book_button_release_event(GtkWidget * widget,
 				key = g_strdelimit(key, "*", ' ');
 				key = g_strstrip(key);
 				url = g_strdup_printf(
-					"xiphos.url?action=showModInfo&value=1&module=%s",
+					"passagestudy.jsp?action=showModInfo&value=1&module=%s",
 					key);
 				main_url_handler(url,TRUE);
 				g_free((gchar*)url);
