@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * main_menu.c - creation of and call backs for xiphos main menu
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -300,47 +300,6 @@ G_MODULE_EXPORT void on_search_activate(GtkMenuItem * menuitem, gpointer user_da
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_sidebar),2);
 }
 
-/******************************************************************************
- * Name
- *  on_verse_style_activate
- *
- * Synopsis
- *   #include "gui/main_menu.h"
- *
- *   void on_verse_style_activate(GtkMenuItem *menuitem, gpointer user_data)
- *
- * Description
- *   toggle between verse and paragraph style
- *
- * Return value
- *   void
- */
-
-extern gboolean style_display;
-
-G_MODULE_EXPORT void
-on_verse_style_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
-{
-	if (style_display) {
-		gchar *file = g_strdup_printf("%s/modops.conf",
-					      settings.gSwordDir);
-		gchar *url = g_strdup_printf("sword://%s/%s",
-					     settings.MainWindowModule,
-					     settings.currentverse);
-		/* remember our choice for the next program startup */
-		settings.versestyle = menuitem->active;
-		save_conf_file_item(file, settings.MainWindowModule, "style",
-				    (menuitem->active
-				     ? "verse"
-				     : "paragraph"));
-		if (settings.havebible) {
-			main_url_handler(url, TRUE);
-		}
-		g_free(url);
-		g_free(file);
-	}
-}
-
 /******************************************************************************
  * Name
  *  on_linked_tabs_activate
@@ -412,6 +371,7 @@ on_show_verse_numbers_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
 	settings.showversenum = menuitem->active;
 	xml_set_value("Xiphos", "misc", "showversenum",
 		      (settings.showversenum ? "1" : "0"));
+	main_display_commentary(NULL, settings.currentverse);
 	main_display_bible(NULL, settings.currentverse);
 }
 
@@ -499,31 +459,6 @@ on_side_preview_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
 	gui_show_previewer_in_sidebar(settings.show_previewer_in_sidebar);
 }
 
-/******************************************************************************
- * Name
- *   on_double_space_text_activate
- *
- * Synopsis
- *   #include "gui/main_menu.h"
- *
- *   void on_double_space_text_activate(GtkMenuItem *menuitem, gpointer user_data)
- *
- * Description
- *   toggle double-spacing of text.
- *
- * Return value
- *   void
- */
-G_MODULE_EXPORT void
-on_double_space_text_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
-{
-	settings.doublespace = menuitem->active;
-	xml_set_value("Xiphos", "misc", "doublespace",
-		      (settings.doublespace ? "1" : "0"));
-	//main_display_bible(NULL, settings.currentverse);
-	main_refresh_all();
-}
-
 /******************************************************************************
  * Name
  *  on_quit_activate
@@ -644,7 +579,7 @@ on_save_session_activate(GtkMenuItem * menuitem, gpointer user_data)
  * Return value
  *   void
  */
-static void
+void
 redisplay_to_realign()
 {
 	static int realign_busy = FALSE;
@@ -888,7 +823,6 @@ GtkWidget *gui_create_main_menu(void)
 	widgets.viewpreview_item = glade_xml_get_widget (gxml, "preview");
 	widgets.viewcomms_item = glade_xml_get_widget (gxml, "commentary");
 	widgets.viewdicts_item = glade_xml_get_widget (gxml, "show_dictionary_lexicon");
-	widgets.versestyle_item = glade_xml_get_widget (gxml, "verse_per_line");
 	widgets.linkedtabs_item = glade_xml_get_widget (gxml, "link_tabs");
 	widgets.readaloud_item = glade_xml_get_widget (gxml, "read_aloud");
 	widgets.showversenum_item = glade_xml_get_widget (gxml, "show_verse_numbers");
@@ -896,10 +830,7 @@ GtkWidget *gui_create_main_menu(void)
 	widgets.parallel_tab_item = glade_xml_get_widget (gxml, "show_parallel_view_in_a_tab");
 	widgets.side_preview_item = glade_xml_get_widget (gxml, "show_previewer_in_sidebar");
 
-	widgets.doublespace_item = glade_xml_get_widget (gxml, "double_space_text");
-#ifndef USE_GTKMOZEMBED
-	gtk_widget_hide(widgets.doublespace_item);
-#endif /* !USE_GTKMOZEMBED */
+	widgets.new_journal_item = glade_xml_get_widget (gxml, "newjournal");
 
 	/* map tab's show state into view menu. */
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
@@ -922,9 +853,6 @@ GtkWidget *gui_create_main_menu(void)
 				       settings.show_previewer_in_sidebar);
 
 	/* update other status toys */
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
-				       (widgets.versestyle_item),
-				       settings.versestyle);
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
 				       (widgets.linkedtabs_item),
 				       settings.linkedtabs);
@@ -937,12 +865,6 @@ GtkWidget *gui_create_main_menu(void)
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
 				       (widgets.versehighlight_item),
 				       settings.versehighlight);
-#ifdef USE_GTKMOZEMBED
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
-				       (widgets.doublespace_item),
-				       settings.doublespace);
-#endif /* USE_GTKMOZEMBED */
-
     	/* connect signals and data */
 	glade_xml_signal_autoconnect_full
 		(gxml, (GladeXMLConnectFunc)gui_glade_signal_connect_func, NULL);
@@ -950,5 +872,10 @@ GtkWidget *gui_create_main_menu(void)
 	//set up global function to handle all link buttons
 	gtk_link_button_set_uri_hook (link_uri_hook, NULL, NULL);
 
+	if (settings.prayerlist)
+		gtk_widget_show(widgets.new_journal_item);
+	else
+		gtk_widget_hide(widgets.new_journal_item);
+
 	return menu;
 }
