@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * main_window.c - main window gui
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,10 +44,7 @@
 #include "gui/xiphos.h"
 #include "gui/main_window.h"
 #include "gui/main_menu.h"
-#include "gui/shortcutbar_main.h"
-#include "gui/shortcutbar_dialog.h"
 #include "gui/sidebar.h"
-//#include "gui/toolbar_nav.h"
 #include "gui/utilities.h"
 #include "gui/bibletext.h"
 #include "gui/parallel_view.h"
@@ -71,6 +68,12 @@
 
 #include "gui/debug_glib_null.h"
 
+/* X keyboard #definitions, to handle shortcuts */
+/* we must define the categories of #definitions we need. */
+#define XK_MISCELLANY
+#define XK_LATIN1
+#include <X11/keysymdef.h>
+
 WIDGETS widgets;
 
 
@@ -245,9 +248,9 @@ void gui_set_bible_comm_layout(void)
 	gtk_paned_set_position(GTK_PANED(widgets.hpaned),
 				       settings.biblepane_width);
 	gtk_paned_set_position(GTK_PANED(widgets.vpaned),
-				       settings.biblepane_hight);
+				       settings.biblepane_height);
 	gtk_paned_set_position(GTK_PANED(widgets.vpaned2),
-				       settings.commpane_hight);
+				       settings.commpane_height);
 
 	if ((settings.showcomms == TRUE)  ||  (settings.showdicts == TRUE)) {
 		gtk_widget_show(widgets.vpaned2);
@@ -260,13 +263,13 @@ void gui_set_bible_comm_layout(void)
 
 	gtk_paned_set_position(GTK_PANED(widgets.vpaned2),
 			       (settings.showcomms
-				? settings.commpane_hight
+				? settings.commpane_height
 				: 0));
 
 	gtk_paned_set_position(GTK_PANED(widgets.vpaned2),
 			       (settings.showdicts
-				? settings.commpane_hight
-				: settings.gs_hight));
+				? settings.commpane_height
+				: settings.gs_height));
 
 	if ((settings.showcomms == FALSE)  && (settings.showdicts == FALSE)) {
 		gtk_widget_hide(widgets.vpaned2);
@@ -358,7 +361,11 @@ static gboolean  delete_event (GtkWidget *widget,
 	/* shutdown the sword stuff */
 	main_shutdown_backend();
 	gtk_main_quit();
+#if 0
+	/* this causes trouble when paratab is active.
+	   and frankly, why do we care?  we're about to exit.  just leave. */
 	gtk_widget_destroy(widgets.app);
+#endif
 	exit(0);
 	return TRUE;
 }
@@ -397,16 +404,16 @@ static gboolean epaned_button_release_event(GtkWidget * widget,
 				      "shortcutbar", layout);
 		}
 		if (!strcmp((gchar *) user_data, "vpaned")) {
-			settings.biblepane_hight = panesize;
-			sprintf(layout, "%d", settings.biblepane_hight);
+			settings.biblepane_height = panesize;
+			sprintf(layout, "%d", settings.biblepane_height);
 			xml_set_value("Xiphos", "layout",
-				      "biblehight", layout);
+				      "bibleheight", layout);
 		}
 		if (!strcmp((gchar *) user_data, "vpaned2")) {
-			settings.commpane_hight = panesize;
-			sprintf(layout, "%d", settings.commpane_hight);
+			settings.commpane_height = panesize;
+			sprintf(layout, "%d", settings.commpane_height);
 			xml_set_value("Xiphos", "layout",
-				      "commentaryhight", layout);
+				      "commentaryheight", layout);
 		}
 		if (!strcmp((gchar *) user_data, "hpaned1")) {
 			settings.biblepane_width = panesize;
@@ -432,7 +439,7 @@ static gboolean epaned_button_release_event(GtkWidget * widget,
  *				   gpointer user_data)
  *
  * Description
- *
+ *   remember placement+size of main window.
  *
  * Return value
  *   gboolean
@@ -449,15 +456,15 @@ static gboolean on_configure_event(GtkWidget * widget,
  	gdk_window_get_root_origin(GDK_WINDOW(widgets.app->window), &x, &y);
 
 	settings.gs_width = event->width;
-	settings.gs_hight = event->height;
+	settings.gs_height = event->height;
 	settings.app_x = x;
 	settings.app_y = y;
 
 	sprintf(layout, "%d", settings.gs_width);
 	xml_set_value("Xiphos", "layout", "width", layout);
 
-	sprintf(layout, "%d", settings.gs_hight);
-	xml_set_value("Xiphos", "layout", "hight", layout);
+	sprintf(layout, "%d", settings.gs_height);
+	xml_set_value("Xiphos", "layout", "height", layout);
 
 	sprintf(layout, "%d", settings.app_x);
 	xml_set_value("Xiphos", "layout", "app_x", layout);
@@ -563,28 +570,37 @@ gboolean on_vbox1_key_press_event(GtkWidget * widget, GdkEventKey * event,
 	/* these are the mods we actually use for global keys, we always only check for these set */
 	guint state = event->state & (GDK_SHIFT_MASK  | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_MOD4_MASK );
 
-	switch (event->hardware_keycode) {
-	case GS_KEY_SHIFT: /* shift keys - we need this for locking strongs (and other stuff) while moving mouse */
-	case GS_KEY_SHIFT_R: /* to previewer */
+	switch (event->keyval) {
+	case XK_Shift_L:	/* shift keys - we need this for locking strongs (and */
+	case XK_Shift_R:	/* other stuff) while moving mouse to previewer */
 		shift_key_pressed = TRUE;
-	case GS_KEY_D: // Alt-D  dictionary entry
+		/* no break? hm... */
+
+	case XK_b: // Alt-B  bookmark
+		if (state == GDK_MOD1_MASK) {
+			gchar *label = g_strdup_printf("%s, %s",
+						       settings.currentverse,
+						       settings.MainWindowModule);
+			gui_bookmark_dialog(label,
+					    settings.MainWindowModule,
+					    settings.currentverse);
+			g_free(label);
+		}
+		break;
+
+	case XK_c: // Alt-C  commentary pane
+		if (state == GDK_MOD1_MASK) {
+			gtk_widget_grab_focus(navbar_versekey.lookup_entry);
+			gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_comm_book),0);
+		}
+		break;
+
+	case XK_d: // Alt-D  dictionary entry
 		if (state == GDK_MOD1_MASK)
 			gtk_widget_grab_focus(widgets.entry_dict);
 		break;
 
-	case GS_KEY_G: // Alt-G  genbook entry
-		if (state == GDK_MOD1_MASK) {
-			gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_comm_book),1);
-			gtk_widget_grab_focus(navbar_book.lookup_entry);
-		}
-		break;
-
-	case GS_KEY_L: // Ctrl-L  verse entry
-		if (state == GDK_CONTROL_MASK)
-			gtk_widget_grab_focus(navbar_versekey.lookup_entry);
-		break;
-
-	case GS_KEY_F: // Ctrl-F  find text
+	case XK_f: // Ctrl-F  find text
 		if (state == GDK_CONTROL_MASK) {
 			if (settings.showtexts) {
 				gui_find_dlg(widgets.html_text,
@@ -609,33 +625,43 @@ gboolean on_vbox1_key_press_event(GtkWidget * widget, GdkEventKey * event,
 		}
 		break;
 
-	case GS_KEY_C: // Alt-C  commentary pane
+	case XK_g: // Alt-G  genbook entry
 		if (state == GDK_MOD1_MASK) {
+			gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_comm_book),1);
+			gtk_widget_grab_focus(navbar_book.lookup_entry);
+		}
+		break;
+
+	case XK_j: // J    "next verse"
+		if (state == 0)
+			access_on_down_eventbox_button_release_event(VERSE_BUTTON);
+		break;
+
+	case XK_k: // K    "previous verse"
+		if (state == 0)
+			access_on_up_eventbox_button_release_event(VERSE_BUTTON);
+		break;
+
+	case XK_l: // Ctrl-L  verse entry
+		if (state == GDK_CONTROL_MASK)
 			gtk_widget_grab_focus(navbar_versekey.lookup_entry);
-			gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_comm_book),0);
-		}
 		break;
 
-	case GS_KEY_B: // Alt-B  bookmark
-		if (state == GDK_MOD1_MASK) {
-			gchar *label = g_strdup_printf("%s, %s",
-						       settings.currentverse,
-						       settings.MainWindowModule);
-			gui_bookmark_dialog(label,
-					    settings.MainWindowModule,
-					    settings.currentverse);
-			g_free(label);
-		}
+	case XK_n: // N    "next"
+	case XK_N:
+		if (state == GDK_CONTROL_MASK)		// Ctrl-N verse
+			access_on_down_eventbox_button_release_event
+			    (VERSE_BUTTON);
+		else if (state == 0)			// n chapter
+			access_on_down_eventbox_button_release_event
+			    (CHAPTER_BUTTON);
+		else if (state == GDK_SHIFT_MASK)	// N book
+			access_on_down_eventbox_button_release_event
+			    (BOOK_BUTTON);
 		break;
 
-	case GS_KEY_Z: // Alt-Z  open personal commentary
-		if (state == GDK_MOD1_MASK)
-			access_to_edit_percomm();
-		break;
-
-	// future reference: 97 = Home; 103 = End; 99 = PageUp; 105 = PageDown (Linux)
-
-	case GS_KEY_P: // P    "previous" or "parallel"
+	case XK_p: // P    "previous" or "parallel"
+	case XK_P:
 		if (state == GDK_CONTROL_MASK)		// Ctrl-P verse
 			access_on_up_eventbox_button_release_event
 			    (VERSE_BUTTON);
@@ -649,58 +675,46 @@ gboolean on_vbox1_key_press_event(GtkWidget * widget, GdkEventKey * event,
 			on_undockInt_activate(NULL);
 		break;
 
-	case GS_KEY_Q: // quit
+	case XK_q: // quit
 		if (state == GDK_CONTROL_MASK)		// Ctrl-Q quit
 			delete_event (NULL, NULL, NULL);
 		break;
-	case GS_KEY_T: // open a new tab
+
+	case XK_t: // open a new tab
 		if (state == GDK_CONTROL_MASK)
 			on_notebook_main_new_tab_clicked(NULL, NULL);
 		break;
-	case GS_KEY_J: // J    "next verse"
-		access_on_down_eventbox_button_release_event
-			(VERSE_BUTTON);
-		break;
-	case GS_KEY_K: // K    "previous verse"
-		access_on_up_eventbox_button_release_event
-			(VERSE_BUTTON);
-		break;
-	case GS_KEY_N: // N    "next"
-		if (state == GDK_CONTROL_MASK)		// Ctrl-N verse
-			access_on_down_eventbox_button_release_event
-			    (VERSE_BUTTON);
-		else if (state == 0)			// n chapter
-			access_on_down_eventbox_button_release_event
-			    (CHAPTER_BUTTON);
-		else if (state == GDK_SHIFT_MASK)	// N book
-			access_on_down_eventbox_button_release_event
-			    (BOOK_BUTTON);
+
+	case XK_z: // Alt-Z  open personal commentary
+		if (state == GDK_MOD1_MASK)
+			access_to_edit_percomm();
 		break;
 
-	case GS_KEY_PLUS : // Ctrl-Plus  Increase base font size
-	case GS_FREAK_PLUS:	// freakish european keycode
+	case XK_plus : // Ctrl-Plus  Increase base font size
 		if (state == (GDK_CONTROL_MASK|GDK_SHIFT_MASK))
 			new_base_font_size(TRUE);
 		break;
 
-	case GS_KEY_MINUS: // Ctrl-Minus  Decrease base font size
-	case GS_FREAK_MINUS:	// freakish european keycode
+	case XK_minus: // Ctrl-Minus  Decrease base font size
 		if (state == GDK_CONTROL_MASK)
 			new_base_font_size(FALSE);
 		break;
-	case GS_KEY_F1: // F1 help
+	case XK_F1: // F1 help
 		if (state == 0)
 			on_help_contents_activate(NULL, NULL);
 		break;
-	case GS_KEY_F2: // F2 preferences
+	case XK_F2: // F2 preferences
 		if (state == 0)
 			on_preferences_activate(NULL, NULL);
 		break;
-	case GS_KEY_F3: // F3 search
+	case XK_F3: // F3 search
 		if (state == 0)
 			main_open_search_dialog();
+		else if (state == GDK_CONTROL_MASK)
+			gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.
+								   notebook_sidebar), 2);
 		break;
-	case GS_KEY_F4: // F4 module manager
+	case XK_F4: // F4 module manager
 		if (state == 0)
 			on_module_manager_activate (NULL, NULL);
 		else if (state == GDK_CONTROL_MASK)
@@ -709,13 +723,13 @@ gboolean on_vbox1_key_press_event(GtkWidget * widget, GdkEventKey * event,
 					       ((PASSAGE_TAB_INFO*)cur_passage_tab)->
 					       page_widget));
 		break;
-	case GS_KEY_F10: // F10 bible module right click
+	case XK_F10: // Shift-F10 bible module right click
 		if (state == GDK_SHIFT_MASK)
 			gui_menu_popup(settings.MainWindowModule, NULL);
 		break;
 	}
-	GS_message(("on_vbox1_key_press_event\nkeycode: %d, state: %d",
-		    event->hardware_keycode, state));
+	GS_message(("on_vbox1_key_press_event\nkeycode: %d, keysym: %0x, state: %d",
+		    event->hardware_keycode, event->keyval, state));
 	return FALSE;
 }
 
@@ -724,13 +738,13 @@ gboolean on_vbox1_key_release_event(GtkWidget * widget,
                                         GdkEventKey * event,
                                         gpointer user_data)
 {
-        switch (event->hardware_keycode) {
-		case GS_KEY_SHIFT:
-		case GS_KEY_SHIFT_R:
+        switch (event->keyval) {
+		case XK_Shift_L:
+		case XK_Shift_R:
 			shift_key_pressed = FALSE;
 		break;
 	}
-  return FALSE;
+	return FALSE;
 }
 
 /******************************************************************************
@@ -779,7 +793,7 @@ void create_mainwindow(void)
 
 	widgets.studypad_dialog = NULL;
 
-	widgets.app = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	widgets.app = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title (GTK_WINDOW (widgets.app), _("Xiphos - Bible Study Software"));
 
 	g_object_set_data(G_OBJECT(widgets.app),
@@ -870,11 +884,13 @@ void create_mainwindow(void)
 /**widgets.vpaned********/
 	widgets.vpaned = gtk_vpaned_new();
 	gtk_widget_show(widgets.vpaned);
-	gtk_paned_pack1(GTK_PANED(widgets.hpaned), widgets.vpaned, TRUE, TRUE);
+	gtk_widget_set_size_request(widgets.vpaned, 50, -1);
+	gtk_paned_pack1(GTK_PANED(widgets.hpaned), widgets.vpaned, TRUE, FALSE);
 
 	widgets.vpaned2 = gtk_vpaned_new();
 	gtk_widget_show(widgets.vpaned2);
-	gtk_paned_pack2(GTK_PANED(widgets.hpaned), widgets.vpaned2, TRUE, TRUE);
+	gtk_widget_set_size_request(widgets.vpaned2, 50, -1);
+	gtk_paned_pack2(GTK_PANED(widgets.hpaned), widgets.vpaned2, TRUE, FALSE);
 
 /**widgets.hpaned********/
 	widgets.vbox_text = gtk_vbox_new(FALSE, 0);
@@ -1081,7 +1097,7 @@ void create_mainwindow(void)
 
 	gtk_window_set_default_size((GtkWindow *)widgets.app,
                                              settings.gs_width,
-                                             settings.gs_hight);
+                                             settings.gs_height);
 	main_window_created = TRUE;
 }
 
