@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * menu_popup.c - main window panes and dialogs popup menus
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -550,6 +550,43 @@ G_MODULE_EXPORT void on_popup_font_activate (GtkMenuItem * menuitem, gpointer us
 }
 
 
+/******************************************************************************
+ * Name
+ *
+ *
+ * Synopsis
+ *   #include "gui/menu_popup.h"
+ *
+ *
+ *
+ * Description
+ *
+ *
+ * Return value
+ *
+ */
+
+G_MODULE_EXPORT void on_verse_per_line_activate (GtkCheckMenuItem * menuitem, gpointer user_data)
+{
+	gchar *file = g_strdup_printf("%s/modops.conf",
+				      settings.gSwordDir);
+	gchar *url = g_strdup_printf("sword://%s/%s",
+				     settings.MainWindowModule,
+				     settings.currentverse);
+
+	settings.versestyle = menuitem->active;
+	save_conf_file_item(file, settings.MainWindowModule, "style",
+			    (menuitem->active
+			     ? "verse"
+			     : "paragraph"));
+	if (settings.havebible) {
+		main_url_handler(url, TRUE);
+	}
+	g_free(url);
+	g_free(file);
+}
+
+
 /******************************************************************************
  * Name
  *
@@ -817,6 +854,28 @@ G_MODULE_EXPORT void on_commentary_by_chapter_activate (GtkCheckMenuItem * menui
 }
 
 
+/******************************************************************************
+ * Name
+ *
+ *
+ * Synopsis
+ *   #include "gui/menu_popup.h"
+ *
+ *
+ *
+ * Description
+ *
+ *
+ * Return value
+ *
+ */
+
+G_MODULE_EXPORT void on_doublespace_activate (GtkCheckMenuItem * menuitem, gpointer user_data)
+{
+   	_global_option_main_pane((GtkMenuItem*)menuitem, "Doublespace"); /* string not seen by user */
+}
+
+
 /******************************************************************************
  * Name
  *
@@ -997,23 +1056,8 @@ G_MODULE_EXPORT void on_respect_font_faces_activate (GtkCheckMenuItem * menuitem
 
 G_MODULE_EXPORT void on_unlock_this_module_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	gchar *cipher_key;
-	gchar *cipher_old;
-    	gchar *key = NULL;
-
     	if (is_dialog) return;
-
-	cipher_old = main_get_mod_config_entry (menu_mod_name, "CipherKey");
-	cipher_key = gui_add_cipher_key (menu_mod_name, cipher_old);
-	if (cipher_key) {
-	    	if ((key = _get_key(menu_mod_name))) {
-			main_display_bible (menu_mod_name, key);
-			g_free (key);
-		}
-		g_free (cipher_key);
-	}
-	if (cipher_old)
-		g_free (cipher_old);
+	main_check_unlock(menu_mod_name, FALSE);
 }
 
 
@@ -1207,10 +1251,8 @@ G_MODULE_EXPORT void on_rename_perscomm_activate (GtkMenuItem * menuitem, gpoint
 		goto out1;
 	}
 
-	sworddir = g_new(char, strlen(settings.homedir) + 8);
-	sprintf(sworddir, "%s/" DOTSWORD, settings.homedir);
-	modsdir  = g_new(char, strlen(sworddir) + 8);
-	sprintf(modsdir,  "%s/mods.d", sworddir);
+	sworddir = g_strdup_printf("%s/" DOTSWORD, settings.homedir);
+	modsdir  = g_strdup_printf("%s/mods.d", sworddir);
 
 	conf_old =
 	    main_get_mod_config_file(settings.CommWindowModule, sworddir);
@@ -1401,6 +1443,7 @@ G_MODULE_EXPORT void _add_and_check_global_opts (GladeXML *gxml,
 {
 	GtkWidget * item;
 	GLOBAL_OPS *ops = NULL;
+	gint modtype = main_get_mod_type((gchar*) (is_dialog ? d->mod_name : mod_name));
 
 	if (is_dialog)
 		ops = main_new_globals((gchar*) mod_name, 1);
@@ -1408,6 +1451,14 @@ G_MODULE_EXPORT void _add_and_check_global_opts (GladeXML *gxml,
 		ops = main_new_globals((gchar*) mod_name, 0);
 
 
+    	item = glade_xml_get_widget (gxml, "verse_per_line");
+    	gtk_widget_hide (item);
+
+	if (mod_name && (modtype == TEXT_TYPE)) {
+	    	gtk_widget_show (item);
+		GTK_CHECK_MENU_ITEM (item)->active = settings.versestyle;
+	}
+
     	item = glade_xml_get_widget (gxml, "words_of_christ_in_red");
     	gtk_widget_hide (item);
 
@@ -1533,13 +1584,18 @@ G_MODULE_EXPORT void _add_and_check_global_opts (GladeXML *gxml,
     	item = glade_xml_get_widget (gxml, "commentary_by_chapter");
     	gtk_widget_hide (item);
 
-    	if (main_get_mod_type((gchar*) (is_dialog ? d->mod_name : mod_name)) == COMMENTARY_TYPE) {
+    	if ((modtype == COMMENTARY_TYPE) || (modtype == PERCOM_TYPE)) {
     		gtk_widget_show (item);
    		GTK_CHECK_MENU_ITEM (item)->active = ops->commentary_by_chapter;
 	}
 
-	g_free(ops);
+    	item = glade_xml_get_widget (gxml, "doublespace");
+	GTK_CHECK_MENU_ITEM (item)->active = ops->doublespace;
+#ifndef USE_GTKMOZEMBED
+    	gtk_widget_hide (item);
+#endif
 
+	g_free(ops);
 }
 
 /******************************************************************************
@@ -1643,11 +1699,14 @@ static void _lookup_selection(GtkMenuItem *menuitem,
  */
 
 static
-GtkWidget * _create_popup_menu ( const gchar * mod_name, DIALOG_DATA * d)
+GtkWidget * _create_popup_menu (const gchar * mod_name, DIALOG_DATA * d)
 {
 	gchar *glade_file;
 	GladeXML *gxml;
-    	const gchar *mname = NULL;
+    	const gchar *mname = (is_dialog ? dialog->mod_name : mod_name);
+
+	if (!mname || !*mname)
+		return NULL;
 
 	glade_file = gui_general_user_file ("xi-menus.glade", FALSE);
 	g_return_val_if_fail ((glade_file != NULL), NULL);
@@ -1692,19 +1751,18 @@ GtkWidget * _create_popup_menu ( const gchar * mod_name, DIALOG_DATA * d)
 	gtk_widget_hide (close); /* FIXME: hide until connected to dialog close */
 
     	if (is_dialog) {
-		mname = dialog->mod_name;
 	    	gtk_widget_hide (open);
 	    	gtk_widget_hide (bookmark);
 	    	gtk_widget_hide (export_);
 	} else {
-		mname = mod_name;
 	    	gtk_widget_hide (close);
     		gtk_menu_item_set_submenu (GTK_MENU_ITEM(open),
 				  	open_sub);
     		gui_add_mods_2_gtk_menu (_get_type_mod_list (), open_sub,
 				(GCallback) on_view_mod_activate);
 
-	    	if (main_has_cipher_tag((gchar*) mod_name)) /* only unlock from main window */
+		/* unlock from main window only */
+	    	if (main_has_cipher_tag((gchar*) mod_name))
 			gtk_widget_show(unlock);
 	}
 
@@ -1800,6 +1858,9 @@ void gui_menu_popup (const gchar * mod_name, DIALOG_DATA * d)
 		return;
 
 	menu = _create_popup_menu (mod_name, d);
-	gtk_menu_popup ((GtkMenu*)menu, NULL, NULL, NULL, NULL, 2,
-		     			gtk_get_current_event_time());
+	if (menu)
+		gtk_menu_popup ((GtkMenu*)menu, NULL, NULL, NULL, NULL, 2,
+				gtk_get_current_event_time());
+	else
+		gui_generic_warning(_("No module in this pane."));
 }
