@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * navbar_versekey_parallel.c - navigation bar for the parallel dialog
  *
- * Copyright (C) 2007-2009 Xiphos Developer Team
+ * Copyright (C) 2007-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -400,7 +400,7 @@ static void sync_with_main (GtkToggleButton * button, gpointer data)
 		buf = (gchar*)main_url_encode(settings.currentverse);
 		if (buf && (strlen(buf) > 3)) {
 			url =
-			    g_strdup_printf("xiphos.url?action=showParallel&"
+			    g_strdup_printf("passagestudy.jsp?action=showParallel&"
 						"type=verse&value=%s",
 						buf); // xml_get_value("keys", "verse")));
 			main_url_handler(url, TRUE);
