@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * parallel_dialog.c - dialog for detached parallel
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -64,6 +64,8 @@ GtkWidget *entryIntLookup;
 /******************************************************************************
  * static
  */
+static GtkWidget *dialog_parallel;
+
 static GtkWidget *parallel_UnDock_Dialog;
 static GtkWidget *vboxInt;
 static gboolean ApplyChangeBook;
@@ -188,6 +190,9 @@ static void on_dlgparallel_destroy(GtkObject * object,
 					1);
 	settings.dockedInt = TRUE;
 	main_update_parallel_page();
+
+	settings.parallelpage = 0;
+	xml_set_value("Xiphos", "layout", "parallelopen", "0");
 }
 
 
@@ -209,14 +214,13 @@ static void on_dlgparallel_destroy(GtkObject * object,
 
 static void sync_with_main(void)
 {
-	//GS_message((xml_get_value("keys", "verse")));
 	gchar *buf = NULL;
 
 	buf = (gchar*)main_url_encode (settings.currentverse);
 
 	if (buf && (strlen(buf) > 3)) {
 		gchar *url =
-		    g_strdup_printf ("xiphos.url?action=showParallel&"
+		    g_strdup_printf ("passagestudy.jsp?action=showParallel&"
 					"type=verse&value=%s",
 					buf);
 		main_url_handler (url, TRUE);
@@ -291,6 +295,57 @@ static GtkWidget *create_nav_toolbar(void)
 }
 
 
+/******************************************************************************
+ * Name
+ *   on_parallel_configure_event
+ *
+ * Synopsis
+ *   #include "gui/main_window.h"
+ *
+ *   gboolean on_parallel_configure_event(GtkWidget * widget,
+ *				   GdkEventConfigure * event,
+ *				   gpointer user_data)
+ *
+ * Description
+ *   remember placement+size of parallel window.
+ *   cloned from on_configure_event
+ *
+ * Return value
+ *   gboolean
+ */
+
+static gboolean on_parallel_configure_event(GtkWidget * widget,
+					    GdkEventConfigure * event,
+					    gpointer user_data)
+{
+	gchar layout[80];
+	gint x;
+	gint y;
+
+ 	gdk_window_get_root_origin(
+	    GDK_WINDOW(dialog_parallel->window), &x, &y);
+
+	settings.parallel_width  = event->width;
+	settings.parallel_height = event->height;
+	settings.parallel_x = x;
+	settings.parallel_y = y;
+
+	sprintf(layout, "%d", settings.parallel_width);
+	xml_set_value("Xiphos", "layout", "parallel_width", layout);
+
+	sprintf(layout, "%d", settings.parallel_height);
+	xml_set_value("Xiphos", "layout", "parallel_height", layout);
+
+	sprintf(layout, "%d", settings.parallel_x);
+	xml_set_value("Xiphos", "layout", "parallel_x", layout);
+
+	sprintf(layout, "%d", settings.parallel_y);
+	xml_set_value("Xiphos", "layout", "parallel_y", layout);
+	xml_save_settings_doc(settings.fnconfigure);
+
+	return FALSE;
+}
+
 /******************************************************************************
  * Name
  *   create_parallel_dialog
@@ -310,7 +365,6 @@ static GtkWidget *create_nav_toolbar(void)
 static
 GtkWidget *create_parallel_dialog(void)
 {
-	GtkWidget *dialog_parallel;
   	GtkWidget *box_parallel_labels;
 	GtkWidget *dialog_vbox25;
 	GtkWidget *toolbar29;
@@ -328,12 +382,13 @@ GtkWidget *create_parallel_dialog(void)
 	sprintf(title,"%s - %s", settings.program_title, _("Parallel"));
 
 	dialog_parallel = gtk_dialog_new();
+	gtk_window_set_title(GTK_WINDOW(dialog_parallel), title);
+
 	g_object_set_data(G_OBJECT(dialog_parallel),
 			  "dialog_parallel", dialog_parallel);
-	gtk_window_set_title(GTK_WINDOW(dialog_parallel),
-			     title);
-	gtk_window_set_default_size(GTK_WINDOW(dialog_parallel), 657,
-				    361);
+	gtk_window_set_default_size(GTK_WINDOW(dialog_parallel),
+				    settings.parallel_width,
+				    settings.parallel_height);
 	gtk_window_set_resizable(GTK_WINDOW(dialog_parallel), TRUE);
 
 	dialog_vbox25 = GTK_DIALOG(dialog_parallel)->vbox;
@@ -357,30 +412,26 @@ GtkWidget *create_parallel_dialog(void)
 	gtk_box_pack_start (GTK_BOX (vboxInt), box_parallel_labels, FALSE, TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (box_parallel_labels), 2);
 
-	plabels.label_1 = gtk_label_new (" ");
-	gtk_widget_show (plabels.label_1);
-	gtk_box_pack_start (GTK_BOX (box_parallel_labels), plabels.label_1, FALSE, FALSE, 0);
-	gtk_label_set_use_markup (GTK_LABEL (plabels.label_1), TRUE);
+#if 0
+	if (settings.parallel_list) {
+		GtkWidget *plabel;
+		gchar *label;
+		gint modidx;
 
-	plabels.label_2 = gtk_label_new (" ");
-	gtk_widget_show (plabels.label_2);
-	gtk_box_pack_start (GTK_BOX (box_parallel_labels), plabels.label_2, FALSE, FALSE, 0);
-	gtk_label_set_use_markup (GTK_LABEL (plabels.label_2), TRUE);
+		for (modidx = 0; settings.parallel_list[modidx]; ++modidx) {
+			plabel = gtk_label_new(NULL);
+			gtk_widget_show(plabel);
+			gtk_box_pack_start(GTK_BOX (box_parallel_labels), plabel, FALSE, FALSE, 0);
+			gtk_label_set_use_markup(GTK_LABEL(plabel), TRUE);
 
-	plabels.label_3 = gtk_label_new (" ");
-	gtk_widget_show (plabels.label_3);
-	gtk_box_pack_start (GTK_BOX (box_parallel_labels), plabels.label_3, FALSE, FALSE, 0);
-	gtk_label_set_use_markup (GTK_LABEL (plabels.label_3), TRUE);
-
-	plabels.label_4 = gtk_label_new (" ");
-	gtk_widget_show (plabels.label_4);
-	gtk_box_pack_start (GTK_BOX (box_parallel_labels), plabels.label_4, FALSE, FALSE, 0);
-	gtk_label_set_use_markup (GTK_LABEL (plabels.label_4), TRUE);
-
-	plabels.label_5 = gtk_label_new (" ");
-	gtk_widget_show (plabels.label_5);
-	gtk_box_pack_start (GTK_BOX (box_parallel_labels), plabels.label_5, FALSE, FALSE, 0);
-	gtk_label_set_use_markup (GTK_LABEL (plabels.label_5), TRUE);
+			label = g_strdup_printf("<span color='%s' weight='bold'>%s</span>",
+						settings.bible_verse_num_color,
+						settings.parallel_list[modidx]);
+			gtk_label_set_markup(GTK_LABEL(plabel), label);
+			g_free(label);
+		}
+	}
+#endif /* 0 */
 
 #ifdef USE_GTKMOZEMBED
 	frame = gtk_frame_new(NULL);
@@ -392,7 +443,7 @@ GtkWidget *create_parallel_dialog(void)
 	gtk_widget_show (eventbox);
 	gtk_container_add(GTK_CONTAINER(frame), eventbox);
 
-	widgets.html_parallel_dialog = GTK_WIDGET(gecko_html_new(NULL, FALSE, PARALLEL_TYPE)); //embed_new(PARALLEL_TYPE); //gtk_moz_embed_new();
+	widgets.html_parallel_dialog = GTK_WIDGET(gecko_html_new(NULL, FALSE, PARALLEL_TYPE));
 	gtk_widget_show(widgets.html_parallel_dialog);
 	gtk_container_add(GTK_CONTAINER(eventbox),
 			  widgets.html_parallel_dialog);
@@ -419,6 +470,9 @@ GtkWidget *create_parallel_dialog(void)
 			 "button_release_event",
 			 G_CALLBACK (_popupmenu_requested_cb),
 			 NULL);
+	g_signal_connect(GTK_OBJECT(widgets.html_parallel_dialog),
+			 "url_requested",
+			 G_CALLBACK(url_requested), NULL);
 #endif
 	dialog_action_area25 =
 	    GTK_DIALOG(dialog_parallel)->action_area;
@@ -449,7 +503,28 @@ GtkWidget *create_parallel_dialog(void)
 			   G_CALLBACK(gui_btnDockInt_clicked),
 			   NULL);
 
-	set_window_icon (GTK_WINDOW(dialog_parallel));
+	g_signal_connect((gpointer) dialog_parallel, 
+			 "configure_event",
+			 G_CALLBACK(on_parallel_configure_event), NULL);
+
+	settings.parallelpage = 1;
+	xml_set_value("Xiphos", "layout", "parallelopen", "1");
+
+	set_window_icon(GTK_WINDOW(dialog_parallel));
+
+	/*
+	 * (from xiphos.c)
+	 * a little paranoia:
+	 * clamp geometry values to a reasonable bound.
+	 * sometimes xiphos gets insane reconfig events as it dies,
+	 * especially if it's due to just shutting linux down.
+	 */
+	if ((settings.parallel_x < 0) || (settings.parallel_x > 2000))
+		settings.parallel_x = 0;
+	if ((settings.parallel_y < 0) || (settings.parallel_y > 2000))
+		settings.parallel_y = 0;
+
+ 	gtk_window_move(GTK_WINDOW(dialog_parallel),settings.parallel_x,settings.parallel_y);
 
 	return dialog_parallel;
 }
