@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * search_dialog.c - gui for searching Sword modules
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -74,15 +74,11 @@
 SEARCH_DIALOG1 search1;
 
 static gboolean _preview_on;
-static gboolean _in_url;
 static gchar *module_selected;
 gchar *verse_selected;
 
 GtkWidget *remember_search;	/* needed to change button in search stop */
 
-extern int drag_module_type;
-
-
 /* click on treeview folder to expand or collapse it */
 static gboolean button_release_event(GtkWidget * widget,
 				     GdkEventButton * event,
@@ -124,8 +120,7 @@ void on_comboboxentry2_changed(GtkComboBox * combobox,
  * Synopsis
  *   #include "gui/search_dialog.h"
  *
- *   void button_clean(GtkButton * button,
- *						gpointer user_data)
+ *   void button_clean(GtkButton * button, gpointer user_data)
  *
  * Description
  *   user pressed clear button - clears search results page
@@ -143,24 +138,20 @@ void button_clean(GtkButton * button, gpointer user_data)
 #endif
 
 	GS_message(("button_clean"));
-	model =
-	    gtk_tree_view_get_model(GTK_TREE_VIEW
-				    (search1.listview_results));
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(search1.listview_results));
 	list_store = GTK_LIST_STORE(model);
 	gtk_list_store_clear(list_store);
 
-	model =
-	    gtk_tree_view_get_model(GTK_TREE_VIEW
-				    (search1.listview_verses));
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(search1.listview_verses));
 	list_store = GTK_LIST_STORE(model);
 	gtk_list_store_clear(list_store);
 
 #ifdef USE_GTKMOZEMBED
-	html_text=g_string_new(HTML_START);
+	html_text = g_string_new(HTML_START);
 	g_string_append(html_text," ");
 	g_string_append(html_text,"</html>");
-	gecko_html_open_stream(GECKO_HTML(search1.preview_html),"text/html");
-	gecko_html_write(GECKO_HTML(search1.preview_html),html_text->str,html_text->len);
+	gecko_html_open_stream(GECKO_HTML(search1.preview_html), "text/html");
+	gecko_html_write(GECKO_HTML(search1.preview_html), html_text->str, html_text->len);
 	gecko_html_close(GECKO_HTML(search1.preview_html));
 	g_string_free(html_text,TRUE);
 #else
@@ -221,8 +212,7 @@ void button_export(GtkButton * button, gpointer user_data)
  * Synopsis
  *   #include "gui/search_dialog.h"
  *
- *   void on_destroy(GtkWidget * dialog,
- *				    gpointer user_data)
+ *   void on_destroy(GtkWidget * dialog, gpointer user_data)
  *
  * Description
  *   destroy the search dialog
@@ -273,48 +263,19 @@ void on_button_begin_search(GtkButton * button, gpointer user_data)
 {
 	if (search_active) {
 		terminate_search = TRUE;
-		const gchar *label;
-		label = g_strdup("gtk-find");
-		gtk_button_set_label((GtkButton *)remember_search, label);
+		gtk_button_set_label((GtkButton *)remember_search, "gtk-find");
 		gtk_button_set_use_stock((GtkButton *)remember_search, TRUE);
 		sync_windows();
 	} else {
-		const gchar *label;
-		label = g_strdup("gtk-stop");
-		gtk_button_set_label((GtkButton *)remember_search, label);
+		gtk_button_set_label((GtkButton *)remember_search, "gtk-stop");
 		gtk_button_set_use_stock((GtkButton *)remember_search, TRUE);
 		main_do_dialog_search();
-		label = g_strdup("gtk-find");
-		gtk_button_set_label((GtkButton *)remember_search, label);
+		gtk_button_set_label((GtkButton *)remember_search, "gtk-find");
 		gtk_button_set_use_stock((GtkButton *)remember_search, TRUE);
 	}
 }
 
 
-/******************************************************************************
- * Name
- *   on_togglebutton_show_main
- *
- * Synopsis
- *   #include "gui/search_dialog.h"
- *
- *   void on_togglebutton_show_main(GtkToggleButton * togglebutton,
- *						    gpointer user_data)
- *
- * Description
- *
- *
- * Return value
- *   void
- */
-
-void on_togglebutton_show_main(GtkToggleButton * togglebutton,
-			       gpointer user_data)
-{
-	search1.show_in_main = togglebutton->active;
-}
-
-
 /******************************************************************************
  * Name
  *   list_name_changed
@@ -341,18 +302,14 @@ void list_name_changed(GtkEditable * editable, gpointer user_data)
 	GtkTreeSelection *selection;
 	GtkTreeIter selected;
 
-	model =
-	    gtk_tree_view_get_model(GTK_TREE_VIEW
-				    (search1.module_lists));
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(search1.module_lists));
 	list_store = GTK_LIST_STORE(model);
 	selection = gtk_tree_view_get_selection
 	    (GTK_TREE_VIEW(search1.module_lists));
 
-	if (!gtk_tree_selection_get_selected
-	    (selection, NULL, &selected))
+	if (!gtk_tree_selection_get_selected(selection, NULL, &selected))
 		return;
 
-
 	text = gtk_entry_get_text(GTK_ENTRY(editable));
 	gtk_list_store_set(list_store, &selected, 0, text, -1);
 }
@@ -384,9 +341,7 @@ void range_name_changed(GtkEditable * editable, gpointer user_data)
 	GtkTreeSelection *selection;
 	GtkTreeIter selected;
 
-	model =
-	    gtk_tree_view_get_model(GTK_TREE_VIEW
-				    (search1.list_range_name));
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(search1.list_range_name));
 	list_store = GTK_LIST_STORE(model);
 	selection = gtk_tree_view_get_selection
 	    (GTK_TREE_VIEW(search1.list_range_name));
@@ -395,13 +350,8 @@ void range_name_changed(GtkEditable * editable, gpointer user_data)
 	    (selection, NULL, &selected))
 		return;
 
-
 	text = gtk_entry_get_text(GTK_ENTRY(editable));
 	gtk_list_store_set(list_store, &selected, 0, text, -1);
-/*
-	gtk_clist_set_text((GtkCList *) search1.list_range_name,
-			   search1.custom_range_row, 0, text);
-	*/
 }
 
 
@@ -455,24 +405,18 @@ void new_modlist(GtkButton * button, gpointer user_data)
 	GtkTreeSelection *selection;
 	GtkTreePath *path;
 
-	selection = gtk_tree_view_get_selection
-	    (GTK_TREE_VIEW(search1.module_lists));
+	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(search1.module_lists));
 
-
-	model =
-	    gtk_tree_view_get_model(GTK_TREE_VIEW
-				    (search1.listview_modules));
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(search1.listview_modules));
 	list_store = GTK_LIST_STORE(model);
 
-	model2 =
-	    gtk_tree_view_get_model(GTK_TREE_VIEW
-				    (search1.module_lists));
+	model2 = gtk_tree_view_get_model(GTK_TREE_VIEW(search1.module_lists));
 	list_store2 = GTK_LIST_STORE(model2);
 
 	{
 		// must encode locale-sensitively
 		char *num = main_format_number(search1.list_rows);
-		sprintf(buf, "New List %s", num);
+		sprintf(buf, _("New List %s"), num);
 		g_free(num);
 	}
 
@@ -483,9 +427,6 @@ void new_modlist(GtkButton * button, gpointer user_data)
 	gtk_list_store_set(list_store2, &iter, 0, buf, -1);
 	path = gtk_tree_model_get_path(model2, &iter);
 	gtk_tree_selection_select_path(selection, path);
-	/*search1.custom_list_row = gtk_clist_append((GtkCList *) search1.
-	   module_lists, text); */
-	//search1.list_rows = search1.custom_list_row;
 	gtk_entry_set_text(GTK_ENTRY(search1.entry_list_name), buf);
 	gtk_tree_path_free(path);
 }
@@ -515,24 +456,20 @@ void clear_modules(GtkButton * button, gpointer user_data)
 	GtkTreeIter selected;
 	gchar *str;
 
-	selection = gtk_tree_view_get_selection
-			(GTK_TREE_VIEW(search1.module_lists));
-	model =
-	    gtk_tree_view_get_model(GTK_TREE_VIEW(search1.listview_modules));
-	list_store = GTK_LIST_STORE(model);
-
 	str = g_strdup_printf("<span weight=\"bold\">%s</span>\n\n%s",
 			      _("Clear List?"),
 			      _("Are you sure you want to clear the module list?"));
 
 	if (gui_yes_no_dialog(str, GTK_STOCK_DIALOG_WARNING)) {
+		model = gtk_tree_view_get_model(GTK_TREE_VIEW(search1.listview_modules));
+		list_store = GTK_LIST_STORE(model);
 		gtk_list_store_clear(list_store);
 
-		model =
-		    gtk_tree_view_get_model(GTK_TREE_VIEW(search1.module_lists));
+		model = gtk_tree_view_get_model(GTK_TREE_VIEW(search1.module_lists));
 		list_store = GTK_LIST_STORE(model);
+		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(search1.module_lists));
 		if (gtk_tree_selection_get_selected(selection, NULL, &selected))
-		    gtk_list_store_set(list_store, &selected, 1, "", -1);
+			gtk_list_store_set(list_store, &selected, 1, "", -1);
 	}
 	g_free(str);
 }
@@ -777,7 +714,7 @@ void scope_toggled(GtkToggleButton * togglebutton, gpointer user_data)
  *   #include "gui/search_dialog.h"
  *
  *   void mod_list_toggled(GtkToggleButton *togglebutton,
-						gpointer user_data)
+ *			   gpointer user_data)
  *
  * Description
  *
@@ -797,11 +734,135 @@ void mod_list_toggled(GtkToggleButton * togglebutton,
 		gtk_widget_set_sensitive(search1.combo_list,TRUE);
 	else
 		gtk_widget_set_sensitive(search1.combo_list,FALSE);
-
-
 }
 
 
+/******************************************************************************
+ * Name
+ *   optimized_toggled
+ *
+ * Synopsis
+ *   #include "gui/search_dialog.h"
+ *
+ *   void optimized_toggled(GtkToggleButton *togglebutton,
+ *			    gpointer user_data)
+ *
+ * Description
+ *
+ *
+ * Return value
+ *   void
+ */
+
+void optimized_toggled(GtkToggleButton * togglebutton,
+		      gpointer user_data)
+{
+	if (togglebutton->active)
+		gtk_widget_show(search1.button_intro_lucene);
+	else
+		gtk_widget_hide(search1.button_intro_lucene);
+}
+
+
+/******************************************************************************
+ * Name
+ *   on_lucene_intro_clicked
+ *
+ * Synopsis
+ *   #include "gui/search_dialog.h"
+ *
+ *   void on_lucene_intro_clicked(GtkToggleButton *button,
+ *				  gpointer user_data)
+ *
+ * Description
+ *
+ *
+ * Return value
+ *   void
+ */
+
+#define	LUCENE_INTRO	\
+_("<b>Syntax overview for optimized \"lucene\" searches</b>\nSearch for verses that contain...\n\nloved one\n\t \"loved\" or \"one\"\n\tThis is the same as searching for loved OR one\n\"loved one\"\n\tThe phrase \"loved one\"\nlove*\n\tA word starting with \"love\"\n\t(love OR loves OR loved OR etc...)\nloved AND one\n\tThe word \"loved\" and the word \"one\"\n\t&amp;&amp; can be used in place of AND\n+loved one\n\tVerses that <b>must</b> contain \"loved\" and <b>may</b> contain \"one\"\nloved NOT one\n\t\"loved\" but not \"one\"\n(loved one) AND God\n\t\"loved\" or \"one\" and \"God\"\nlemma:G2316\n\tSearch for the Strong's Greek (\"G\") word number 2316.\n\tAlso, select Strong's display on the <i>Attribute Search</i> tab.\n\nFor complete details, search the web for \"lucene search syntax\".")
+
+void
+on_lucene_intro_clicked(GtkButton * button, gpointer user_data)
+{
+	GtkWidget *dialog;
+	dialog = gtk_message_dialog_new_with_markup
+	    (NULL,	/* no need for a parent window */
+	     GTK_DIALOG_DESTROY_WITH_PARENT,
+	     GTK_MESSAGE_INFO,
+	     GTK_BUTTONS_OK,
+	     LUCENE_INTRO);
+	g_signal_connect_swapped (dialog, "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  dialog);
+	gtk_widget_show(dialog);
+}
+
+/******************************************************************************
+ * Name
+ *   attributes_toggled
+ *
+ * Synopsis
+ *   #include "gui/search_dialog.h"
+ *
+ *   void attributes_toggled(GtkToggleButton *togglebutton,
+ *			     gpointer user_data)
+ *
+ * Description
+ *
+ *
+ * Return value
+ *   void
+ */
+
+void attributes_toggled(GtkToggleButton * togglebutton,
+		      gpointer user_data)
+{
+	if (togglebutton->active)
+		gtk_widget_show(search1.button_intro_attributes);
+	else
+		gtk_widget_hide(search1.button_intro_attributes);
+}
+
+
+/******************************************************************************
+ * Name
+ *   on_attributes_intro_clicked
+ *
+ * Synopsis
+ *   #include "gui/search_dialog.h"
+ *
+ *   void on_attributes_intro_clicked(GtkToggleButton *button,
+ *				  gpointer user_data)
+ *
+ * Description
+ *
+ *
+ * Return value
+ *   void
+ */
+
+#define	ATTRIBUTES_INTRO	\
+_("<b>Attribute-based searches</b>\nSearches for content contained in markup outside the main text. Attributes are footnotes, Strong's numbers, and morphological symbols.\n\nBe aware that most such searches can now be done faster via optimized \"lucene\" searches using keyword qualifiers.\n\nTo use attribute searches, you must select the appropriate button on the <i>Attribute Search</i> tab.\n* Footnote text is searched just like regular text.\n* Strong's words are specified as a prefix letter H or G (Hebrew or Greek) and the numeric word identifier, e.g. G2316 to find \"θεός\" (\"God\").\n* Morphological tags are identified literally, e.g. N-ASF for \"noun, accusative singular feminine\" -- see the Robinson module for details.")
+
+void
+on_attributes_intro_clicked(GtkButton * button, gpointer user_data)
+{
+	GtkWidget *dialog;
+	dialog = gtk_message_dialog_new_with_markup
+	    (NULL,	/* no need for a parent window */
+	     GTK_DIALOG_DESTROY_WITH_PARENT,
+	     GTK_MESSAGE_INFO,
+	     GTK_BUTTONS_OK,
+	     ATTRIBUTES_INTRO);
+	g_signal_connect_swapped (dialog, "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  dialog);
+	gtk_widget_show(dialog);
+}
+
 /******************************************************************************
  * Name
  *   current_module_toggled
@@ -836,34 +897,6 @@ void current_module_toggled(GtkToggleButton * togglebutton,
 
 
 
-/******************************************************************************
- * Name
- *
- *
- * Synopsis
- *   #include "gui/search_dialog.h"
- *
- *
- *
- * Description
- *
- *
- * Return value
- *
- */
-
-gboolean _on_button_release_event(GtkWidget * widget,
-				  GdkEventButton * event, gpointer data)
-{
-	if (_in_url)
-		return FALSE;
-
-	if (GPOINTER_TO_INT(data))
-		_preview_on = TRUE;
-	return FALSE;
-}
-
-
 /******************************************************************************
  * Name
  *   mod_selection_changed
@@ -960,24 +993,20 @@ static void _modules_lists_changed(GtkTreeSelection *
 {
 	gchar *mod = NULL;
 	GtkTreeIter selected;
-
-	GtkTreeModel *model =
-	    gtk_tree_view_get_model(GTK_TREE_VIEW(tree_widget));
+	GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(tree_widget));
 
 	if (!gtk_tree_selection_get_selected(selection, NULL, &selected))
 		return;
 	if (gtk_tree_model_iter_has_child(model, &selected)) {
-
-		if (module_selected) g_free(module_selected);
+		g_free(module_selected);
 		module_selected = NULL;
 		return;
 	}
+
 	gtk_tree_model_get(model, &selected, 0, &mod, -1);
 	if (mod) {
-
-		if (module_selected) g_free(module_selected);
-		module_selected = g_strdup(mod);
-		g_free(mod);
+		g_free(module_selected);
+		module_selected = mod;
 	}
 
 }
@@ -1162,8 +1191,7 @@ void _setup_combobox(GtkComboBox * combo)
 
 	store = gtk_list_store_new(1, G_TYPE_STRING);
 	gtk_combo_box_set_model(combo, GTK_TREE_MODEL(store));
-	gtk_combo_box_entry_set_text_column(GTK_COMBO_BOX_ENTRY(combo),
-					    0);
+	gtk_combo_box_entry_set_text_column(GTK_COMBO_BOX_ENTRY(combo), 0);
 }
 
 
@@ -1190,16 +1218,12 @@ void _setup_listviews(GtkWidget * listview, GCallback callback)
 	GObject *selection;
 
 	model = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
-	gtk_tree_view_set_model(GTK_TREE_VIEW(listview),
-				GTK_TREE_MODEL(model));
+	gtk_tree_view_set_model(GTK_TREE_VIEW(listview), GTK_TREE_MODEL(model));
 	_add_two_text_columns(GTK_TREE_VIEW(listview));
 	if (!callback)
 		return;
-	selection =
-	    G_OBJECT(gtk_tree_view_get_selection
-		     (GTK_TREE_VIEW(listview)));
-	g_signal_connect(selection, "changed", G_CALLBACK(callback),
-			 NULL);
+	selection = G_OBJECT(gtk_tree_view_get_selection(GTK_TREE_VIEW(listview)));
+	g_signal_connect(selection, "changed", G_CALLBACK(callback), NULL);
 
 }
 
@@ -1210,8 +1234,7 @@ void _setup_listviews2(GtkWidget * listview, GCallback callback)
 	GObject *selection;
 
 	model = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
-	gtk_tree_view_set_model(GTK_TREE_VIEW(listview),
-				GTK_TREE_MODEL(model));
+	gtk_tree_view_set_model(GTK_TREE_VIEW(listview), GTK_TREE_MODEL(model));
 	_add_two_text_columns(GTK_TREE_VIEW(listview));
 	if (!callback)
 		return;
@@ -1221,12 +1244,7 @@ void _setup_listviews2(GtkWidget * listview, GCallback callback)
 	g_signal_connect((gpointer) listview,
 				"button_release_event",
 				G_CALLBACK(callback), NULL);
-	selection =
-	    G_OBJECT(gtk_tree_view_get_selection
-		     (GTK_TREE_VIEW(listview)));
-	/*g_signal_connect((gpointer) listview,
-				"key_press_event",
-				G_CALLBACK(tree_key_press_cb), NULL);*/
+	selection = G_OBJECT(gtk_tree_view_get_selection(GTK_TREE_VIEW(listview)));
 	g_signal_connect(selection, "changed", G_CALLBACK(selection_verselist_changed),
 			 NULL);
 
@@ -1263,11 +1281,9 @@ void _setup_treeview(GtkWidget * treeview)
 							  0, NULL);
 	gtk_tree_view_column_set_sort_column_id(column, 0);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column);
-	gui_load_module_tree(treeview);
+	gui_load_module_tree(treeview, FALSE);
 
-	selection =
-	    G_OBJECT(gtk_tree_view_get_selection
-		     (GTK_TREE_VIEW(treeview)));
+	selection = G_OBJECT(gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview)));
 	g_signal_connect(selection, "changed",
 			 G_CALLBACK(mod_selection_changed), treeview);
 
@@ -1275,7 +1291,6 @@ void _setup_treeview(GtkWidget * treeview)
 			       "button_release_event",
 			       G_CALLBACK(button_release_event),
 			       GINT_TO_POINTER(0));
-
 }
 
 
@@ -1291,16 +1306,12 @@ void _setup_treeview2(GtkWidget * treeview)
 							  renderer,
 							  "text",
 							  0, NULL);
-	gtk_tree_view_column_set_sort_column_id(column, 0);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column);
-	gui_load_module_tree(treeview);
-
-	selection =
-	   G_OBJECT(gtk_tree_view_get_selection
-	   (GTK_TREE_VIEW(treeview)));
-	   g_signal_connect(selection, "changed",
-	   G_CALLBACK(_modules_lists_changed), treeview);
+	gtk_tree_view_column_set_sort_column_id(column, 0);
+	gui_load_module_tree(treeview, FALSE);
 
+	selection = G_OBJECT(gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview)));
+	g_signal_connect(selection, "changed", G_CALLBACK(_modules_lists_changed), treeview);
 }
 
 
@@ -1368,8 +1379,7 @@ void _create_mod_sel_dialog(void)
 	search1.mod_sel_dialog = glade_xml_get_widget(gxml2, "dialog2");
 	g_signal_connect((gpointer)search1.mod_sel_dialog, "response",
 			 G_CALLBACK(_on_dialog2_response), NULL);
-	search1.mod_sel_dlg_treeview =
-	    glade_xml_get_widget(gxml2, "treeview8");
+	search1.mod_sel_dlg_treeview = glade_xml_get_widget(gxml2, "treeview8");
 	_setup_treeview2(search1.mod_sel_dlg_treeview);
 	gtk_widget_hide(search1.mod_sel_dialog);
 
@@ -1579,14 +1589,31 @@ void _create_search_dialog(void)
 	search1.rb_custom_list = glade_xml_get_widget(gxml, "radiobutton6");
 	g_signal_connect(search1.rb_custom_list, "toggled",
 			 G_CALLBACK(mod_list_toggled), NULL);
-	/*  */
+
+	/* search type selection */
 	search1.rb_words        = glade_xml_get_widget(gxml, "radiobutton9");
 	search1.rb_regexp       = glade_xml_get_widget(gxml, "radiobutton10");
 	search1.rb_exact_phrase = glade_xml_get_widget(gxml, "radiobutton11");
+
 	search1.rb_optimized    = glade_xml_get_widget(gxml, "radiobutton16");
+	g_signal_connect(search1.rb_optimized, "toggled",
+			 G_CALLBACK(optimized_toggled), NULL);
+
+	search1.button_intro_lucene = glade_xml_get_widget(gxml, "button_intro_lucene");
+	g_signal_connect(search1.button_intro_lucene, "clicked",
+			 G_CALLBACK(on_lucene_intro_clicked), NULL);
+	gtk_widget_show(search1.button_intro_lucene);
+
+	search1.rb_attributes = glade_xml_get_widget(gxml, "radiobutton12");
+	g_signal_connect(search1.rb_attributes, "toggled",
+			 G_CALLBACK(attributes_toggled), NULL);
+
+	search1.button_intro_attributes = glade_xml_get_widget(gxml, "button_intro_attributes");
+	g_signal_connect(search1.button_intro_attributes, "clicked",
+			 G_CALLBACK(on_attributes_intro_clicked), NULL);
+	gtk_widget_hide(search1.button_intro_attributes);
 
 	/* attributes radio buttons */
-	search1.rb_attributes = glade_xml_get_widget(gxml, "radiobutton12");
 	search1.rb_strongs    = glade_xml_get_widget(gxml, "radiobutton13");
 	search1.rb_morphs     = glade_xml_get_widget(gxml, "radiobutton15");
 	search1.rb_footnotes  = glade_xml_get_widget(gxml, "radiobutton14");
@@ -1647,10 +1674,6 @@ void _create_search_dialog(void)
 	g_signal_connect(toolbutton13, "clicked",
 			 G_CALLBACK(button_export), NULL);
 
-	search1.togglebutton_show_main =
-	    glade_xml_get_widget(gxml, "toggletoolbutton1");
-	g_signal_connect(search1.togglebutton_show_main, "toggled",
-			 G_CALLBACK(on_togglebutton_show_main), NULL);
 	search1.combo_list =
 	    glade_xml_get_widget(gxml, "comboboxentry2");
 	_setup_combobox(GTK_COMBO_BOX(search1.combo_list));
