@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * sidebar.c - create and maintain the new sidebar bar
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -73,7 +73,6 @@ static GtkWidget *button_search;
 static GtkWidget *button_v_lists;
 static GtkWidget *button_modules;
 static gchar *buf_module;
-static gchar *buf_caption;
 GList *list_of_verses;
 GtkListStore *model_verselist;
 gboolean is_search_result;
@@ -107,6 +106,7 @@ void  gui_sync_module_treeview(gint direction)
 }
 
 
+#ifdef USE_TREEVIEW_PATH
 /******************************************************************************
  * Name
  *   gui_save_treeview_path_string
@@ -122,15 +122,12 @@ void  gui_sync_module_treeview(gint direction)
  * Return value
  *   void
  */
-#ifdef USE_TREEVIEW_PATH
 void gui_save_treeview_path_string (const gchar * path_str, const gchar * book_name)
 {
-	gchar file[250];
-
-	sprintf(file, "%s/book_path.conf", settings.gSwordDir);
+	gchar *file = g_strdup_printf("%s/book_path.conf", settings.gSwordDir);
 	save_conf_file_item(file, book_name, "PATH", path_str);
-	GS_message (("\n\nPATH: %s\n\n", path_str));
-	g_free ((gchar*)path_str);
+	GS_message (("book %s, path %s, file %s\n", book_name, path_str, file));
+	g_free(file);
 }
 
 
@@ -406,9 +403,6 @@ void gui_set_sidebar_program_start(void)
 		gtk_paned_set_position(GTK_PANED(widgets.epaned), 1);
 	}
 
-	/* set hight of bible and commentary pane */
-	//gtk_paned_set_position(GTK_PANED(widgets.vpaned),settings.upperpane_hight);
-
 	/* set width of bible pane */
 	//gtk_paned_set_position(GTK_PANED(widgets.hpaned), settings.biblepane_width);
 
@@ -536,6 +530,7 @@ static void on_search_activate(GtkToggleButton * button,
 	if (button->active) {
 		gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.
 							   notebook_sidebar), 2);
+		gtk_widget_grab_focus(ss.entrySearch);
 	}
 }
 
@@ -635,10 +630,7 @@ static gboolean on_modules_list_button_release(GtkWidget *widget,
 			return FALSE;
 		}
 	    	if (caption && (!g_utf8_collate(caption, _("Prayer List/Journal")))) {
-			buf_caption = caption;
-			gtk_menu_popup(GTK_MENU(sidebar.menu_prayerlist),
-				       NULL, NULL, NULL, NULL,
-				       0, gtk_get_current_event_time());
+			gui_menu_prayerlist_popup(NULL, NULL);
 			g_free(mod);
 			return FALSE;
 		}
@@ -1089,6 +1081,13 @@ GtkWidget *create_menu_prayerlist_mod(void)
 	return menu;
 }
 
+G_MODULE_EXPORT void gui_menu_prayerlist_popup(GtkMenuItem *menuitem, gpointer user_data)
+{
+	gtk_menu_popup(GTK_MENU(sidebar.menu_prayerlist),
+		       NULL, NULL, NULL, NULL,
+		       0, gtk_get_current_event_time());
+}
+
 static void tree_selection_changed_cb(GtkTreeSelection * selection,
 				      gpointer data)
 {
@@ -1244,11 +1243,10 @@ static gboolean paned_button_release_event(GtkWidget * widget,
 	panesize = gtk_paned_get_position(GTK_PANED(widget));
 
 	if (panesize > 15) {
-		GS_warning(("paned_sidebar = %d",panesize));
-		settings.sidebar_notebook_hight = panesize;
-		sprintf(layout, "%d", settings.sidebar_notebook_hight);
+		settings.sidebar_notebook_height = panesize;
+		sprintf(layout, "%d", settings.sidebar_notebook_height);
 		xml_set_value("Xiphos", "layout",
-			      "sidebar_notebook_hight", layout);
+			      "sidebar_notebook_height", layout);
 	}
 	return FALSE;
 }
@@ -1264,7 +1262,7 @@ void gui_show_previewer_in_sidebar(gint choice)
 #endif
 		gtk_widget_hide(widgets.vbox_previewer);
 		gtk_paned_set_position(GTK_PANED(widgets.paned_sidebar),
-				       settings.sidebar_notebook_hight);
+				       settings.sidebar_notebook_height);
 	} else {
 #ifdef USE_GTKMOZEMBED
 		gtk_widget_show (widgets.vbox_previewer);
@@ -1273,13 +1271,12 @@ void gui_show_previewer_in_sidebar(gint choice)
 #endif
 		gtk_widget_hide(widgets.box_side_preview);
 		gtk_paned_set_position(GTK_PANED(widgets.vpaned),
-				       settings.biblepane_hight);
+				       settings.biblepane_height);
 	}
 	main_set_previewer_widget(choice);
 	main_init_previewer();
 }
 
-
 /******************************************************************************
  * Name
  *   gui_create_sidebar
@@ -1304,7 +1301,7 @@ GtkWidget *gui_create_sidebar(GtkWidget * paned)
 	GtkWidget *title_label = NULL;
 #ifdef USE_GTKMOZEMBED
 	GtkWidget *frame;
-	GtkWidget *eventbox;
+	//GtkWidget *eventbox;
 #else
 	GtkWidget *scrolledwindow;
 #endif
@@ -1337,12 +1334,12 @@ GtkWidget *gui_create_sidebar(GtkWidget * paned)
 			   	0);
 
 
-	eventbox = gtk_event_box_new();
-	gtk_widget_show(eventbox);
-	gtk_container_add(GTK_CONTAINER(frame), eventbox);
+	sidebar.html_viewer_eventbox = gtk_event_box_new();
+	gtk_widget_show(sidebar.html_viewer_eventbox);
+	gtk_container_add(GTK_CONTAINER(frame), sidebar.html_viewer_eventbox);
 
-	sidebar.html_viewer_widget = GTK_WIDGET(gecko_html_new(NULL, FALSE, SB_VIEWER_TYPE));//embed_new(VIEWER_TYPE);
-	gtk_container_add(GTK_CONTAINER(eventbox), sidebar.html_viewer_widget);
+	sidebar.html_viewer_widget = GTK_WIDGET(gecko_html_new(NULL, FALSE, SB_VIEWER_TYPE));
+	gtk_container_add(GTK_CONTAINER(sidebar.html_viewer_eventbox), sidebar.html_viewer_widget);
 #else
 	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow);
