@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * sidebar_dialog.c - dialog for detached sidebar
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,10 +33,20 @@
 #include "gui/xiphos.h"
 #include "gui/widgets.h"
 
+#include "main/previewer.h"
 #include "main/settings.h"
+#include "main/sword.h"
 
 #include "gui/debug_glib_null.h"
 
+#ifdef USE_GTKMOZEMBED
+#ifdef WIN32
+#include "geckowin/gecko-html.h"
+#else
+#include "gecko/gecko-html.h"
+#endif
+#endif
+
 static GtkWidget* create_sidebar_dialog(void);
 static GtkWidget * vbox_dock;
 
@@ -70,8 +80,17 @@ void gui_attach_detach_sidebar(void)
 		gtk_paned_set_position(GTK_PANED(widgets.epaned), 0);
 		/*gtk_paned_set_position(GTK_PANED(widgets.hpaned),
 				       biblepanesize);*/
+		
+		/* ugly fix until someone can make mozembed work with 'gtk_widget_reparent()' */
+#ifdef USE_GTKMOZEMBED
+		gtk_widget_destroy(sidebar.html_viewer_widget);
+		sidebar.html_viewer_widget = GTK_WIDGET(gecko_html_new(NULL, FALSE, SB_VIEWER_TYPE));
+		gtk_container_add(GTK_CONTAINER(sidebar.html_viewer_eventbox), sidebar.html_viewer_widget);
+#endif
+		/* */
+		
 		gtk_widget_show_all(widgets.dock_sb);
-		//gtk_widget_show();
+		gtk_widget_show(sidebar.html_viewer_widget);
 
 	} else {
 		settings.docked = TRUE;
@@ -83,8 +102,20 @@ void gui_attach_detach_sidebar(void)
 				       biblepanesize);
 		gtk_widget_reparent(widgets.shortcutbar,
 				    widgets.epaned);
+		
+		/* ugly fix until someone can make mozembed work with 'gtk_widget_reparent()' */
+#ifdef USE_GTKMOZEMBED
+		gtk_widget_destroy(sidebar.html_viewer_widget);
+		sidebar.html_viewer_widget = GTK_WIDGET(gecko_html_new(NULL, FALSE, SB_VIEWER_TYPE));
+		gtk_container_add(GTK_CONTAINER(sidebar.html_viewer_eventbox), sidebar.html_viewer_widget);
+#endif
+		gtk_widget_show(sidebar.html_viewer_widget);
+		/*  */
+		
 		gtk_widget_destroy(widgets.dock_sb);
 	}
+	main_set_previewer_widget(TRUE);
+	main_init_previewer();
 }
 
 /******************************************************************************
@@ -139,7 +170,7 @@ GtkWidget* create_sidebar_dialog(void)
 	gtk_window_set_title(GTK_WINDOW(dlgDock), _("Sidebar"));
 	gtk_window_set_resizable(GTK_WINDOW(dlgDock), TRUE);
 	gtk_widget_set_size_request(dlgDock, settings.sidebar_width,
-			     settings.gs_hight);
+			     settings.gs_height);
 
 	vbox_dock = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox_dock);
