@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * tabbed_browser.c - functions to facilitate tabbed browsing of different passages at once
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,14 +37,12 @@
 #include "gui/bibletext.h"
 #include "gui/bibletext_dialog.h"
 #include "gui/commentary.h"
-#include "gui/shortcutbar_main.h"
 #include "gui/sidebar.h"
 #include "gui/cipher_key_dialog.h"
 //#include "gui/html.h"
 #include "gui/main_menu.h"
 #include "gui/main_window.h"
 #include "gui/parallel_tab.h"
-#include "gui/shortcutbar_search.h"
 #include "gui/dialog.h"
 #include "gui/font_dialog.h"
 #include "gui/dictlex.h"
@@ -356,16 +354,20 @@ void gui_save_tabs(const gchar *filename)
 	if (NULL == filename)
 		filename = default_tab_filename;
 
-	tabs_dir = g_strdup_printf("%s/tabs/",settings.gSwordDir);
-
-	if (g_access(tabs_dir, F_OK) == -1) {
-		if ((g_mkdir(tabs_dir, S_IRWXU)) == -1) {
-			gui_generic_warning("Can't create tabs dir.");
-			return;
+	if (g_access(filename, F_OK) == 0) {
+		/* we're done, just copy for local use that can be free'd */
+		file = g_strdup(filename);
+	} else {
+		tabs_dir = g_strdup_printf("%s/tabs/",settings.gSwordDir);
+		if (g_access(tabs_dir, F_OK) == -1) {
+			if ((g_mkdir(tabs_dir, S_IRWXU)) == -1) {
+				gui_generic_warning(_("Can't create tabs dir."));
+				return;
+			}
 		}
+		file = g_strdup_printf("%s%s",tabs_dir,filename);
+		g_free(tabs_dir);
 	}
-	file = g_strdup_printf("%s%s",tabs_dir,filename);
-	g_free(tabs_dir);
 	//xml_filename = (const xmlChar *) file;
 
 	xml_doc = xmlNewDoc((const xmlChar *) "1.0");
@@ -544,14 +546,18 @@ void gui_load_tabs(const gchar *filename)
 	}
 	else
 	{
-		tabs_dir = g_strdup_printf("%s/tabs/",settings.gSwordDir);
-		if (g_access(tabs_dir, F_OK) == -1) {
-			GS_message(("Creating new tabs directory\n"));
-			gui_save_tabs (filename);
-			//return;
+		if (g_access(filename, F_OK) == 0) {
+			/* we're done, just copy for local use that can be free'd */
+			file = g_strdup(filename);
+		} else {
+			tabs_dir = g_strdup_printf("%s/tabs/",settings.gSwordDir);
+			if (g_access(tabs_dir, F_OK) == -1) {
+				GS_message(("Creating new tabs directory\n"));
+				gui_save_tabs(filename);
+			}
+			file = g_strdup_printf("%s%s",tabs_dir,filename);
+			g_free(tabs_dir);
 		}
-		file = g_strdup_printf("%s%s",tabs_dir,filename);
-		g_free(tabs_dir);
 
 	    	/* we need this for first time non tabbed browsing */
 	    	if (!settings.browsing && g_access(file, F_OK) == -1) {
@@ -991,7 +997,6 @@ void gui_set_named_tab_label(const gchar * key, PASSAGE_TAB_INFO *pt, gboolean u
 	str = pick_tab_label(pt);
 
 	gtk_label_set_text(pt->tab_label, str->str);
-	GS_message(("label = %s", str->str));
 	gtk_notebook_set_menu_label_text(
 		GTK_NOTEBOOK(widgets.notebook_main),
 		pt->page_widget, str->str);
@@ -1456,7 +1461,7 @@ void on_notebook_main_new_tab_clicked(GtkButton *button, gpointer user_data)
  * Return value
  *   void
  */
-void gui_notebook_main_setup(int tabs)
+void gui_notebook_main_setup(int tabs, const char *tabsfile)
 {
 	if (stop_refresh)
 		return;
@@ -1465,7 +1470,7 @@ void gui_notebook_main_setup(int tabs)
 	cur_passage_tab = NULL;
 	passage_list = NULL;
 
-	gui_load_tabs(tabs ? default_tab_filename : no_tab_filename);
+	gui_load_tabs(tabsfile ? tabsfile : (tabs ? default_tab_filename : no_tab_filename));
 
 	g_signal_connect(GTK_OBJECT(widgets.notebook_main),
 			   "switch_page",
