@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * utilities.c - support functions
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,8 +27,11 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <string.h>
+#include <ctype.h>
 #include <assert.h>
 
+#include <gdk-pixbuf/gdk-pixbuf.h>
+
 #include <gtk/gtk.h>
 
 #include "gui/utilities.h"
@@ -50,7 +53,12 @@
 #undef DATADIR
 #include <windows.h>
 #include <shellapi.h>
-#endif /* WIN32 */
+#include <winsock2.h>
+#else
+#include <sys/socket.h>
+#include <netinet/in.h>
+#endif /* !WIN32 */
+#include <errno.h>
 
 #ifdef USE_GTKMOZEMBED
 #ifdef WIN32
@@ -373,7 +381,7 @@ gchar * gui_general_user_file (const char *fname, gboolean critical)
 
 	for (i = 0; alternative[i] != NULL; i++)
 	{
-		if (file == NULL &&  g_file_test (alternative[i], G_FILE_TEST_EXISTS))
+		if (file == NULL &&  g_file_test (alternative[i], G_FILE_TEST_IS_REGULAR))
 		{
 			file = alternative[i];
 		}
@@ -556,16 +564,18 @@ static void add_module_to_language_folder(GtkTreeModel * model,
  *   void
  */
 
-void gui_load_module_tree(GtkWidget * tree)
+void gui_load_module_tree(GtkWidget * tree, gboolean limited)
 {
 	GtkTreeStore *store;
 	GtkTreeIter text;
 	GtkTreeIter commentary;
 	GtkTreeIter dictionary;
+	GtkTreeIter glossary;
 	GtkTreeIter devotional;
 	GtkTreeIter book;
 	GtkTreeIter map;
 	GtkTreeIter image;
+	GtkTreeIter cult;
 	GtkTreeIter prayerlist;
 	GList *tmp = NULL;
 	GList *tmp2 = NULL;
@@ -582,87 +592,109 @@ void gui_load_module_tree(GtkWidget * tree)
 	gtk_tree_store_append(store, &commentary, NULL);
 	gtk_tree_store_set(store, &commentary, 0, _("Commentaries"), -1);
 
-	/*  Dictionaries folders */
-	gtk_tree_store_append(store, &dictionary, NULL);
-	gtk_tree_store_set(store, &dictionary, 0, _("Dictionaries"), -1);
+	if (!limited) {
+		/*  Dictionaries folders */
+		gtk_tree_store_append(store, &dictionary, NULL);
+		gtk_tree_store_set(store, &dictionary, 0, _("Dictionaries"), -1);
 
-	/*  Devotionals folders */
-	gtk_tree_store_append(store, &devotional, NULL);
-	gtk_tree_store_set(store, &devotional, 0, _("Daily Devotionals"), -1);
+		/*  Glossaries folders */
+		gtk_tree_store_append(store, &glossary, NULL);
+		gtk_tree_store_set(store, &glossary, 0, _("Glossaries"), -1);
 
-	/*  General Books folders */
-	gtk_tree_store_append(store, &book, NULL);
-	gtk_tree_store_set(store, &book, 0, _("General Books"), -1);
+		/*  Devotionals folders */
+		gtk_tree_store_append(store, &devotional, NULL);
+		gtk_tree_store_set(store, &devotional, 0, _("Daily Devotionals"), -1);
 
-	/*  Maps folders */
-	gtk_tree_store_append(store, &map, NULL);
-	gtk_tree_store_set(store, &map, 0, _("Maps"), -1);
+		/*  General Books folders */
+		gtk_tree_store_append(store, &book, NULL);
+		gtk_tree_store_set(store, &book, 0, _("General Books"), -1);
 
-	/*  Images folders */
-	gtk_tree_store_append(store, &image, NULL);
-	gtk_tree_store_set(store, &image, 0, _("Images"), -1);
+		/*  Maps folders */
+		gtk_tree_store_append(store, &map, NULL);
+		gtk_tree_store_set(store, &map, 0, _("Maps"), -1);
 
-	/*  Prayer lists folder */
-	if (settings.prayerlist) {
-		gtk_tree_store_append(store, &prayerlist, NULL);
-		gtk_tree_store_set(store, &prayerlist, 0, _("Prayer List/Journal"), -1);
+		/*  Images folders */
+		gtk_tree_store_append(store, &image, NULL);
+		gtk_tree_store_set(store, &image, 0, _("Images"), -1);
+
+		/*  Cult folders */
+		gtk_tree_store_append(store, &cult, NULL);
+		gtk_tree_store_set(store, &cult, 0, _("Cult/Unorthodox"), -1);
+
+		/*  Prayer lists folder */
+		if (settings.prayerlist) {
+			gtk_tree_store_append(store, &prayerlist, NULL);
+			gtk_tree_store_set(store, &prayerlist, 0, _("Prayer List/Journal"), -1);
+		}
 	}
 
 	tmp = mod_mgr_list_local_modules(settings.path_to_mods, TRUE);
 
 	language_make_list(tmp, store,
 			   text, commentary, map, image,
-			   devotional, dictionary, book,
+			   devotional, dictionary, glossary, book, cult,
 			   NULL, NULL,
-			   language_add_folders);
+			   language_add_folders, limited);
 
 	tmp2 = tmp;
 	while (tmp2 != NULL) {
 		info = (MOD_MGR *) tmp2->data;
 
-		// see comment on similar code in src/main/sidebar.cc.
+		/* see comment on similar code in src/main/sidebar.cc. */
 
-		if (info->type[0] == 'B') {
+		if ((info->type[0] == 'B') && !info->is_cult) {
 			add_module_to_language_folder(GTK_TREE_MODEL(store),
 						      text, info->language,
 						      info->name);
 		}
-		else if (info->type[0] == 'C') {
+		else if ((info->type[0] == 'C') && !info->is_cult) {
 			add_module_to_language_folder(GTK_TREE_MODEL(store),
 						      commentary, info->language,
 						      info->name);
 		}
-		else if (info->is_maps) {
-			add_module_to_language_folder(GTK_TREE_MODEL(store),
-						      map, info->language,
-						      info->name);
-		}
-		else if (info->is_images) {
-			add_module_to_language_folder(GTK_TREE_MODEL(store),
-						      image, info->language,
-						      info->name);
-		}
-		else if (info->is_devotional) {
-			add_module_to_language_folder(GTK_TREE_MODEL(store),
-						      devotional, info->language,
-						      info->name);
-		}
-		else if (info->type[0] == 'L') {
-			add_module_to_language_folder(GTK_TREE_MODEL(store),
-						      dictionary, info->language,
-						      info->name);
-		}
-		else if (info->type[0] == 'G') {
-			gchar *gstype = main_get_mod_config_entry(info->name, "GSType");
-			if ((gstype == NULL) || strcmp(gstype, "PrayerList")) {
+		else if (!limited) {
+			if (info->is_cult) {
 				add_module_to_language_folder(GTK_TREE_MODEL(store),
-							      book, info->language,
+							      cult, info->language,
 							      info->name);
 			}
-		}
-		else {
-			GS_warning(("mod `%s' unknown type `%s'",
-				    info->name, info->type));
+			else if (info->is_maps) {
+				add_module_to_language_folder(GTK_TREE_MODEL(store),
+							      map, info->language,
+							      info->name);
+			}
+			else if (info->is_images) {
+				add_module_to_language_folder(GTK_TREE_MODEL(store),
+							      image, info->language,
+							      info->name);
+			}
+			else if (info->is_devotional) {
+				add_module_to_language_folder(GTK_TREE_MODEL(store),
+							      devotional, info->language,
+							      info->name);
+			}
+			else if (info->is_glossary) {
+				add_module_to_language_folder(GTK_TREE_MODEL(store),
+							      glossary, info->language,
+							      info->name);
+			}
+			else if (info->type[0] == 'L') {
+				add_module_to_language_folder(GTK_TREE_MODEL(store),
+							      dictionary, info->language,
+							      info->name);
+			}
+			else if (info->type[0] == 'G') {
+				gchar *gstype = main_get_mod_config_entry(info->name, "GSType");
+				if ((gstype == NULL) || strcmp(gstype, "PrayerList")) {
+					add_module_to_language_folder(GTK_TREE_MODEL(store),
+								      book, info->language,
+								      info->name);
+				}
+			}
+			else {
+				GS_warning(("mod `%s' unknown type `%s'",
+					    info->name, info->type));
+			}
 		}
 
 		g_free(info->name);
@@ -676,7 +708,7 @@ void gui_load_module_tree(GtkWidget * tree)
 	g_list_free(tmp);
 
 	/* prayer list folders */
-	if (settings.prayerlist) {
+	if (!limited && settings.prayerlist) {
 		tmp = get_list(PRAYER_LIST);
 		while (tmp != NULL) {
 			add_module_to_prayerlist_folder(GTK_TREE_MODEL(store),
@@ -710,49 +742,65 @@ void gui_load_module_tree(GtkWidget * tree)
 MOD_FONT *get_font(gchar * mod_name)
 {
 	MOD_FONT *mf;
-	gchar file[250];
+	static gchar *file = NULL;
 
-	sprintf(file, "%s/fonts.conf", settings.gSwordDir);
+	if (file == NULL)
+		file = g_strdup_printf("%s/fonts.conf", settings.gSwordDir); /* not freed */
 
-	mf = g_new(MOD_FONT, 1);
+	mf = g_new0(MOD_FONT, 1);
 	mf->mod_name = mod_name;
-	mf->old_font = NULL;
-	mf->old_gdk_font = NULL;
-	mf->old_font_size = NULL;
-	mf->new_font = NULL;
-	mf->new_gdk_font = NULL;
-	mf->new_font_size = NULL;
-	mf->no_font = 0;
 
 	mf->old_font = get_conf_file_item(file, mod_name, "Font");
 	mf->old_gdk_font = get_conf_file_item(file, mod_name, "GdkFont");
 	mf->old_font_size = get_conf_file_item(file, mod_name, "Fontsize");
+
 	if ((mf->old_font == NULL) ||
 	    !strcmp(mf->old_font, "none")) {
-		gchar *preferred_font =
-		    main_get_mod_config_entry(mod_name, "Font");
+		/* in absence of selected font, module can name its preference */
+		gchar *preferred_font = main_get_mod_config_entry(mod_name, "Font");
+		gchar *preferred_font_size = main_get_mod_config_entry(mod_name, "Fontsize");
 
-		if (mf->old_font)
-			g_free(mf->old_font);
-		if (preferred_font && (*preferred_font != '\0')) {
-			mf->old_font = g_strdup(preferred_font);
-		} else {
-			mf->old_font = g_strdup("none");
+		/* in absence of module preference, user can specify language pref */
+		gchar *lang = main_get_mod_config_entry(mod_name, "Lang");
+		gchar *lang_lang = g_strdup_printf("Language:%s",
+						   (lang ? lang : ""));
+		gchar *lang_font = get_conf_file_item(file, lang_lang, "Font");
+		gchar *lang_size = get_conf_file_item(file, lang_lang, "Fontsize");
+
+		g_free(mf->old_font);
+
+		if (preferred_font && (*preferred_font != '\0'))
+			mf->old_font = preferred_font;
+		else {
+			g_free(preferred_font);
+			/* next try: fallback to per-language choice */
+			if (lang_font && (*lang_font != '\0'))
+				mf->old_font = lang_font;
+			else {
+				/* nothing ever specified: utter default */
+				g_free(lang_font);
+				mf->old_font = g_strdup("none");
+			}
 		}
-	}
 
-	if ((mf->old_font_size == NULL) ||
-	    !strcmp(mf->old_font_size, "+0")) {
-		gchar *preferred_font_size =
-		    main_get_mod_config_entry(mod_name, "Fontsize");
-
-		if (mf->old_font_size)
+		if ((mf->old_font_size == NULL) ||
+		    !strcmp(mf->old_font_size, "+0")) {
 			g_free(mf->old_font_size);
-		if (preferred_font_size && (*preferred_font_size != '\0')) {
-			mf->old_font_size = g_strdup(preferred_font_size);
-		} else {
-			mf->old_font_size = g_strdup("+0");
+
+			if (preferred_font_size && (*preferred_font_size != '\0'))
+				mf->old_font_size = preferred_font_size;
+			else {
+				g_free(preferred_font_size);
+				if (lang_size && (*lang_size != '\0'))
+					mf->old_font_size = lang_size;
+				else {
+					g_free(lang_size);
+					mf->old_font_size = g_strdup("+0");
+				}
+			}
 		}
+
+		g_free(lang);
 	}
 
 	return mf;
@@ -780,12 +828,9 @@ void free_font(MOD_FONT *mf)
 	if (mf->old_font) g_free(mf->old_font);
 	if (mf->old_gdk_font) g_free(mf->old_gdk_font);
 	if (mf->old_font_size) g_free(mf->old_font_size);
-	//mf->new_font = NULL;
-	//mf->new_gdk_font = NULL;
-	//mf->new_font_size = NULL;
-	//mf->no_font = 0;
 	g_free(mf);
 }
+
 /******************************************************************************
  * Name
  *   remove_linefeeds
@@ -1043,10 +1088,13 @@ language_make_list(GList *modlist,
 		   GtkTreeIter image,
 		   GtkTreeIter devotional,
 		   GtkTreeIter dictionary,
+		   GtkTreeIter glossary,
 		   GtkTreeIter book,
+		   GtkTreeIter cult,
 		   GtkTreeIter *update,
 		   GtkTreeIter *uninstalled,
-		   void (*add)(GtkTreeModel *, GtkTreeIter, gchar **))
+		   void (*add)(GtkTreeModel *, GtkTreeIter, gchar **),
+		   gboolean limited)
 {
 	MOD_MGR *info;
 	int i;
@@ -1071,7 +1119,9 @@ language_make_list(GList *modlist,
 		}
 
 		/* modtype analysis identical to add_to_folder calls. */
-		if (info->type[0] == 'B')
+		if (info->is_cult)
+			language_add(info->language, LANGSET_CULT);
+		else if (info->type[0] == 'B')
 			language_add(info->language, LANGSET_BIBLE);
 		else if (info->type[0] == 'C')
 			language_add(info->language, LANGSET_COMMENTARY);
@@ -1081,6 +1131,8 @@ language_make_list(GList *modlist,
 			language_add(info->language, LANGSET_IMAGE);
 		else if (info->is_devotional)
 			language_add(info->language, LANGSET_DEVOTIONAL);
+		else if (info->is_glossary)
+			language_add(info->language, LANGSET_GLOSSARY);
 		else if (info->type[0] == 'L')
 			language_add(info->language, LANGSET_DICTIONARY);
 		else if ((info->type[0] == 'G') &&
@@ -1103,24 +1155,105 @@ language_make_list(GList *modlist,
 	       language_get_type(LANGSET_BIBLE));
 	(*add)(GTK_TREE_MODEL(store), commentary,
 	       language_get_type(LANGSET_COMMENTARY));
-	(*add)(GTK_TREE_MODEL(store), map,
-	       language_get_type(LANGSET_MAP));
-	(*add)(GTK_TREE_MODEL(store), image,
-	       language_get_type(LANGSET_IMAGE));
-	(*add)(GTK_TREE_MODEL(store), devotional,
-	       language_get_type(LANGSET_DEVOTIONAL));
-	(*add)(GTK_TREE_MODEL(store), dictionary,
-	       language_get_type(LANGSET_DICTIONARY));
-	(*add)(GTK_TREE_MODEL(store), book,
-	       language_get_type(LANGSET_GENBOOK));
-	if ((update != NULL) && (uninstalled != NULL)) {
-		(*add)(GTK_TREE_MODEL(store), *update,
-		       language_get_type(LANGSET_UPDATE));
-		(*add)(GTK_TREE_MODEL(store), *uninstalled,
-		       language_get_type(LANGSET_UNINSTALLED));
+	if (!limited) {
+		(*add)(GTK_TREE_MODEL(store), map,
+		       language_get_type(LANGSET_MAP));
+		(*add)(GTK_TREE_MODEL(store), image,
+		       language_get_type(LANGSET_IMAGE));
+		(*add)(GTK_TREE_MODEL(store), cult,
+		       language_get_type(LANGSET_CULT));
+		(*add)(GTK_TREE_MODEL(store), devotional,
+		       language_get_type(LANGSET_DEVOTIONAL));
+		(*add)(GTK_TREE_MODEL(store), glossary,
+		       language_get_type(LANGSET_GLOSSARY));
+		(*add)(GTK_TREE_MODEL(store), dictionary,
+		       language_get_type(LANGSET_DICTIONARY));
+		(*add)(GTK_TREE_MODEL(store), book,
+		       language_get_type(LANGSET_GENBOOK));
+		if ((update != NULL) && (uninstalled != NULL)) {
+			(*add)(GTK_TREE_MODEL(store), *update,
+			       language_get_type(LANGSET_UPDATE));
+			(*add)(GTK_TREE_MODEL(store), *uninstalled,
+			       language_get_type(LANGSET_UNINSTALLED));
+		}
 	}
 }
 
+/******************************************************************************
+ * Name
+ *
+ *
+ * Synopsis
+ *   #include "gui/search_dialog.h"
+ *
+ *
+ *
+ * Description
+ *
+ *
+ * Return value
+ *
+ */
+
+gchar *get_modlist_string(GList * mods)
+{
+	gchar *rv;
+	GString *str = g_string_new("");
+	GList *orig_mods = mods;
+
+	while (mods != NULL) {
+		str = g_string_append(str, (gchar *) mods->data);
+		g_free(mods->data);
+		mods = g_list_next(mods);
+		if (mods != NULL)
+			str = g_string_append_c(str, ',');
+	}
+	g_list_free(orig_mods);
+
+	rv = g_strdup(str->str);
+	g_string_free(str, TRUE);
+	return rv;
+}
+
+
+
+/******************************************************************************
+ * Name
+ *   get_current_list
+ *
+ * Synopsis
+ *   #include "gui/search_dialog.h"
+ *
+ *   GList *get_current_list(GtkTreeView *treeview)
+ *
+ * Description
+ *
+ *
+ * Return value
+ *   GList *
+ */
+
+GList *get_current_list(GtkTreeView *treeview)
+{
+	GList *items = NULL;
+	gchar *buf;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+
+	model = gtk_tree_view_get_model(treeview);
+	if (gtk_tree_model_get_iter_first(model, &iter)) {
+		do {
+			gtk_tree_model_get(model, &iter, 1, &buf, -1);
+			items =
+			    g_list_append(items,
+					  (gchar *) g_strdup(buf));
+
+		} while (gtk_tree_model_iter_next(model, &iter));
+	}
+	return items;
+}
+
+
 /*
  * caller must free the returned string.
  */
@@ -1174,6 +1307,9 @@ pixbuf_finder(const char *image, int size, GError **error)
 //
 // utility function to write out HTML.
 //
+#ifdef min
+#undef min
+#endif
 #define min(x,y)	((x) < (y) ? (x) : (y))
 
 void
@@ -1202,6 +1338,33 @@ HtmlOutput(char *text,
 		gtk_html_set_editable(html, FALSE);
 #endif
 
+#ifdef USE_GTKMOZEMBED
+	// EVIL EVIL EVIL EVIL.
+	// crazy nonsense with xulrunner 1.9.2.3, failure to jump to anchor.
+	// force the issue by stuffing a javascript snippet inside <head></head>.
+	// there are forms of evil so dark that they should not be contemplated.
+	if (anchor || settings.special_anchor) {
+		gchar *buf;
+
+		// first, scribble out everything up to the closing </head>.
+		buf = strstr(text, "</head>");	// yes, lowercase.
+		assert(buf != NULL);	// don't be so stupid as not to include <head></head>.
+		offset = buf - text;
+		gecko_html_write(html, text, offset);
+		len -= offset;
+
+		// now write the javascript snippet.
+		buf = g_strdup_printf(
+		    "<script type=\"text/javascript\" language=\"javascript\">"
+		    " window.onload = function () { window.location.hash = \"%s\"; }"
+		    " </script>", (settings.special_anchor
+				   ? settings.special_anchor
+				   : anchor));
+		gecko_html_write(html, buf, strlen(buf));
+		g_free(buf);
+	}
+#endif /* USE_GTKMOZEMBED */
+
 	// html widgets are uptight about being handed
 	// huge quantities of text -- producer/consumer problem,
 	// and we mustn't overload the receiver.  10k chunks.
@@ -1436,4 +1599,447 @@ void xiphos_create_archive(gchar* conf_file, gchar* datapath, gchar *zip,
 
 }
 
+//
+// Read aloud some text, i.e. the current verse.
+// Text is cleaned of '"', <tokens>, "&symbols;", and *n/*x strings,
+// then scribbled out the local static socket with (SayText "...").
+// Non-zero verse param is prefixed onto supplied text.
+//
+
+#ifndef INVALID_SOCKET
+# define INVALID_SOCKET -1
+#endif
+
+void
+ReadAloud(unsigned int verse, const char *suppliedtext)
+{
+	static int tts_socket = INVALID_SOCKET;	// no initial connection.
+	static int use_counter = -2;	// to shortcircuit early uses.
+
+	if (settings.readaloud ||       // read anything, or
+	    (verse == 0)) {		// read what's handed us.
+		gchar *s, *t;
+
+		// setup for communication.
+		if (tts_socket < 0) {
+			struct sockaddr_in service;
+
+			if ((tts_socket = socket (AF_INET, SOCK_STREAM, 0)) < 0) {
+				char msg[256];
+				sprintf(msg, "ReadAloud disabled:\nsocket failed, %s",
+					strerror(errno));
+				settings.readaloud = 0;
+				gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
+							       (widgets.readaloud_item),
+							       settings.readaloud);
+				gui_generic_warning(msg);
+				return;
+			}
+
+			// festival's port (1314) on localhost (127.0.0.1).
+			memset(&service, 0, sizeof service);
+			service.sin_family = AF_INET;
+			service.sin_port = htons(1314);
+			service.sin_addr.s_addr = htonl(0x7f000001);
+			if (connect(tts_socket, (const struct sockaddr *)&service,
+				    sizeof(service)) != 0) {
+				StartFestival();
+#ifdef WIN32
+				Sleep(2); // give festival a moment to init.
+#else
+				sleep(2); // give festival a moment to init.
+#endif
+				if (connect(tts_socket, (const struct sockaddr *)&service,
+					    sizeof(service)) != 0) {
+					// it still didn't work -- missing.
+					char msg[256];
+					sprintf(msg, "%s\n%s, %s",
+						"TTS \"festival\" not started -- perhaps not installed",
+						"TTS connect failed", strerror(errno));
+					StopFestival(&tts_socket);
+					settings.readaloud = 0;
+					gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
+								       (widgets.readaloud_item),
+								       settings.readaloud);
+					gui_generic_warning(msg);
+					return;
+				}
+			}
+		}
+
+		// avoid speaking the first *2* times.
+		// (2 Display() calls are made during startup.)
+		// though speaking may be intended, startup speech is annoying.
+		if (verse && (++use_counter < 1))
+			return;
+
+		GString *text = g_string_new(NULL);
+		if (verse != 0)
+			g_string_printf(text, "%d. ...  %s", verse, suppliedtext);
+			// use of ". ..." is to induce proper pauses.
+		else
+			g_string_printf(text, "%s", suppliedtext);
+		GS_message(("ReadAloud: dirty: %s\n", text->str));
+
+		// clean: no <span> surrounding strongs/morph.
+		// i wish there was a regexp form of strstr().
+		for (s = strstr(text->str, "<span class=\"strongs\">");
+		     s;
+		     s = strstr(s, "<span class=\"strongs\">")) {
+			if ((t = strstr(s, "</span>"))) {
+				t += 6;
+				while (s <= t)
+					*(s++) = ' ';
+			} else {
+				GS_message(("ReadAloud: Unmatched <span strong></span> in %s\n", s));
+				goto out;
+			}
+		}
+		for (s = strstr(text->str, "<span class=\"morph\">");
+		     s;
+		     s = strstr(s, "<span class=\"morph\">")) {
+			if ((t = strstr(s, "</span>"))) {
+				t += 6;
+				while (s <= t)
+					*(s++) = ' ';
+			} else {
+				GS_message(("ReadAloud: Unmatched <span morph></span> in %s\n", s));
+				goto out;
+			}
+		}
+
+		// clean: no quotes (conflict w/festival syntax).
+		for (s = strchr(text->str, '"'); s; s = strchr(s, '"'))
+			*s = ' ';
+
+		// clean: no <tokens>.
+		for (s = strchr(text->str, '<'); s; s = strchr(s, '<')) {
+			if ((t = strchr(s, '>'))) {
+				while (s <= t)
+					*(s++) = ' ';
+			} else {
+				GS_message(("ReadAloud: Unmatched <> in %s\n", s));
+				goto out;
+			}
+		}
+
+		// clean: no &lt;...&gt; sequences.  (Strong's ref, "<1234>".)
+		for (s = strstr(text->str, "&lt;"); s; s = strstr(s, "&lt;")) {
+			if ((t = strstr(s, "&gt;"))) {
+				t += 3;
+				while (s <= t)
+					*(s++) = ' ';
+			} else {
+				GS_message(("ReadAloud: Unmatched &lt;&gt; in %s\n", s));
+				goto out;
+			}
+		}
+
+		// clean: no other &symbols;.
+		for (s = strchr(text->str, '&'); s; s = strchr(s, '&')) {
+			if ((t = strchr(s, ';'))) {
+				while (s <= t)
+					*(s++) = ' ';
+			} else {
+				GS_message(("ReadAloud: Incomplete &xxx; in %s\n", s));
+				goto out;
+			}
+		}
+
+		// clean: no note/xref strings.
+		for (s = strstr(text->str, "*n"); s; s = strstr(s, "*n")) {
+			*(s++) = ' ';
+			*(s++) = ' ';
+			while (isdigit(*s)) *(s++) = ' ';
+		}
+		for (s = strstr(text->str, "*u"); s; s = strstr(s, "*u")) {
+			*(s++) = ' ';
+			*(s++) = ' ';
+		}
+		for (s = strstr(text->str, "*x"); s; s = strstr(s, "*x")) {
+			*(s++) = ' ';
+			*(s++) = ' ';
+			while (isdigit(*s)) *(s++) = ' ';
+		}
+
+		// festival *pronounces* brackets and asterisks -- idiots.
+		for (s = strchr(text->str, '['); s; s = strchr(s, '['))
+			*s = ' ';
+		for (s = strchr(text->str, ']'); s; s = strchr(s, ']'))
+			*s = ' ';
+		for (s = strchr(text->str, '*'); s; s = strchr(s, '*'))
+			*s = ' ';
+		// in case it isn't obvious, i'd really like a  standard
+		// function that walks a string for multiple individual chars.
+
+		// walk the string, looking for dislocated "LORD" as "L<spaces>ORD".
+		// this occurs in "smallcaps" use in many bibles.
+		for (s = strchr(text->str, 'L'); s; s = strchr(s+1, 'L')) {
+			gchar *begin = s++;
+			while (*s == ' ')
+				++s;
+			if (!strncmp(s, "ORD", 3)) {
+				*begin = ' ';
+				*(s-1) = 'L';
+			}
+		}
+		// same song, second verse: G<spaces>OD.
+		for (s = strchr(text->str, 'G'); s; s = strchr(s+1, 'G')) {
+			gchar *begin = s++;
+			while (*s == ' ')
+				++s;
+			if (!strncmp(s, "OD", 2)) {
+				*begin = ' ';
+				*(s-1) = 'G';
+			}
+		}
+
+		GS_message(("ReadAloud: clean: %s\n", text->str));
+		// scribble clean text to the socket.
+		if (FestivalSpeak(text->str, strlen(text->str), tts_socket) == FALSE)
+		{
+			char msg[256];
+			sprintf(msg, "TTS disappeared?\nTTS write failed: %s",
+				strerror(errno));
+			StopFestival(&tts_socket);
+			settings.readaloud = 0;
+			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
+						       (widgets.readaloud_item),
+						       settings.readaloud);
+			gui_generic_warning(msg);
+		}
+
+	out:
+		g_string_free(text, TRUE);
+		return;
+
+	} else {
+
+		// Reading aloud is disabled.
+		// If we had been reading, shut it down.
+		if (tts_socket >= 0) {
+			StopFestival(&tts_socket);
+		}
+		use_counter++;
+		return;
+	}
+}
+
+//
+// starts festival in a async process
+//
+void
+StartFestival(void)
+{
+#ifdef WIN32
+	//on windows, we will ship festival directly under Xiphos
+	gchar *festival_args[5];
+        gchar *festival_com = g_win32_get_package_installation_directory_of_module(NULL);
+	festival_com = g_strconcat(festival_com, "\0", NULL);
+	gchar *festival_lib = g_build_filename(festival_com, "festival\\lib\0");
+	festival_com = g_build_filename(festival_com, "festival\\festival.exe\0");
+	festival_args[0] = festival_com;
+	festival_args[1] = g_strdup("--libdir");
+	festival_args[2] = festival_lib;
+	festival_args[3] = g_strdup("--server");
+	festival_args[4] = NULL;
+#else
+	gchar *festival_args[3];
+	festival_args[0] = g_strdup("festival");
+	festival_args[1] = g_strdup("--server");
+	festival_args[2] = NULL;
+#endif
+	g_spawn_async ( NULL,
+			festival_args,
+			NULL,
+			G_SPAWN_SEARCH_PATH,
+			NULL,
+			NULL,
+			NULL,
+			NULL);
+}
+
+//
+// shuts down Festival
+//
+void
+StopFestival(int *tts_socket)
+{
+#ifdef WIN32
+	closesocket(*tts_socket);
+#else
+	shutdown(*tts_socket, SHUT_RDWR);
+	close(*tts_socket);
+#endif
+	*tts_socket = INVALID_SOCKET;
+}
+
+//
+// tells Festival to say the given text
+//
+gboolean
+FestivalSpeak(gchar *text, int length, int tts_socket)
+{
+#ifdef WIN32
+	if ((send(tts_socket, "(SayText \"", 10, MSG_DONTROUTE) == INVALID_SOCKET)  ||
+	    (send(tts_socket, text, length, MSG_DONTROUTE) == INVALID_SOCKET) ||
+	    (send(tts_socket, "\")\r\n", 4, MSG_DONTROUTE) == INVALID_SOCKET ))
+		return FALSE;
+#else
+	if ((write(tts_socket, "(SayText \"", 10) < 0)  ||
+	    (write(tts_socket, text, length ) < 0) ||
+	    (write(tts_socket, "\")\r\n", 4) < 0))
+		return FALSE;
+#endif
+	return TRUE;
+}
+
+#ifndef HAVE_STRCASESTR
+/*
+ * strcasestr() turns out to be nonstandard extension, but we need it.
+ */
+const char *
+strcasestr(const char *haystack, const char *needle)
+{
+	char *lower_haystack = g_strdup(haystack);
+	char *lower_needle = g_strdup(needle);
+	char *s;
+
+	for (s = lower_haystack; *s; ++s)
+		if (isupper(*s))
+			*s = tolower(*s);
+	for (s = lower_needle; *s; ++s)
+		if (isupper(*s))
+			*s = tolower(*s);
+
+	s = strstr(lower_haystack, lower_needle);
+	if (s)
+		s = (char *)haystack + (s - lower_haystack);
+
+	g_free(lower_haystack);
+	g_free(lower_needle);
+	return s;
+}
+#endif /* !HAVE_STRCASESTR */
+
+int
+ImageDimensions(const char *path, int *x, int *y)
+{
+
+	if (gdk_pixbuf_get_file_info (path, x, y))
+		return 0;
+	else
+		return -1;
+}
+
+#define	IMGSRC_STRING	"<img src=\""
+#define	IMGSRC_LENGTH	10		// strlen(IMGSRC_STRING)
+const char *strcasestr(const char *haystack, const char *needle);
+
+const char *
+AnalyzeForImageSize(const char *origtext,
+		    GdkWindow *window)
+{
+	static GString *resized;
+	static gint resized_init = FALSE;
+
+	const char *trail;	// "trail" trails behind ...
+	char *path;		// ... the current "path".
+	char *end;		// "end" is the path's end.
+	char buf[32];		// for preparing new width+height spec.
+	gint image_x, image_y, window_x, window_y = -999;
+	int image_retval;
+	gboolean no_warning_yet = TRUE;
+
+	if (!resized_init) {
+		resized = g_string_new("");
+		resized_init = TRUE;
+	}
+
+	// performance tweak:
+	// image content is by no means common. therefore, spend an extra
+	// search call to determine whether any of the rest is needed,
+	// most especially to stop copying large blocks of text w/no images.
+	if ((path = (char *)strcasestr(origtext, IMGSRC_STRING)) == NULL)
+		return origtext;
+
+	for (resized = g_string_assign(resized, ""), trail = origtext
+		 /* and path was initialized just above */ ;
+	     path;
+	     path = (char *)strcasestr(path, IMGSRC_STRING)) {
+
+		if (window_y == -999) {
+			/* we have images, but we don't know bounds yet */
+
+			gdk_drawable_get_size(window, &window_x, &window_y);
+			if ((window_x > 200) || (window_y > 200)) {
+				window_x -= 23;
+				window_y -= 23;
+			} else {
+				window_x = (window_x * 93)/100;
+				window_y = (window_y * 93)/100;
+			}
+		}
+
+		/* add the working segment, with annotation added */
+		/* to keep us from matching IMGSRC_STRING again. */
+		path += IMGSRC_LENGTH;
+                resized = g_string_append_len(resized, trail, path-trail-5);
+                resized = g_string_append(resized, "resized=\"yes\" ");
+                resized = g_string_append_len(resized, path-5, 5);
+
+		// some modules play fast-n-loose with proper file spec.
+		if (strncmp(path, "file://", 7) == 0) {
+			path += 7;
+			resized = g_string_append(resized, "file://");
+		} else if (strncmp(path, "file:", 5) == 0) {
+			path += 5;
+			resized = g_string_append(resized, "file:");
+		} else
+			continue;	// no file spec there -- odd.
+
+		// getting this far means we have a valid img src and file.
+		// find closing '"' to determine pathname end.
+		if ((end = strchr(path, '"')) == 0)
+			continue;
+
+		*end = '\0';
+		resized = g_string_append(resized, path);
+		image_retval = ImageDimensions(path, &image_x, &image_y);
+		*end = '"';
+
+		resized = g_string_append_c(resized, '"');
+		path = end+1;
+		trail = path;
+
+		if (image_retval != 0) {
+			if (no_warning_yet) {
+				gui_generic_warning(
+				    _("An image file's size could not be determined.\n"
+				      "Xiphos cannot resize images to fit window."));
+				// settings.imageresize = 0;
+				no_warning_yet = FALSE;
+			}
+			continue;
+		}
+
+		// knowing image size & window size, adjust to fit.
+		if (image_x > window_x) {
+			float proportion = (float)window_x / (float)image_x;
+			image_x = window_x;
+			image_y = (int)((float)image_y * proportion);
+		}
+		if (image_y > window_y) {
+			float proportion = (float)window_y / (float)image_y;
+			image_y = window_y;
+			image_x = (int)((float)image_x * proportion);
+		}
+		sprintf(buf, " width=\"%d\" height=\"%d\"", image_x, image_y);
+		resized = g_string_append(resized, buf);
+        }
+
+	resized = g_string_append(resized, trail);	// remainder of text appended.
+	return resized->str;
+}
+
 /******   end of file   ******/
