@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * xiphos.c -
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -96,8 +96,6 @@ void frontend_init(void)
 	GS_print(("%s\n", "Initiating Xiphos"));
 	settings.comm_showing = TRUE;
 	settings.displaySearchResults = FALSE;
-	settings.havethayer = main_is_module("Thayer");
-	settings.havebdb = main_is_module("BDB");
 
 	/*
 	 *  setup sidebar
@@ -109,7 +107,10 @@ void frontend_init(void)
 	 */
 	if (settings.havebible) {
 		main_check_parallel_modules();
-		main_init_parallel_view();
+		main_init_parallel_view();	
+		gui_create_parallel_page();
+		gtk_widget_realize(widgets.html_parallel);	
+		main_set_parallel_options_at_start();
 	}
 
 	settings.paratab_showing = FALSE;
@@ -137,7 +138,7 @@ void frontend_init(void)
  */
 
 
-void frontend_display(void)
+void frontend_display(const char *tabs)
 {
 	GS_print(("%s\n", "Displaying Xiphos"));
 	gui_show_main_window();
@@ -178,7 +179,7 @@ void frontend_display(void)
 #endif
 	// setup passage notebook
 //	if (settings.browsing) {
-	gui_notebook_main_setup (settings.browsing);
+	gui_notebook_main_setup (settings.browsing, tabs);
 /*	} else {
 		url = g_strdup_printf("sword://%s/%s",settings.DictWindowModule,
 						      settings.dictkey);
@@ -208,6 +209,8 @@ void frontend_display(void)
 			   NULL	);
 	gui_show_previewer_in_sidebar(settings.show_previewer_in_sidebar);
 
+	if (settings.parallelpage)
+		on_undockInt_activate(NULL);
 
 	if (settings.showdevotional)
 		main_display_devotional();
@@ -276,7 +279,6 @@ void shutdown_frontend(void)
 
 	/* free dir and file stuff */
 	g_free(settings.gSwordDir);
-	g_free(settings.shortcutbarDir);
 	g_free(settings.fnconfigure);
 	g_free(settings.swbmDir);
 
