@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * dictlex_dialog.h - dialog for displaying a dictlex module
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,8 +29,6 @@ extern "C" {
 #include "main/module_dialogs.h"
 
 void gui_create_dictlex_dialog(DIALOG_DATA *dlg);
-void gui_lookup_dictlex_dialog_selection
-    (GtkMenuItem * menuitem, gchar * dict_mod_description);
 void on_btnSyncDL_clicked(GtkButton * button, DIALOG_DATA * d);
 
 #ifdef __cplusplus
