@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * search_dialog.h - gui for searching Sword modules
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -63,7 +63,9 @@ struct _search_dialog1 {
 	GtkWidget *rb_regexp;
 	GtkWidget *rb_exact_phrase;
 	GtkWidget *rb_optimized;
+	GtkWidget *button_intro_lucene;
 	GtkWidget *rb_attributes;
+	GtkWidget *button_intro_attributes;
 	GtkWidget *rb_strongs;
 	GtkWidget *rb_morphs;
 	GtkWidget *rb_footnotes;
@@ -97,8 +99,6 @@ struct _search_dialog1 {
 	gint range_rows;
 	gint list_rows;
 
-	gboolean show_in_main;
-
 	gchar *search_mod;
 };
 extern SEARCH_DIALOG1 search1;
@@ -127,8 +127,11 @@ void delete_range(GtkButton * button, gpointer user_data);
 void delete_list(GtkButton * button, gpointer user_data);
 void scope_toggled(GtkToggleButton * togglebutton, gpointer user_data);
 void mod_list_toggled(GtkToggleButton * togglebutton, gpointer user_data);
+void optimized_toggled(GtkToggleButton * togglebutton, gpointer user_data);
+void on_lucene_intro_clicked(GtkButton * button, gpointer user_data);
+void attributes_toggled(GtkToggleButton * togglebutton, gpointer user_data);
+void on_attributes_intro_clicked(GtkButton * button, gpointer user_data);
 void current_module_toggled(GtkToggleButton * togglebutton, gpointer user_data);
-gboolean _on_button_release_event(GtkWidget * widget, GdkEventButton * event, gpointer data);
 void on_closebutton2_clicked(GtkButton * button, gpointer user_data);
 void _on_dialog2_response(GtkDialog * dialog, gint response_id, gpointer user_data);
 void on_toolbutton12_clicked(GtkToolButton * toolbutton, gpointer user_data);
