@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * sidebar.h - create and maintain the sidebar
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,12 +36,13 @@ struct _sidebar {
 	GtkWidget *menu_modules;
 	GtkWidget *menu_prayerlist;
 	GtkWidget *menu_prayerlist_mod;
-	GtkWidget *results_list,
-		*notebook,
-		*tbtn_view_main,
-		*btn_save,
-		*htmlshow,
-		*html_widget;
+	GtkWidget *results_list;
+	GtkWidget *notebook;
+	GtkWidget *tbtn_view_main;
+	GtkWidget *btn_save;
+	GtkWidget *htmlshow;
+	GtkWidget *html_widget;
+	GtkWidget *html_viewer_eventbox;
 	GtkWidget *html_viewer_widget;
 	GtkWidget *optionmenu1;
 	GtkWidget *menu_item_save_search;
@@ -93,6 +94,7 @@ void on_outlined_topic_activate(GtkMenuItem *menuitem, gpointer user_data);
 GtkWidget *create_menu_prayerlist(void);
 void on_edit_activate(GtkMenuItem *menuitem, gpointer user_data);
 GtkWidget *create_menu_prayerlist_mod(void);
+void gui_menu_prayerlist_popup(GtkMenuItem *menuitem, gpointer user_data);
 
 #ifdef __cplusplus
 }
