@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * tabbed_browser.h - functions to facilitate tabbed browsing of different passages at once
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -86,7 +86,7 @@ void gui_update_tab_struct(const gchar * text_mod,
 void gui_close_all_tabs(void);
 void gui_open_tabs(void);
 
-void gui_notebook_main_setup(int tabs);
+void gui_notebook_main_setup(int tabs, const char *tabsfile);
 void gui_notebook_main_shutdown(int tabs);
 /*void gui_notebook_main_switch_page(GtkNotebook * notebook,
 					GtkNotebookPage * page,
