@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * utilities.h - support functions
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ void gui_glade_signal_connect_func (const gchar *cb_name, GObject *obj,
 			   GObject *conn_obj, gboolean conn_after,
 			   gpointer user_data);
 gchar *gui_general_user_file (const char *fname, gboolean critical);
-void gui_load_module_tree(GtkWidget * tree);
+void gui_load_module_tree(GtkWidget * tree, gboolean limited);
 MOD_FONT *get_font(gchar * mod_name);
 void free_font(MOD_FONT *mf);
 gchar * remove_linefeeds(gchar * buf);
@@ -72,10 +72,16 @@ void language_make_list(GList *modlist,
 			GtkTreeIter image,
 			GtkTreeIter devotional,
 			GtkTreeIter dictionary,
+			GtkTreeIter glossary,
 			GtkTreeIter book,
+			GtkTreeIter cult,
 			GtkTreeIter *update,
 			GtkTreeIter *uninstalled,
-			void (*add)(GtkTreeModel *, GtkTreeIter, gchar **));
+			void (*add)(GtkTreeModel *, GtkTreeIter, gchar **),
+			gboolean limited);
+
+GList *get_current_list(GtkTreeView *treeview);
+gchar *get_modlist_string(GList * mods);
 
 char *image_locator(const char *image);
 GtkWidget *pixmap_finder(char *image);
@@ -90,6 +96,16 @@ void archive_adddir(GsfOutfile *output, gchar *path, const gchar *name);
 void xiphos_create_archive(gchar* conf_file, gchar* datapath, gchar *zip,
 			   const gchar *destination);
 
+void ReadAloud(unsigned int verse, const char *suppliedtext);
+void StartFestival(void);
+void StopFestival(int *tts_socket);
+gboolean FestivalSpeak(gchar *text, int length, int tts_socket);
+
+#ifndef HAVE_STRCASESTR
+const char *strcasestr(const char *haystack, const char *needle);
+#endif
+int ImageDimensions(const char *path, int *x, int *y);
+const char *AnalyzeForImageSize(const char *origtext, GdkWindow *window);
 
 #ifdef WIN32
 gchar* xiphos_win32_get_subdir(const gchar *subdir);
@@ -105,7 +121,9 @@ enum {
 	LANGSET_GENBOOK,
 	LANGSET_MAP,
 	LANGSET_IMAGE,
+	LANGSET_CULT,
 	LANGSET_DEVOTIONAL,
+	LANGSET_GLOSSARY,
 	LANGSET_UPDATE,
 	LANGSET_UNINSTALLED,
 	N_LANGSET_MODTYPES
