@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * xiphos.h -
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ extern "C" {
 /*** function prototypes ***/
 
 void frontend_init(void);
-void frontend_display(void);
+void frontend_display(const char *);
 void shutdown_frontend(void);
 
 #ifdef __cplusplus
