@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * export_passage.cc -
  *
- * Copyright (C) 2008-2009 Xiphos Developer Team
+ * Copyright (C) 2008-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@
 #include "main/sword.h"
 
 
-#define HTML_START "<HTML><HEAD><META HTTP-EQUIV=\"content-type\" CONTENT=\"text/html; CHARSET=utf-8\"><STYLE TYPE=\"text/css\"><!-- A { text-decoration:none } %s --></STYLE></HEAD><BODY>"
+#define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"><style type=\"text/css\"><!-- A { text-decoration:none } %s --></style></head><body>"
 
 enum {
         TARGET_HTML,
@@ -93,12 +93,7 @@ static void clipboardreq_get (GtkClipboard *clipboard,
 int main_get_max_verses (void)
 {
 	VerseKey key = settings.currentverse;
-#ifdef SWORD_MULTIVERSE
 	return (key.getVerseMax());
-#else
-	return (key.books[key.Testament()-1] [key.Book()-1].
-				 versemax[key.Chapter()-1]);
-#endif
 }
 
 int main_get_current_verse (void)
