@@ -3,7 +3,7 @@
  * mod_global_ops.c - setup for SWORD global options and
  *                    a few of our own in the gui
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -164,8 +164,9 @@ void main_dialog_set_global_options(gpointer backend,
 				 ops->hebrewpoints);
 	_set_dialog_global_option(b, "Hebrew Cantillation",
 				 ops->hebrewcant);
-	_set_dialog_global_option(b, "Headings",
-				 ops->headings);
+	// always turn on headings in the engine (and later cache them).
+	// whether we display them or not is another matter (display.cc).
+	_set_dialog_global_option(b, "Headings", 1);
 	_set_dialog_global_option(b, "Words of Christ in Red",
 				 ops->words_in_red);
 
@@ -219,8 +220,9 @@ void main_set_global_options(GLOBAL_OPS * ops)
 			  ops->hebrewpoints);
 	_set_global_option(ops->module_type, "Hebrew Cantillation",
 			  ops->hebrewcant);
-	_set_global_option(ops->module_type, "Headings",
-			  ops->headings);
+	// always turn on headings in the engine (and later cache them).
+	// whether we display them or not is another matter (display.cc).
+	_set_global_option(ops->module_type, "Headings", 1);
 	_set_global_option(ops->module_type, "Words of Christ in Red",
 			  ops->words_in_red);
 
@@ -323,5 +325,8 @@ GLOBAL_OPS *main_new_globals(gchar * mod_name, int dialog)
 	ops->commentary_by_chapter =
 	    gui_of2tf(module_options[mod_name]["Commentary by Chapter"].c_str());
 
+	ops->doublespace =
+	    gui_of2tf(module_options[mod_name]["Doublespace"].c_str());
+
 	return ops;
 }
