@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * mod_mgr.h
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,6 +44,8 @@ struct  _mm {
 	int is_devotional;
 	int is_maps;
 	int is_images;
+	int is_glossary;
+	int is_cult;
 	int locked;
 	char *installsize;
 	char *about;
