@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * module_dialogs.cc - view module in a dialog
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,23 +28,6 @@
 #include <swmodule.h>
 #include <url.h>
 
-#ifdef USE_GTKMOZEMBED
-#ifdef WIN32
-#include "geckowin/gecko-html.h"
-#else
-#include "gecko/gecko-html.h"
-#endif
-#else
-#ifdef __cplusplus
-extern "C" {
-#endif
-#include <gtkhtml/gtkhtml.h>
-#include "gui/html.h"
-#ifdef __cplusplus
-}
-#endif
-#endif
-
 #include <string.h>
 
 #include "gui/bibletext_dialog.h"
@@ -202,48 +185,18 @@ void main_dialogs_chapter_heading(DIALOG_DATA * d)
 
 void main_dialogs_clear_viewer(DIALOG_DATA *d)
 {
-	GString *tmp_str = g_string_new(NULL);
-	GString *str;
-	const char *buf;
+	GString *str = g_string_new(NULL);
+	const char *buf = N_("Previewer");
 
-#ifdef USE_GTKMOZEMBED
-	GeckoHtml *new_browser = GECKO_HTML(d->previewer);
-#else
-	gboolean was_editable = FALSE;
+	g_string_printf(str,
+			HTML_START
+			"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">"
+			"<b><font color=\"grey\" size=\"-1\">%s</font></b><hr/></body></html>",
+			settings.bible_bg_color, settings.bible_text_color,
+			settings.link_color, buf);
 
-	/* setup gtkhtml widget */
-	GtkHTML *html = GTK_HTML(d->previewer);
-	was_editable = gtk_html_get_editable(html);
-	if (was_editable)
-		gtk_html_set_editable(html, FALSE);
-#endif
-	g_string_printf(tmp_str,
-		HTML_START
-		"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">",
-		settings.bible_bg_color, settings.bible_text_color,
-		settings.link_color);
-
-	str = g_string_new(tmp_str->str);
-	buf = N_("Previewer");
-	g_string_printf(tmp_str,
-	"<b>%s</b><br><font color=\"grey\">" "<HR></font><br>", buf);
-	str = g_string_append(str, tmp_str->str);
-
-	g_string_printf(tmp_str, " %s", "</font></body></html>");
-	str = g_string_append(str, tmp_str->str);
-
-#ifdef USE_GTKMOZEMBED
-	if (str->len)
-		gecko_html_render_data(new_browser, str->str, str->len);
-
-#else
-	if (str->len)
-		gtk_html_load_from_string(html,str->str,str->len);
-	gtk_html_set_editable(html, was_editable);
-#endif
-	//free_font(mf);
+	HtmlOutput(str->str, d->previewer, NULL, NULL);
 	g_string_free(str, TRUE);
-	g_string_free(tmp_str, TRUE);
 }
 
 
@@ -272,11 +225,6 @@ void main_dialogs_information_viewer(DIALOG_DATA * d, gchar * mod_name,
 	GString *tmp_str = g_string_new(NULL);
 	GString *str;
 	MOD_FONT *mf = get_font(mod_name);
-#ifdef USE_GTKMOZEMBED
-	GeckoHtml *new_browser = GECKO_HTML(sidebar.html_viewer_widget);
-#else
-	GtkHTML *html = GTK_HTML(sidebar.html_viewer_widget);
-#endif
 
 	g_string_printf(tmp_str,
 		HTML_START
@@ -288,25 +236,25 @@ void main_dialogs_information_viewer(DIALOG_DATA * d, gchar * mod_name,
 	if (type) {
 		if (!strcmp(type,"n")) {
 			g_string_printf(tmp_str,
-				"<font color=\"grey\">%s<HR></font><br>",
+				"<font color=\"grey\">%s<hr/></font><br/>",
 					_("Footnote"));
 			str = g_string_append(str, tmp_str->str);
 		}
 		if (!strcmp(type,"x")) {
 			g_string_printf(tmp_str,
-				"<font color=\"grey\">%s<HR></font><br>",
+				"<font color=\"grey\">%s<hr/></font><br/>",
 					_("Cross Reference"));
 			str = g_string_append(str, tmp_str->str);
 		}
 		if (!strcmp(action ,"showStrongs")) {  //&& !strcmp(type,"Greek")
 			g_string_printf(tmp_str,
-				"<font color=\"grey\">%s: %s<HR></font><br>",
+				"<font color=\"grey\">%s: %s<hr/></font><br/>",
 					_("Strongs"),key);
 			str = g_string_append(str, tmp_str->str);
 		}
 		if (!strcmp(action ,"showMorph")) {  //&& !strcmp(type,"Greek")
 			g_string_printf(tmp_str,
-				"<font color=\"grey\">%s: %s<HR></font><br>",
+				"<font color=\"grey\">%s: %s<hr/></font><br/>",
 					_("Morphology"),key);
 			str = g_string_append(str, tmp_str->str);
 		}
@@ -314,7 +262,7 @@ void main_dialogs_information_viewer(DIALOG_DATA * d, gchar * mod_name,
 
 	if (!strcmp(action ,"showStrongsMorph")) {  //&& !strcmp(type,"Greek")
 		g_string_printf(tmp_str,
-			"<font color=\"grey\">%s: %s<HR></font><br>",
+			"<font color=\"grey\">%s: %s<hr/></font><br/>",
 				_("Strongs"),key);
 		str = g_string_append(str, tmp_str->str);
 		g_string_printf(tmp_str,
@@ -325,11 +273,11 @@ void main_dialogs_information_viewer(DIALOG_DATA * d, gchar * mod_name,
 		str = g_string_append(str, text);
 
 		g_string_printf(tmp_str,
-			"<font color=\"grey\"><br><br>%s: %s<HR></font><br>",
+			"<font color=\"grey\"><br/><br/>%s: %s<hr/></font><br/>",
 					_("Morphology"),morph);
 		str = g_string_append(str, tmp_str->str);
 		str = g_string_append(str, morph_text);
-		g_string_printf(tmp_str, " %s<br>", "</font></body></html>");
+		g_string_printf(tmp_str, " %s<br/>", "</font></body></html>");
 		str = g_string_append(str, tmp_str->str);
 
 
@@ -346,18 +294,7 @@ void main_dialogs_information_viewer(DIALOG_DATA * d, gchar * mod_name,
 
 	}
 
-#ifdef USE_GTKMOZEMBED
-	if (str->len)
-		gecko_html_render_data(new_browser, str->str, str->len);
-#else
-	if (str->len)
-		gtk_html_load_from_string(html,str->str,str->len);
-	//gtk_html_set_editable(html, was_editable);
-#endif
-/*	if (str->len) {
-		gtk_html_load_from_string(html,str->str,str->len);
-	}
-*/
+	HtmlOutput(str->str, sidebar.html_viewer_widget, NULL, NULL);
 	free_font(mf);
 	g_string_free(str, TRUE);
 	g_string_free(tmp_str, TRUE);
@@ -385,10 +322,14 @@ void main_dialogs_information_viewer(DIALOG_DATA * d, gchar * mod_name,
  *   void
  */
 
-void main_dialog_information_viewer(const gchar * mod_name, const gchar * text,
-									const gchar * key, const gchar * action,
-									const gchar * type, const gchar * morph_text,
-									const gchar * morph, DIALOG_DATA * d)
+void main_dialog_information_viewer(const gchar * mod_name,
+				    const gchar * text,
+				    const gchar * key,
+				    const gchar * action,
+				    const gchar * type,
+				    const gchar * morph_text,
+				    const gchar * morph,
+				    DIALOG_DATA * d)
 {
 	GString *tmp_str = g_string_new(NULL);
 	GString *str;
@@ -397,12 +338,6 @@ void main_dialog_information_viewer(const gchar * mod_name, const gchar * text,
 	if (!d->previewer)
 		return;
 
-#ifdef USE_GTKMOZEMBED
-	GeckoHtml *html= GECKO_HTML(d->previewer);
-#else
-	GtkHTML *html= GTK_HTML(d->previewer);
-#endif
-
 	g_string_printf(tmp_str,
 		HTML_START
 		"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">",
@@ -412,29 +347,29 @@ void main_dialog_information_viewer(const gchar * mod_name, const gchar * text,
 	str = g_string_new(tmp_str->str);
 	if (type) {
 		if (!strcmp(type,"n")) {
-			g_string_printf(tmp_str,"<font color=\"grey\">%s<HR></font><br>",
+			g_string_printf(tmp_str,"<font color=\"grey\">%s<hr/></font><br/>",
 					_("Footnote"));
 			str = g_string_append(str, tmp_str->str);
 		}
 		if (!strcmp(type,"x")) {
-			g_string_printf(tmp_str,"<font color=\"grey\">%s<HR></font><br>",
+			g_string_printf(tmp_str,"<font color=\"grey\">%s<hr/></font><br/>",
 					_("Cross Reference"));
 			str = g_string_append(str, tmp_str->str);
 		}
 		if (!strcmp(action ,"showStrongs")) {  //&& !strcmp(type,"Greek")
-			g_string_printf(tmp_str,"<font color=\"grey\">%s: %s<HR></font><br>",
+			g_string_printf(tmp_str,"<font color=\"grey\">%s: %s<hr/></font><br/>",
 					_("Strongs"),key);
 			str = g_string_append(str, tmp_str->str);
 		}
 		if (!strcmp(action ,"showMorph")) {  //&& !strcmp(type,"Greek")
-			g_string_printf(tmp_str,"<font color=\"grey\">%s: %s<HR></font><br>",
+			g_string_printf(tmp_str,"<font color=\"grey\">%s: %s<hr/></font><br/>",
 					_("Morphology"),key);
 			str = g_string_append(str, tmp_str->str);
 		}
 	}
 
 	if (!strcmp(action ,"showStrongsMorph")) {  //&& !strcmp(type,"Greek")
-		g_string_printf(tmp_str,"<font color=\"grey\">%s: %s<HR></font><br>",
+		g_string_printf(tmp_str,"<font color=\"grey\">%s: %s<hr/></font><br/>",
 				_("Strongs"),key);
 		str = g_string_append(str, tmp_str->str);
 		g_string_printf(tmp_str,
@@ -444,11 +379,11 @@ void main_dialog_information_viewer(const gchar * mod_name, const gchar * text,
 		str = g_string_append(str, tmp_str->str);
 		str = g_string_append(str, text);
 
-		g_string_printf(tmp_str,"<font color=\"grey\"><br><br>%s: %s<HR></font><br>",
+		g_string_printf(tmp_str,"<font color=\"grey\"><br/><br/>%s: %s<hr/></font><br/>",
 					_("Morphology"),morph);
 		str = g_string_append(str, tmp_str->str);
 		str = g_string_append(str, morph_text);
-		g_string_printf(tmp_str, " %s<br>", "</font></body></html>");
+		g_string_printf(tmp_str, " %s<br/>", "</font></body></html>");
 		str = g_string_append(str, tmp_str->str);
 
 
@@ -465,18 +400,7 @@ void main_dialog_information_viewer(const gchar * mod_name, const gchar * text,
 
 	}
 
-#ifdef USE_GTKMOZEMBED
-	if (str->len) {
-		gecko_html_open_stream(html,"text/html");
-		gecko_html_write(html, str->str, str->len);
-		gecko_html_close(html);
-	}
-#else
-	if (str->len)
-		gtk_html_load_from_string(html,str->str,str->len);
-#endif
-
-
+	HtmlOutput(str->str, d->previewer, NULL, NULL);
 	free_font(mf);
 	g_string_free(str, TRUE);
 	g_string_free(tmp_str, TRUE);
@@ -1060,7 +984,7 @@ static gint show_note(DIALOG_DATA * d,const gchar * module, const gchar * passag
 		while (tmp != NULL) {
 			buf = g_strdup_printf(
 				"<a href=\"sword://%s/%s\">"
-				"<font color=\"%s\">%s,</font></a><br>",
+				"<font color=\"%s\">%s,</font></a><br/>",
 				(gchar*)module,
 				(const char *) tmp->data,
 				settings.bible_text_color,
@@ -1076,7 +1000,7 @@ static gint show_note(DIALOG_DATA * d,const gchar * module, const gchar * passag
 
 		buf = g_strdup_printf(
 				"<a href=\"sword://%s/%s\">"
-				"<font color=\"%s\">%s%s</font></a><br>",
+				"<font color=\"%s\">%s%s</font></a><br/>",
 				(gchar*)module,
 				d->key,
 				settings.bible_text_color,
