@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * navbar.cc - glue between all navbars and sword
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -88,11 +88,7 @@ void main_navbar_set(NAVBAR navbar, const char * key)
 	char xbook = vkey.Book();
 	int xchapter = vkey.Chapter();
 	int xverse = vkey.Verse();
-#ifdef SWORD_MULTIVERSE
 	x = (vkey.getChapterMax());
-#else
-	x = (vkey.books[xtestament-1][xbook-1].chapmax);
-#endif
 	for(i=1; i <= x; i++) {
 		char *num = main_format_number(i);
 		gtk_list_store_append (GTK_LIST_STORE(chapter_store), &iter);
@@ -111,11 +107,7 @@ void main_navbar_set(NAVBAR navbar, const char * key)
 	xbook = vkey.Book();
 	xchapter = vkey.Chapter();
 	xverse = vkey.Verse();
-#ifdef SWORD_MULTIVERSE
 	x = (vkey.getVerseMax());
-#else
-	x = (vkey.books[xtestament-1][xbook-1].versemax[xchapter-1]);
-#endif
 	for(i=1; i <= x; i++) {
 		char *num = main_format_number(i);
 		gtk_list_store_append (GTK_LIST_STORE(verse_store), &iter);
@@ -155,13 +147,9 @@ void main_navbar_fill_book_combo(NAVBAR navbar)
 	gtk_list_store_clear(GTK_LIST_STORE(book_model));
 	if (backend->module_has_testament(navbar.module_name, 1)) {
 		while (i < key.BMAX[0]) {
-#ifdef SWORD_MULTIVERSE
 			key.Testament(1);
 			key.Book(i+1);
 			book = strdup((const char *) key.getBookName());
-#else
-			book = strdup((const char *) key.books[0][i].name);
-#endif
 			char *mykey = g_strdup_printf("%s 1:1",book);
 			if (!main_get_raw_text(navbar.module_name, mykey)){
 				GS_message(("book-out: %s",book));
@@ -183,13 +171,9 @@ void main_navbar_fill_book_combo(NAVBAR navbar)
 	i = 0;
 	if (backend->module_has_testament(navbar.module_name, 2)) {
 		while (i < key.BMAX[1]) {
-#ifdef SWORD_MULTIVERSE
 			key.Testament(2);
 			key.Book(i+1);
 			book = strdup((const char *) key.getBookName());
-#else
-			book = strdup((const char *) key.books[1][i].name);
-#endif
 			char *mykey = g_strdup_printf("%s 1:1",book);
 			if (!main_get_raw_text(navbar.module_name, mykey)){
 				GS_message(("book-in: %s",book));
