@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * navbar.cc - glue between all navbars and sword
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -512,14 +512,7 @@ GtkWidget *main_versekey_drop_down_verse_menu(NAVBAR_VERSEKEY navbar,
 	vkey = navbar.key->str;
 	int xverse = vkey.Verse();
 
-#ifdef SWORD_MULTIVERSE
 	x = (vkey.getVerseMax());
-#else
-	char xtestament = vkey.Testament() ;
-	char xbook = vkey.Book();
-	int xchapter = vkey.Chapter();
-	x = (vkey.books[xtestament-1][xbook-1].versemax[xchapter-1]);
-#endif
 	for(i=1; i <= x; i++) {
 		num = main_format_number(i);
 		if (i == xverse) {
@@ -586,13 +579,7 @@ GtkWidget *main_versekey_drop_down_chapter_menu(NAVBAR_VERSEKEY navbar,
 	menu_shell = GTK_MENU_SHELL(menu);
 	vkey = navbar.key->str;
 	int xchapter = vkey.Chapter();
-#ifdef SWORD_MULTIVERSE
 	x = (vkey.getChapterMax());
-#else
-	char xtestament = vkey.Testament() ;
-	char xbook = vkey.Book();
-	x = (vkey.books[xtestament-1][xbook-1].chapmax);
-#endif
 	for(i=1; i <= x; i++) {
 		num = main_format_number(i);
 		if (i == xchapter) {
@@ -664,13 +651,9 @@ GtkWidget *main_versekey_drop_down_book_menu(NAVBAR_VERSEKEY navbar,
 
 	if (backend->module_has_testament(navbar.module_name->str, 1)) {
 		while (i < key.BMAX[0]) {
-#ifdef SWORD_MULTIVERSE
 			key.Testament(1);
 			key.Book(i+1);
 			book = strdup((const char *) key.getBookName());
-#else
-			book = strdup((const char *) key.books[0][i].name);
-#endif
 			char *mykey = g_strdup_printf("%s 1:1",book);
 			char *rawtext = main_get_raw_text(navbar.module_name->str, mykey);
 			if (!rawtext || (rawtext && (strlen(rawtext) < 2))){
@@ -706,13 +689,9 @@ GtkWidget *main_versekey_drop_down_book_menu(NAVBAR_VERSEKEY navbar,
 	i = 0;
 	if (backend->module_has_testament(navbar.module_name->str, 2)) {
 		while (i < key.BMAX[1]) {
-#ifdef SWORD_MULTIVERSE
 			key.Testament(2);
 			key.Book(i+1);
 			book = strdup((const char *) key.getBookName());
-#else
-			book = strdup((const char *) key.books[1][i].name);
-#endif
 			char *mykey = g_strdup_printf("%s 1:1",book);
 			char *rawtext = main_get_raw_text(navbar.module_name->str, mykey);
 			if (!rawtext || (rawtext && (strlen(rawtext) < 2))){
