@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * parallel_view.cc - support for displaying multiple modules
  *
- * Copyright (C) 2004-2009 Xiphos Developer Team
+ * Copyright (C) 2004-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,21 +25,6 @@
 
 #include <gtk/gtk.h>
 
-#ifdef USE_GTKMOZEMBED
-#ifdef WIN32
-#include "geckowin/gecko-html.h"
-#else
-#include "gecko/gecko-html.h"
-#endif
-#else
-#ifdef __cplusplus
-extern "C" {
-#include <gtkhtml/gtkhtml.h>
-}
-#endif  /* __cplusplus */
-#include "gui/html.h"
-#endif  /* USE_GTKMOZEMBED */
-
 #include "backend/sword_main.hh"
 
 #include "gui/parallel_view.h"
@@ -59,7 +44,7 @@ extern "C" {
 
 #include "gui/debug_glib_null.h"
 
-#define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"><STYLE type=\"text/css\"><!--A { text-decoration:none }--></STYLE></head>"
+#define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"><style type=\"text/css\"><!--A { text-decoration:none }--></style></head>"
 
 extern GtkWidget *entrycbIntBook;
 extern GtkWidget *sbIntChapter;
@@ -69,15 +54,6 @@ extern GtkWidget *entryIntLookup;
 /******************************************************************************
  * static
  */
-#ifndef USE_GTKMOZEMBED
-static GtkHTMLStreamStatus status1;
-static GtkHTMLStream *htmlstream;
-#endif
-static gboolean parallel1;
-static gboolean parallel2;
-static gboolean parallel3;
-static gboolean parallel4;
-static gboolean parallel5;
 
 BackEnd *backend_p;
 
@@ -492,7 +468,11 @@ void main_load_g_ops_parallel(GtkWidget *menu)
 
 
 	item = gtk_check_menu_item_new_with_label(_("Morpheme Segmentation"));
+#if 0
 	gtk_widget_show(item);
+#else
+	gtk_widget_hide(item);
+#endif
 	gtk_container_add(GTK_CONTAINER(menu), item);
 
 	GTK_CHECK_MENU_ITEM(item)->active = settings.parallel_segmentation;
@@ -579,111 +559,34 @@ void main_load_g_ops_parallel(GtkWidget *menu)
 
 void main_check_parallel_modules(void)
 {
-	if (settings.parallel1Module)
-		parallel1 =
-		    main_is_module(settings.parallel1Module);
-	else
-		parallel1 = FALSE;
-
-	if (settings.parallel2Module)
-		parallel2 =
-		    main_is_module(settings.parallel2Module);
-	else
-		parallel2 = FALSE;
-
-	if (settings.parallel3Module)
-		parallel3 =
-		    main_is_module(settings.parallel3Module);
-	else
-		parallel3 = FALSE;
-
-	if (settings.parallel4Module)
-		parallel4 =
-		    main_is_module(settings.parallel4Module);
-	else
-		parallel4 = FALSE;
-
-	if (settings.parallel5Module)
-		parallel5 =
-		    main_is_module(settings.parallel5Module);
-	else
-		parallel5 = FALSE;
-
+	/* i don't know what it's good for, but we'll keep it for now. */
+	return;
 }
 
 
-/******************************************************************************
- * Name
- *   gui_change_int1_mod
- *
- * Synopsis
- *   #include "main/parallel_view.h
- *
- *   void gui_changeint1_mod(gchar * mod_name)
- *
- * Description
- *
- *
- * Return value
- *   void
- */
-
-void main_change_parallel_module(GSParallel parallel, gchar * mod_name)
+void get_heading(SWBuf &text, BackEnd *p, gint modidx)
 {
-	if (!mod_name)
-		return;
-	switch (parallel) {
-	case PARALLEL1:
-		xml_set_value("Xiphos", "modules", "int1",
-			      mod_name);
-		settings.parallel1Module =
-		    xml_get_value("modules", "int1");
-		parallel1 =
-		    main_is_module(settings.parallel1Module);
-		break;
-	case PARALLEL2:
-		xml_set_value("Xiphos", "modules", "int2",
-			      mod_name);
-		settings.parallel2Module =
-		    xml_get_value("modules", "int2");
-		parallel2 =
-		    main_is_module(settings.parallel2Module);
-		break;
-	case PARALLEL3:
-		xml_set_value("Xiphos", "modules", "int3",
-			      mod_name);
-		settings.parallel3Module =
-		    xml_get_value("modules", "int3");
-		parallel3 =
-		    main_is_module(settings.parallel3Module);
-		break;
-	case PARALLEL4:
-		xml_set_value("Xiphos", "modules", "int4",
-			      mod_name);
-		settings.parallel4Module =
-		    xml_get_value("modules", "int4");
-		parallel4 =
-		    main_is_module(settings.parallel4Module);
-		break;
-	case PARALLEL5:
-		xml_set_value("Xiphos", "modules", "int5",
-			      mod_name);
-		settings.parallel5Module =
-		    xml_get_value("modules", "int5");
-		parallel5 =
-		    main_is_module(settings.parallel5Module);
-		break;
-	default:
-		return;
-		break;
+	const gchar *preverse, *preverse2, *buf;
+	gchar heading[8];
+
+	int x = 0;
+	sprintf(heading, "%d", x);
+	while ((preverse = p->get_entry_attribute("Heading", "Preverse",
+						  heading)) != NULL) {
+		preverse2 = p->render_this_text(
+			       settings.parallel_list[modidx], preverse);
+		buf = g_strdup_printf("<br/><b>%s</b><br/><br/>", preverse2);
+
+		text += buf;
+
+		g_free((gchar *)preverse2); 
+		g_free((gchar *)preverse);
+		g_free((gchar *)buf);
+		++x;
+		sprintf(heading, "%d", x);
 	}
-	if (settings.dockedInt)
-		main_update_parallel_page();
-	else
-		main_update_parallel_page_detached();
 }
 
-#ifdef USE_GTKMOZEMBED
 /******************************************************************************
  * Name
  *   gui_update_parallel_page
@@ -704,475 +607,102 @@ void main_update_parallel_page(void)
 {
 	gchar tmpBuf[256];
 	const gchar *rowcolor;
-	gchar *font_size_tmp = NULL, *font_size = NULL;
-	gchar *utf8str, *mod_name, *font_name = NULL;
-	gint utf8len, i, j;
-	gboolean use_gtkhtml_font;
+	gchar *utf8str, *mod_name;
+	gint modidx;
 	gboolean is_rtol = FALSE;
-	gchar *buf;
-	gchar *file = NULL;
-	gchar *data = NULL;
-
-
-	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(widgets.html_parallel))) return ;
-	GeckoHtml *html = GECKO_HTML(widgets.html_parallel);
-	gecko_html_open_stream(html,"text/html");
+	GString *data;
+	MOD_FONT *mf;
+	SWBuf text;
 
 	settings.cvparallel = settings.currentverse;
 
-	if (settings.havebible) {
-		sprintf(tmpBuf, HTML_START
-			"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\"><table>",
-			settings.bible_bg_color,
-			settings.bible_text_color, settings.link_color);
+	sprintf(tmpBuf, HTML_START
+		"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\"><table>",
+		settings.bible_bg_color,
+		settings.bible_text_color, settings.link_color);
+	data = g_string_new(tmpBuf);
 
-		utf8len = strlen(tmpBuf);
-		if (utf8len) {
-			data = g_strconcat(tmpBuf,NULL);
-		}
+	if (settings.parallel_list) {
+		for (modidx = 0;
+		     (mod_name = settings.parallel_list[modidx]);
+		     modidx++) {
+			mf = get_font(mod_name);
 
-		for (i = 0, j = 0; i < 5; i++) {
-			mod_name = NULL;
-			switch (i) {
-			case 0:
-				if (parallel1)
-					mod_name =
-					    settings.parallel1Module;
-				else
-					mod_name = NULL;
-				break;
-			case 1:
-				if (parallel2)
-					mod_name =
-					    settings.parallel2Module;
-				else
-					mod_name = NULL;
-				break;
-			case 2:
-				if (parallel3)
-					mod_name =
-					    settings.parallel3Module;
-				else
-					mod_name = NULL;
-				break;
-			case 3:
-				if (parallel4)
-					mod_name =
-					    settings.parallel4Module;
-				else
-					mod_name = NULL;
-				break;
-			case 4:
-				if (parallel5)
-					mod_name =
-					    settings.parallel5Module;
-				else
-					mod_name = NULL;
-				break;
-			}
-			GS_message(("mod_name = %s",mod_name));
-			if (!mod_name)
-				continue;
-
-			++j;
 			is_rtol = main_is_mod_rtol(mod_name);
 
-			file = g_strdup_printf("%s/fonts.conf", settings.gSwordDir);
-			font_name = get_conf_file_item(file, mod_name, "Font");
-			if (!font_name || !strcmp(font_name, "none")) {
-				font_name =
-				    main_get_mod_config_entry(mod_name, "Font");
-				if (!font_name)
-					font_name = g_strdup("none");
-			}
-			if (strlen(font_name) < 2) {
-				use_gtkhtml_font = TRUE;
-			} else {
-				if (!strncmp(font_name, "none", 4)) {
-					use_gtkhtml_font = TRUE;
-				} else {
-					use_gtkhtml_font = FALSE;
-				}
-			}
-
-			font_size_tmp = get_conf_file_item(file, mod_name, "Fontsize");
-			g_free(file);
-			if (!font_size_tmp) {
-				font_size_tmp =
-				    main_get_mod_config_entry(mod_name, "Fontsize");
-			}
-
-			font_size =
-			    g_strdup_printf("%+d",
-					    (font_size_tmp ? atoi(font_size_tmp) : 0)
-					     + settings.base_font_size);
-
-			if (j == 0 || j == 2 || j == 4)
+			if (modidx % 2 == 1)	/* alternating background color */
 				rowcolor = "#F1F1F1";
 			else
 				rowcolor = settings.bible_bg_color;
 
-			if (j == 0) {
+			if (modidx == 0) {
 				sprintf(tmpBuf,
 					"<tr><td><i><font color=\"%s\" size=\"%d\">[%s]</font></i></td></tr>",
 					settings.bible_verse_num_color,
 					settings.verse_num_font_size + settings.base_font_size,
 					settings.currentverse);
-
-				utf8len = strlen(tmpBuf);
-				if (utf8len) {
-					data = g_strconcat(data, tmpBuf, NULL);
-				}
+				g_string_append(data, tmpBuf);
 			}
 
 			sprintf(tmpBuf,
-				"<tr bgcolor=\"%s\"><td><b><a href=\"xiphos.url?action=showModInfo&value=%s&module=%s\"><font color=\"%s\" size=\"%+d\"> [%s]</font></a></b>",
+				"<tr bgcolor=\"%s\"><td><b><a href=\"passagestudy.jsp?action=showModInfo&value=%s&module=%s\"><font color=\"%s\" size=\"%+d\"> [%s]</font></a></b>",
 				rowcolor,
 				main_get_module_description(mod_name),
 				mod_name,
 				settings.bible_verse_num_color,
 				settings.verse_num_font_size + settings.base_font_size,
 				mod_name);
+			g_string_append(data, tmpBuf);
 
-			utf8len = strlen(tmpBuf);
-			if (utf8len) {
-					data = g_strconcat(data, tmpBuf, NULL);
-			}
-
-			if (use_gtkhtml_font)
+			if ((strlen(mf->old_font) < 2) ||
+			    !strncmp(mf->old_font, "none", 4))
 				sprintf(tmpBuf, "<font size=\"%s\">",
-					font_size);
+					mf->old_font_size);
 			else
 				sprintf(tmpBuf,
 					"<font face=\"%s\" size=\"%s\">",
-					font_name, font_size);
+					mf->old_font, mf->old_font_size);
+			free_font(mf);
+			g_string_append(data, tmpBuf);
 
+			if (is_rtol)
+				g_string_append(data, "<br/><div align=right>");
 
-			utf8len = strlen(tmpBuf);
-			if (utf8len) {
-				data = g_strconcat(data, tmpBuf, NULL);
+			backend_p->set_module_key(settings.parallel_list[modidx], settings.cvparallel);
+			text = "";
+			get_heading(text, backend_p, modidx);
+			g_string_append(data, text.c_str());
+
+			utf8str = backend_p->get_render_text(mod_name, settings.currentverse);
+			if (utf8str) {
+				g_string_append(data, utf8str);
+				g_free(utf8str);
 			}
 
-			utf8str =
-			    backend_p->get_render_text(mod_name,
-							settings.
-							currentverse);
-			if (is_rtol) {
-				buf = g_strdup_printf(
-					"%s","<br><DIV ALIGN=right>");
-				if (strlen(buf)) {
-					data = g_strconcat(data, buf, NULL);
-					free(buf);
-				}
-			}
-			if (strlen(utf8str)) {
-				data = g_strconcat(data, utf8str, NULL);
-				free(utf8str);
-			}
+			if (is_rtol)
+				g_string_append(data, "</div><br/>");
 
-			if (is_rtol) {
-				buf = g_strdup_printf(
-					"%s","</DIV><br>");
-				if (strlen(buf)) {
-					data = g_strconcat(data, buf, NULL);
-					free(buf);
-				}
-			}
 			sprintf(tmpBuf,
-				"</font><small>[<a href=\"xiphos.url?action=showParallel&"
+				"</font><small>[<a href=\"passagestudy.jsp?action=showParallel&"
 				"type=swap&value=%s\">%s</a>]</small></td></tr>",
 				mod_name,_("view context"));
-
-			utf8len = strlen(tmpBuf);
-			if (utf8len) {
-				data = g_strconcat(data, tmpBuf, NULL);
-			}
-		}
-
-		sprintf(tmpBuf, "</table></body></html>");
-
-		utf8len = strlen(tmpBuf);
-		if (utf8len) {
-			data = g_strconcat(data, tmpBuf, NULL);
-			gecko_html_write(html,data,-1);
+			g_string_append(data, tmpBuf);
 		}
 	}
-	gecko_html_close(html);
-	if (data)
-		g_free(data);
-	if (font_name)
-		free(font_name);
-	if (font_size)
-		free(font_size);
-	if (font_size_tmp)
-		free(font_size_tmp);
+
+	g_string_append(data, "</table></body></html>");
+	HtmlOutput(data->str, widgets.html_parallel, NULL, NULL);
+	g_string_free(data, TRUE);
 }
 
-#else
 /******************************************************************************
  * Name
- *   gui_update_parallel_page
+ *   interpolate_parallel_display
  *
  * Synopsis
  *   #include "main/parallel_view.h
  *
- *   void gui_update_parallel_page(void)
- *
- * Description
- *
- *
- * Return value
- *   void
- */
-
-void main_update_parallel_page(void)
-{
-	gchar tmpBuf[256], *rowcolor;
-	gchar *font_size_tmp = NULL, *font_size = NULL;
-	gchar *utf8str, *mod_name, *font_name = NULL;
-	gint utf8len, i, j;
-	gboolean was_editable, use_gtkhtml_font;
-	gboolean is_rtol = FALSE;
-	gchar *buf;
-	gchar *file = NULL;
-
-	settings.cvparallel = settings.currentverse;
-
-	if (settings.havebible) {
-		/* setup gtkhtml widget */
-		GtkHTML *html = GTK_HTML(widgets.html_parallel);
-		was_editable = gtk_html_get_editable(html);
-		if (was_editable)
-			gtk_html_set_editable(html, FALSE);
-		htmlstream =
-		    gtk_html_begin_content(html,
-					   (gchar *)"text/html; charset=utf-8");
-		sprintf(tmpBuf,
-			"<html><body bgcolor=\"%s\" text=\"%s\" link=\"%s\"><table>",
-			settings.bible_bg_color,
-			settings.bible_text_color, settings.link_color);
-		/*utf8str =
-		    e_utf8_from_gtk_string(widgets.html_parallel,
-					   tmpBuf);*/
-		utf8len = strlen(tmpBuf);
-		if (utf8len) {
-			gtk_html_write(GTK_HTML(html), htmlstream,
-				       tmpBuf, utf8len);
-		}
-
-		for (i = 0, j = 0; i < 5; i++) {
-			mod_name = NULL;
-			switch (i) {
-			case 0:
-				if (parallel1)
-					mod_name =
-					    settings.parallel1Module;
-				else
-					mod_name = NULL;
-				break;
-			case 1:
-				if (parallel2)
-					mod_name =
-					    settings.parallel2Module;
-				else
-					mod_name = NULL;
-				break;
-			case 2:
-				if (parallel3)
-					mod_name =
-					    settings.parallel3Module;
-				else
-					mod_name = NULL;
-				break;
-			case 3:
-				if (parallel4)
-					mod_name =
-					    settings.parallel4Module;
-				else
-					mod_name = NULL;
-				break;
-			case 4:
-				if (parallel5)
-					mod_name =
-					    settings.parallel5Module;
-				else
-					mod_name = NULL;
-				break;
-			}
-			if (!mod_name)
-				continue;
-			GS_message(("mod_name = %s", mod_name));
-
-			++j;
-			is_rtol = main_is_mod_rtol(mod_name);
-			//font_name = get_module_font_name(mod_name);
-			file = g_strdup_printf("%s/fonts.conf", settings.gSwordDir);
-			font_name = get_conf_file_item(file, mod_name, "Font");
-			if (!font_name || !strcmp(font_name, "none")) {
-				font_name =
-				    main_get_mod_config_entry(mod_name, "Font");
-				if (!font_name)
-					font_name = g_strdup("none");
-			}
-			if (strlen(font_name) < 2) {
-				use_gtkhtml_font = TRUE;
-				GS_message(("use_gtkhtml_font = TRUE"));
-			} else {
-				if (!strncmp(font_name, "none", 4)) {
-					use_gtkhtml_font = TRUE;
-					GS_message(("use_gtkhtml_font = TRUE"));
-				} else {
-					use_gtkhtml_font = FALSE;
-					GS_message(("use_gtkhtml_font = FALSE"));
-				}
-			}
-
-			font_size_tmp = get_conf_file_item(file, mod_name, "Fontsize");
-			g_free(file);
-			if (!font_size_tmp) {
-				font_size_tmp =
-				    main_get_mod_config_entry(mod_name, "Fontsize");
-			}
-
-			font_size =
-			    g_strdup_printf("%+d",
-					    (font_size_tmp ? atoi(font_size_tmp) : 0)
-					     + settings.base_font_size);
-
-			if (j == 0 || j == 2 || j == 4)
-				rowcolor = (gchar *)"#F1F1F1";
-			else
-				rowcolor = settings.bible_bg_color;
-
-			if (j == 0) {
-				sprintf(tmpBuf,
-					"<tr><td><i><font color=\"%s\" size=\"%d\">[%s]</font></i></td></tr>",
-					settings.bible_verse_num_color,
-					settings.verse_num_font_size + settings.base_font_size,
-					settings.currentverse);
-
-				utf8len = strlen(tmpBuf);
-				if (utf8len) {
-					gtk_html_write(GTK_HTML(html),
-						       htmlstream,
-						       tmpBuf,
-						       utf8len);
-				}
-			}
-
-			sprintf(tmpBuf,
-				"<tr bgcolor=\"%s\"><td><b><a href=\"xiphos.url?action=showModInfo&value=%s&module=%s\"><font color=\"%s\" size=\"%+d\"> [%s]</font></a></b>",
-				rowcolor,
-				main_get_module_description(mod_name),
-				mod_name,
-				settings.bible_verse_num_color,
-				settings.verse_num_font_size + settings.base_font_size,
-				mod_name);
-
-			utf8len = strlen(tmpBuf);
-			if (utf8len) {
-				gtk_html_write(GTK_HTML(html),
-					       htmlstream, tmpBuf,
-					       utf8len);
-			}
-
-			if (use_gtkhtml_font)
-				sprintf(tmpBuf, "<font size=\"%s\">",
-					font_size);
-			else
-				sprintf(tmpBuf,
-					"<font face=\"%s\"size=\"%s\">",
-					font_name, font_size);
-
-
-			utf8len = strlen(tmpBuf);
-			if (utf8len) {
-				gtk_html_write(GTK_HTML(html),
-					       htmlstream, tmpBuf,
-					       utf8len);
-			}
-
-			utf8str =
-			    backend_p->get_render_text(mod_name,
-							settings.
-							currentverse);
-/*#ifdef  DEBUG
-			if (!strcmp(mod_name,"KJV2006"))
-				g_message("\nmod: %s\nRAW: %s\nRENDERED: %s", mod_name,
-						backend_p->get_raw_text(mod_name,
-								settings.currentverse),utf8str);
-#endif
-*/
-			if (is_rtol) {
-				buf = g_strdup_printf(
-					"%s","<br><DIV ALIGN=right>");
-				if (strlen(buf)) {
-					gtk_html_write(GTK_HTML(html),
-						       htmlstream, buf,
-						       strlen(buf));
-					free(buf);
-				}
-			}
-			if (strlen(utf8str)) {
-				gtk_html_write(GTK_HTML(html),
-					       htmlstream, utf8str,
-					       strlen(utf8str));
-				free(utf8str);
-			}
-
-			if (is_rtol) {
-				buf = g_strdup_printf(
-					"%s","</DIV><br>");
-				if (strlen(buf)) {
-					gtk_html_write(GTK_HTML(html),
-						       htmlstream, buf,
-						       strlen(buf));
-					free(buf);
-				}
-			}
-			sprintf(tmpBuf,
-				"</font><small>[<a href=\"xiphos.url?action=showParallel&"
-				"type=swap&value=%s\">%s</a>]</small></td></tr>",
-				mod_name,_("view context"));
-
-			utf8len = strlen(tmpBuf);
-			if (utf8len) {
-				gtk_html_write(GTK_HTML(html),
-					       htmlstream, tmpBuf,
-					       utf8len);
-			}
-			if (font_name)
-				free(font_name);
-			if (font_size)
-				free(font_size);
-			if (font_size_tmp)
-				free(font_size_tmp);
-
-		}
-
-		sprintf(tmpBuf, "</table></body></html>");
-
-		utf8len = strlen(tmpBuf);
-		if (utf8len) {
-			gtk_html_write(GTK_HTML(html), htmlstream,
-				       tmpBuf, utf8len);
-		}
-
-		gtk_html_end(GTK_HTML(html), htmlstream, status1);
-		gtk_html_set_editable(html, was_editable);
-	}
-}
-
-#endif
-
-/******************************************************************************
- * Name
- *   int_display
- *
- * Synopsis
- *   #include "main/parallel_view.h
- *
- *   void int_display(SWBuf& text, gchar *key, char *mod_name[])
+ *   void interpolate_parallel_display(SWBuf& text, gchar *key)
  *
  * Description
  *   carry out the hard work of getting verses for parallel display.
@@ -1181,140 +711,107 @@ void main_update_parallel_page(void)
  *   void
  */
 
-static void int_display(SWBuf& text, gchar *key, char *mod_name[])
+static void interpolate_parallel_display(SWBuf& text, gchar *key, gint parallel_count, gint fraction)
 {
 	gchar  	*utf8str,
 		*textColor,
 		*tmpkey,
-		tmpbuf[256],
-		*use_font_size[5],
-		*font_size_tmp[5],
-		*use_font_name[5];
+		tmpbuf[256];
 	const gchar *bgColor;
 	gchar str[500];
-	gboolean evenRow = FALSE;
-	gboolean is_rtol = FALSE;
-	gchar *file = NULL;
-	gint cur_verse, cur_chapter, i = 1, j;
+	gint cur_verse, cur_chapter, verse, modidx;
 	char *cur_book;
-	gboolean is_module[5] = { FALSE, FALSE, FALSE, FALSE, FALSE };
+	MOD_FONT **mf;
+	gboolean *is_rtol, *is_module;
 
 	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(widgets.notebook_bible_parallel))) return;
 
-	// need #verses to process in this book.
+	is_module = g_new(gboolean, parallel_count);
+	is_rtol   = g_new(gboolean, parallel_count);
+	mf        = g_new(MOD_FONT *, parallel_count);
+
+	// quick cache of fonts/rtol info.
+	for (modidx = 0; modidx < parallel_count; ++modidx) {
+		// determine module presence once each.
+		is_module[modidx] = backend->is_module(settings.parallel_list[modidx]);
+
+		if (is_module[modidx]) {
+			is_rtol[modidx] = main_is_mod_rtol(settings.parallel_list[modidx]);
+			mf[modidx] = get_font(settings.parallel_list[modidx]);
+		}
+	}
+
+	// need #verses to process in this chapter.
 	VerseKey vkey;
 	int xverses;
 
 	vkey.AutoNormalize(1);
 	vkey = key;
-
-#ifdef SWORD_MULTIVERSE
 	xverses = (vkey.getVerseMax());
-#else
-	xverses = (vkey.books[vkey.Testament()-1]
-				 [vkey.Book()-1].
-				 versemax[vkey.Chapter()-1]);
-#endif
-
-	// quick cache of fonts.  (mod_name was passed in.)
-	file = g_strdup_printf("%s/fonts.conf", settings.gSwordDir);
-	for (j = 0; j < 5; ++j) {
-		// determine module presence just once each for this routine.
-		is_module[j] = (mod_name[j] &&
-				*(mod_name[j]) &&
-				backend->is_module(mod_name[j]));
-
-		// collect decorations.
-		font_size_tmp[j] = get_conf_file_item(file, mod_name[j], "Fontsize");
-		if ((font_size_tmp[j] == NULL) ||
-		    !strcmp(font_size_tmp[j], "+0")) {
-			g_free(font_size_tmp[j]);
-			font_size_tmp[j] =
-			    main_get_mod_config_entry(mod_name[j], "Fontsize");
-			if ((font_size_tmp[j] == NULL) || (*font_size_tmp[j] == '\0'))
-				font_size_tmp[j] = g_strdup("+0");
-		}
-
-		use_font_size[j] =
-		    g_strdup_printf("%+d",
-				    (font_size_tmp[j] ? atoi(font_size_tmp[j]) : 0)
-				    + settings.base_font_size);
-
-		use_font_name[j] = get_conf_file_item(file, mod_name[j], "Font");
-		if ((use_font_name[j] == NULL) ||
-		    !strcmp(use_font_name[j], "none")) {
-			use_font_name[j] =
-			    main_get_mod_config_entry(mod_name[j], "Font");
-			if (!use_font_name[j])
-				use_font_name[j] = g_strdup("none");
-		}
-	}
-	g_free(file);
-
-	bgColor = "#f1f1f1";
 
 	tmpkey = backend_p->get_valid_key(key);
 	cur_verse = backend_p->key_get_verse(tmpkey);
-	settings.intCurVerse = cur_verse;
 	cur_chapter = backend_p->key_get_chapter(tmpkey);
 	cur_book = backend_p->key_get_book(tmpkey);
+	settings.intCurVerse = cur_verse;
 
-	for (i = 1; i <= xverses; ++i) {
-		snprintf(tmpbuf, 255, "%s %d:%d", cur_book, cur_chapter, i);
+	for (verse = 1; verse <= xverses; ++verse) {
+		snprintf(tmpbuf, 255, "%s %d:%d", cur_book, cur_chapter, verse);
 		free(tmpkey);
 		tmpkey = backend_p->get_valid_key(tmpbuf);
 
 		text += "<tr valign=\"top\">";
 
 		// mark current verse properly.
-		if (i == cur_verse)
+		if (verse == cur_verse)
 			textColor = settings.currentverse_color;
 		else
 			textColor = settings.bible_text_color;
 
 		// alternate background colors.
-		if (evenRow) {
-			evenRow = FALSE;
+		if (verse % 2 == 0)
 			bgColor = "#f1f1f1";
-		} else {
-			evenRow = TRUE;
+		else
 			bgColor = settings.bible_bg_color;
-		}
 
-		for (j = 0; j < 5; j++) {
-			is_rtol = main_is_mod_rtol(mod_name[j]);
+		for (modidx = 0; modidx < parallel_count; modidx++) {
+			if (is_module[modidx]) {		
+				
+				const gchar *newurl = main_url_encode(tmpkey);
+				gchar *num = main_format_number(verse);
+				snprintf(str, 499,
+					 "<td width=\"%d%%\" bgcolor=\"%s\">"
+					 "<a href=\"passagestudy.jsp?action=showParallel&"
+					 "type=verse&value=%s\" name=\"%d\">"
+					 "<font color=\"%s\">%s. </font></a>"
+					 "<font face=\"%s\" size=\"%s\" color=\"%s\">",
+					 fraction,
+					 bgColor,
+					 newurl,
+					 verse,
+					 settings.bible_verse_num_color,
+					 num,
+					 mf[modidx]->old_font,
+					 mf[modidx]->old_font_size,
+					 textColor);
+				g_free((gchar*)newurl);
+				g_free(num);
+				text += str;
 
-			char *num = main_format_number(i);
-			snprintf(str, 499,
-				"<td width=\"20%%\" bgcolor=\"%s\">"
-				"<a href=\"xiphos.url?action=showParallel&"
-				"type=verse&value=%s\" name=\"%d\">"
-				"<font color=\"%s\">%s. </font></a>"
-				"<font face=\"%s\" size=\"%s\" color=\"%s\">",
-				bgColor,
-				main_url_encode(tmpkey),
-				i,
-				settings.bible_verse_num_color,
-				num,
-				use_font_name[j],
-				use_font_size[j],
-				textColor);
-			g_free(num);
-			text += str;
+				if (is_rtol[modidx])
+					text += "<br/><div align=right>";
 
-			if (is_module[j]) {
-				if (is_rtol)
-					text += "<br><DIV ALIGN=right>";
+				backend_p->set_module_key(settings.parallel_list[modidx], tmpkey);
+				get_heading(text, backend_p, modidx);
 
-				utf8str = backend_p->get_render_text
-				    (mod_name[j], tmpkey);
-				if (strlen(utf8str)) {
+				utf8str = backend_p->get_render_text(settings.parallel_list[modidx], tmpkey);
+				if (utf8str) {
 					text += utf8str;
-					free(utf8str);
+					g_free(utf8str);
 				}
 
-				if (is_rtol)
-					text += "</DIV>";
+				if (is_rtol[modidx])
+					text += "</div>";
 			}
 
 			text += "</font></td>";
@@ -1322,14 +819,16 @@ static void int_display(SWBuf& text, gchar *key, char *mod_name[])
 
 		text += "</tr>";
 	}
-
-	for (j = 0; j < 5; ++j) {
-		g_free(use_font_size[j]);
-		g_free(font_size_tmp[j]);
-		g_free(use_font_name[j]);
-	}
 	g_free(tmpkey);
 	g_free(cur_book);
+
+	/* clear bookkeeping data */
+	for (modidx = 0; modidx < parallel_count; ++modidx)
+		if (is_module[modidx])
+			free_font(mf[modidx]);
+	g_free(mf);
+	g_free(is_rtol);
+	g_free(is_module);
 }
 
 
@@ -1352,53 +851,41 @@ static void int_display(SWBuf& text, gchar *key, char *mod_name[])
 void main_update_parallel_page_detached(void)
 {
 	SWBuf text("");
-	gchar buf[500], *mod_name[5];
-	gint j;
-	gchar space[2];  //there is surely a better way?
-	space[0] = ' ';
-	space[1] = '\0';
-	mod_name[0] = (parallel1 ? settings.parallel1Module : space);
-	mod_name[1] = (parallel2 ? settings.parallel2Module : space);
-	mod_name[2] = (parallel3 ? settings.parallel3Module : space);
-	mod_name[3] = (parallel4 ? settings.parallel4Module : space);
-	mod_name[4] = (parallel5 ? settings.parallel5Module : space);
-
-    	snprintf(buf, 499, "<span color='blue' weight='bold'>%s</span>", mod_name[0]);
-    	gtk_label_set_markup(GTK_LABEL(plabels.label_1), buf);
-
-    	snprintf(buf, 499, "<span color='blue' weight='bold'>%s</span>", mod_name[1]);
-    	gtk_label_set_markup(GTK_LABEL(plabels.label_2), buf);
-
-    	snprintf(buf, 499, "<span color='blue' weight='bold'>%s</span>", mod_name[2]);
-    	gtk_label_set_markup(GTK_LABEL(plabels.label_3), buf);
-
-    	snprintf(buf, 499, "<span color='blue' weight='bold'>%s</span>", mod_name[3]);
-    	gtk_label_set_markup(GTK_LABEL(plabels.label_4), buf);
-
-    	snprintf(buf, 499, "<span color='blue' weight='bold'>%s</span>", mod_name[4]);
-    	gtk_label_set_markup(GTK_LABEL(plabels.label_5), buf);
+	gchar buf[500];
+	gint modidx, parallel_count, fraction;
 
 #ifdef USE_GTKMOZEMBED
 	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(widgets.html_parallel_dialog))) return;
 #endif
 
+	/* how big a pile of parallels have we got? */
+	if (settings.parallel_list == NULL)
+		return;
+	for (parallel_count = 0; settings.parallel_list[parallel_count]; ++parallel_count)
+		/* just count non-null string ptrs */;
+
+	/* get the per-column percentage width. */
+	/* 2 => 50, 4 => 25, 5 => 20, 10 => 10, ... */
+	fraction = (parallel_count ? (100/parallel_count) : 100);
+
 	snprintf(buf, 499, HTML_START
 		"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\"><table align=\"left\" valign=\"top\"><tr valign=\"top\" >",
 		settings.bible_bg_color, settings.bible_text_color,
 		settings.link_color);
 	text += buf;
 
-	for (j = 0; j < 5; ++j){
+	for (modidx = 0; settings.parallel_list[modidx]; ++modidx) {
 		snprintf(buf, 499,
-			"<td valign=\"top\" width=\"20%%\" bgcolor=\"#f1f1f1\"><font color=\"%s\" size=\"%+d\"><b>%s</b></td>",
-			settings.bible_verse_num_color,
-			settings.verse_num_font_size + settings.base_font_size,
-			mod_name[j]);
+			 "<td valign=\"top\" width=\"%d%%\" bgcolor=\"#f1f1f1\"><font color=\"%s\" size=\"%+d\"><b>%s</b></font></td>",
+			 fraction,
+			 settings.bible_verse_num_color,
+			 settings.verse_num_font_size + settings.base_font_size,
+			 settings.parallel_list[modidx]);
 		text += buf;
 	}
 
 	text += "</tr>";
-	int_display(text, settings.cvparallel, mod_name);
+	interpolate_parallel_display(text, settings.cvparallel, parallel_count, fraction);
 	text += "</table></body></html>";
 
 	snprintf(buf, 499, "%d", ((settings.intCurVerse > 1)
@@ -1426,23 +913,6 @@ void main_update_parallel_page_detached(void)
 
 void main_swap_parallel_with_main(char *intmod)
 {
-#if 0
-	if ((settings.parallel5Module) && !strcmp(settings.parallel5Module, intmod)) {
-		settings.parallel5Module = xml_get_value("modules", "bible");
-	}
-	if ((settings.parallel4Module) && !strcmp(settings.parallel4Module, intmod)) {
-		settings.parallel4Module = xml_get_value("modules", "bible");
-	}
-	if ((settings.parallel3Module) && !strcmp(settings.parallel3Module, intmod)) {
-		settings.parallel3Module = xml_get_value("modules", "bible");
-	}
-	if ((settings.parallel2Module) && !strcmp(settings.parallel2Module, intmod)) {
-		settings.parallel2Module = xml_get_value("modules", "bible");
-	}
-	if ((settings.parallel1Module) && !strcmp(settings.parallel1Module, intmod)) {
-		settings.parallel1Module = xml_get_value("modules", "bible");
-	}
-#endif
 	main_display_bible(intmod, settings.currentverse);
 	main_update_parallel_page();
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_bible_parallel),
@@ -1522,9 +992,6 @@ void main_load_menu_form_mod_list(GtkWidget * pmInt, gchar * label,
 void main_init_parallel_view(void)
 {
 	backend_p = new BackEnd();
-	gui_create_parallel_page();
-	gtk_widget_realize(widgets.html_parallel);
-	main_set_parallel_options_at_start();
 }
 
 
