@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * previewer.cc -
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,14 +29,6 @@
 #include <stringmgr.h>
 #include <localemgr.h>
 
-#ifdef USE_GTKMOZEMBED
-#ifdef WIN32
-#include "geckowin/gecko-html.h"
-#else
-#include "gecko/gecko-html.h"
-#endif
-#endif
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -58,9 +50,7 @@ extern "C" {
 
 #include "gui/debug_glib_null.h"
 
-//#define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"></head>"
-#define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"><STYLE type=\"text/css\"><!-- A { text-decoration:none } %s --></STYLE></head>"
-#define DOUBLE_SPACE " * { line-height: 2em ! important; }"
+#define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"><style type=\"text/css\"><!-- A { text-decoration:none } --></style></head>"
 
 using namespace std;
 
@@ -99,51 +89,18 @@ GtkWidget *main_get_previewer_widget(void)
 
 void main_init_previewer(void)
 {
-	GString *tmp_str = g_string_new(NULL);
-	GString *str;
-	gchar *buf;
+	GString *str = g_string_new(NULL);
+	gchar *buf = _("Previewer");
 
-#ifdef USE_GTKMOZEMBED
-	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(previewer_html_widget)))
-		return;
-	GeckoHtml *html = GECKO_HTML(previewer_html_widget);
-	gecko_html_open_stream(html, "text/html");
-#else
-	/* setup gtkhtml widget */
-	GtkHTML *html = GTK_HTML(previewer_html_widget);
-	gboolean was_editable = gtk_html_get_editable(html);
-
-	if (was_editable)
-		gtk_html_set_editable(html, FALSE);
-#endif
-	g_string_printf(tmp_str,
+	g_string_printf(str,
 			HTML_START
-			"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">",
-			"",
+			"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">"
+			"<font color=\"grey\" size=\"-1\"><b>%s</b></font><hr/></body></html>",
 			settings.bible_bg_color, settings.bible_text_color,
-			settings.link_color);
-
-	str = g_string_new(tmp_str->str);
-	buf = _("Previewer");
-	g_string_printf(tmp_str,
-			"<b>%s</b><br><font color=\"grey\">"
-			"<HR></font><br>", buf);
-	str = g_string_append(str, tmp_str->str);
-
-	g_string_printf(tmp_str, " %s", "</font></body></html>");
-	str = g_string_append(str, tmp_str->str);
-
-#ifdef USE_GTKMOZEMBED
-	if (str->len)
-		gecko_html_write(html, str->str, str->len);
-	gecko_html_close(html);
-#else
-	if (str->len)
-		gtk_html_load_from_string(html, str->str, str->len);
-	gtk_html_set_editable(html, was_editable);
-#endif
+			settings.link_color,
+			buf);
+	HtmlOutput(str->str, previewer_html_widget, NULL, NULL);
 	g_string_free(str, TRUE);
-	g_string_free(tmp_str, TRUE);
 }
 
 
@@ -166,51 +123,10 @@ void main_init_previewer(void)
 void main_clear_viewer(void)
 {
 #ifdef USE_PREVIEWER_AUTOCLEAR
-	GString *tmp_str = g_string_new(NULL);
-	GString *str;
-	gchar *buf;
-
-#ifdef USE_GTKMOZEMBED
-	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(previewer_html_widget)))
+	if (!previewer_html_widget ||
+	    !GTK_WIDGET_REALIZED(GTK_WIDGET(previewer_html_widget)))
 		return;
-	GeckoHtml *html = GECKO_HTML(previewer_html_widget);
-	gecko_html_open_stream(html, "text/html");
-#else
-	/* setup gtkhtml widget */
-	GtkHTML *html = GTK_HTML(previewer_html_widget);
-	gboolean was_editable = gtk_html_get_editable(html);
-
-	if (was_editable)
-		gtk_html_set_editable(html, FALSE);
-#endif
-	g_string_printf(tmp_str,
-			HTML_START
-			"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">",
-			"",
-			settings.bible_bg_color, settings.bible_text_color,
-			settings.link_color);
-
-	str = g_string_new(tmp_str->str);
-	buf = _("Previewer");
-	g_string_printf(tmp_str,
-			"<b>%s</b><br><font color=\"grey\">"
-			"<HR></font><br>", buf);
-	str = g_string_append(str, tmp_str->str);
-
-	g_string_printf(tmp_str, " %s", "</font></body></html>");
-	str = g_string_append(str, tmp_str->str);
-
-#ifdef USE_GTKMOZEMBED
-	if (str->len)
-		gecko_html_write(html, str->str, str->len);
-	gecko_html_close(html);
-#else
-	if (str->len)
-		gtk_html_load_from_string(html, str->str, str->len);
-	gtk_html_set_editable(html, was_editable);
-#endif
-	g_string_free(str, TRUE);
-	g_string_free(tmp_str, TRUE);
+	main_init_previewer();
 #endif /* USE_PREVIEWER_AUTOCLEAR */
 }
 
@@ -232,127 +148,88 @@ void main_clear_viewer(void)
  *   void
  */
 
-void main_information_viewer(const gchar * mod_name, const gchar * text, const gchar * key,
-			     const gchar * action, const gchar * type,
-			     const gchar * morph_text, const gchar * morph)
+void main_information_viewer(const gchar * mod_name,
+			     const gchar * text,
+			     const gchar * key,
+			     const gchar * action,
+			     const gchar * type,
+			     const gchar * morph_text,
+			     const gchar * morph)
 {
 	GString *tmp_str = g_string_new(NULL);
 	GString *str;
 	MOD_FONT *mf = get_font((gchar*)mod_name);
-#ifdef USE_GTKMOZEMBED
-	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(previewer_html_widget)))
-		return;
-	GeckoHtml *html = GECKO_HTML(previewer_html_widget);
-	gecko_html_open_stream(html, "text/html");
-#else
-	GtkHTML *html = GTK_HTML(previewer_html_widget);
-	PangoContext* pc = gtk_widget_create_pango_context(GTK_WIDGET(html));
-	PangoFontDescription *desc = pango_context_get_font_description(pc);
-	pango_font_description_set_family(
-	    desc, ((mf->old_font) ? mf->old_font : "Serif"));
-	gtk_widget_modify_font(GTK_WIDGET(html), desc);
-#endif
 
 	g_string_printf(tmp_str,
 			HTML_START
-			"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">",
-			(settings.doublespace ? DOUBLE_SPACE : ""),
+			"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">"
+			"<font face=\"%s\" size=\"%+d\">",
 			settings.bible_bg_color, settings.bible_text_color,
-			settings.link_color);
+			settings.link_color,
+			(mf->old_font ? mf->old_font : "none"),
+			(mf->old_font_size
+			 ? atoi(mf->old_font_size) + settings.base_font_size
+			 : settings.base_font_size) - 1);
 
 	str = g_string_new(tmp_str->str);
 
 	if (type) {
-		if (!strcmp(type, "n")) {
+		if (*type == 'n') {
 			g_string_printf(tmp_str,
-					"<font color=\"grey\">%s<HR></font><br>",
+					"<font color=\"grey\">%s</font><hr/>",
 					_("Footnote"));
 			str = g_string_append(str, tmp_str->str);
 		}
-		if (!strcmp(type, "u")) {
+		else if (*type == 'u') {
 			g_string_printf(tmp_str,
-					"<font color=\"grey\">%s: %s<HR></font><br>",
+					"<font color=\"grey\">%s:<br/>%s</font><hr/>",
 					_("User Annotation"), key);
 			str = g_string_append(str, tmp_str->str);
 		}
-		if (!strcmp(type, "x")) {
+		else if (*type == 'x') {
 			g_string_printf(tmp_str,
-					"<font color=\"grey\">%s<HR></font><br>",
+					"<font color=\"grey\">%s</font><hr/>",
 					_("Cross Reference"));
 			str = g_string_append(str, tmp_str->str);
 		}
-		if (!strcmp(action, "showStrongs")) {	//&& !strcmp(type,"Greek")
+		else if (!strcmp(action, "showStrongs")) {
 			g_string_printf(tmp_str,
-					"<font color=\"grey\">%s: %s<HR></font><br>",
+					"<font color=\"grey\">%s: %s</font><hr/>",
 					_("Strongs"), key);
 			str = g_string_append(str, tmp_str->str);
 		}
-		if (!strcmp(action, "showMorph")) {	//&& !strcmp(type,"Greek")
+		else if (!strcmp(action, "showMorph")) {
 			g_string_printf(tmp_str,
-					"<font color=\"grey\">%s: %s<HR></font><br>",
+					"<font color=\"grey\">%s: %s</font><hr/>",
 					_("Morphology"), key);
 			str = g_string_append(str, tmp_str->str);
 		}
 	} else {
 		g_string_printf(tmp_str,
-				"<font color=\"grey\">%s: %s<HR></font><br>",
+				"<font color=\"grey\">%s: %s</font><hr/>",
 				mod_name, key);
 		str = g_string_append(str, tmp_str->str);
 	}
 
-	if (action && (!strcmp(action, "showStrongsMorph"))) {	//&& !strcmp(type,"Greek")
+	if (action && (!strcmp(action, "showStrongsMorph"))) {
 		g_string_printf(tmp_str,
-				"<font color=\"grey\">%s: %s<HR></font>",
+				"<font color=\"grey\">%s: %s</font><hr/>",
 				_("Strongs"), key);
 		str = g_string_append(str, tmp_str->str);
-		g_string_printf(tmp_str,
-				"<font face=\"%s\" size=\"%+d\">",
-				((mf->old_font) ? mf->old_font : "none"),
-				((mf->old_font_size)
-			        ? atoi(mf->old_font_size) + settings.base_font_size
-			        : settings.base_font_size));
-		str = g_string_append(str, tmp_str->str);
 		str = g_string_append(str, text);
 
 		g_string_printf(tmp_str,
-				"<font color=\"grey\"><br><br>%s: %s<HR></font>",
+				"<font color=\"grey\"><br/><br/>%s: %s</font><hr/>",
 				_("Morphology"), morph);
 		str = g_string_append(str, tmp_str->str);
 		str = g_string_append(str, morph_text);
-		g_string_printf(tmp_str, " %s<br>",
-				"</font></body></html>");
-		str = g_string_append(str, tmp_str->str);
 	} else {
-		g_string_printf(tmp_str,
-				"<font face=\"%s\" size=\"%+d\">",
-				((mf->old_font) ? mf->old_font : "none"),
-				((mf->old_font_size)
-			        ? atoi(mf->old_font_size) + settings.base_font_size
-			        : settings.base_font_size));
-		str = g_string_append(str, tmp_str->str);
 		str = g_string_append(str, text);
-
-		g_string_printf(tmp_str, " %s", "</font></body></html>");
-		str = g_string_append(str, tmp_str->str);
 	}
 
-#ifdef USE_GTKMOZEMBED
-	if (str->len) {
-		// manage too-large text blobs (e.g. NaveLinked "GOD, CREATOR").
-		int len = str->len, offset = 0, write_size;
+	str = g_string_append(str, "</font></body></html>");
 
-		while (len > 0) {
-			write_size = min(10000, len);
-			gecko_html_write(html, str->str+offset, write_size);
-			offset += write_size;
-			len -= write_size;
-		}
-	}
-	gecko_html_close(html);
-#else
-	if (str->len)
-		gtk_html_load_from_string(html, str->str, str->len);
-#endif
+	HtmlOutput(str->str, previewer_html_widget, mf, NULL);
 	free_font(mf);
 	g_string_free(str, TRUE);
 	g_string_free(tmp_str, TRUE);
@@ -366,11 +243,10 @@ void main_information_viewer(const gchar * mod_name, const gchar * text, const g
  * Synopsis
  *   #include "main/previewer.h"
  *
- *   void mark_search_words(GString *str, gboolean eliminate)
+ *   void mark_search_words(GString *str)
  *
  * Description
- *    purplifies search terms in results.
- *    "eliminate" indicates whether to eliminate internal markup.
+ *    highlights ("purplifies," formerly) search terms in results.
  *
  * Return value
  *   void
@@ -380,7 +256,7 @@ void mark_search_words(GString * str)
 {
 	gchar *tmpbuf, *buf, *searchbuf;
 	gint len_overall, len_word, len_tail, len_prefix;
-	gchar closestr[40], openstr[40];
+	gchar closestr[40], openstr[80];
 
 	/* regular expression search results         **fixme** */
 	if ((settings.searchType == 0) ||
@@ -388,10 +264,16 @@ void mark_search_words(GString * str)
 		return;
 	}
 	GS_message(("%s",settings.searchText));
-	/* close tags */
-	sprintf(closestr, "</b></font>");
-	/* open tags */
+	/* open and close tags */
+#ifdef USE_GTKMOZEMBED
+	sprintf(openstr,
+		"<span style=\"background-color: %s; color: %s\">",
+		settings.highlight_fg, settings.highlight_bg);
+	sprintf(closestr, "</span>");
+#else
 	sprintf(openstr, "<font color=\"%s\"><b>", settings.found_color);
+	sprintf(closestr, "</b></font>");
+#endif /* !USE_GTKMOZEMBED */
 	searchbuf = g_utf8_casefold(g_strdup(settings.searchText),-1);
 	if (g_str_has_prefix(searchbuf, "\"")) {
 		searchbuf = g_strdelimit(searchbuf, "\"", ' ');
@@ -407,10 +289,12 @@ void mark_search_words(GString * str)
 		gint count = 0, i = 0;
 
 		list = NULL;
-		/* seperate the search words and add them to a glist */
+		/* separate the search words and add them to a glist */
 		if ((token = strtok(searchbuf, " ")) != NULL) {
 			if (!isalnum(*token) && isalnum(*(token+1)))
-				token++;
+				token++;	// skip leading punctuation.
+			if (!strncmp(token, "lemma:", 6))
+				token += 7;	// skip the H/G qualifier.
 			list = g_list_append(list, token);
 			++count;
 			while ((token = strtok(NULL, " ")) != NULL) {
@@ -530,29 +414,10 @@ void main_entry_display(gpointer data, gchar * mod_name,
 	GString *str;
 	GString *search_str;
 	MOD_FONT *mf = get_font(mod_name);
-#ifdef USE_GTKMOZEMBED
-	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(html_widget)))
-		return;
-	GeckoHtml *html = GECKO_HTML(html_widget);
-	gecko_html_open_stream(html, "text/html");
-#else
-	gboolean was_editable = FALSE;
-	GtkHTML *html = GTK_HTML(html_widget);
-	PangoContext* pc = gtk_widget_create_pango_context(html_widget);
-	PangoFontDescription *desc = pango_context_get_font_description(pc);
-	pango_font_description_set_family(
-	    desc, ((mf->old_font) ? mf->old_font : "Serif"));
-	gtk_widget_modify_font(html_widget, desc);
 
-	/* setup gtkhtml widget */
-	was_editable = gtk_html_get_editable(html);
-	if (was_editable)
-		gtk_html_set_editable(html, FALSE);
-#endif
 	g_string_printf(tmp_str,
 			HTML_START
 			"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">",
-			(settings.doublespace ? DOUBLE_SPACE : ""),
 			settings.bible_bg_color, settings.bible_text_color,
 			settings.link_color);
 
@@ -560,10 +425,10 @@ void main_entry_display(gpointer data, gchar * mod_name,
 
 	g_string_printf(tmp_str,
 			"<font face=\"%s\" size=\"%+d\">",
-			((mf->old_font) ? mf->old_font : "none"),
-			((mf->old_font_size)
-			? atoi(mf->old_font_size) + settings.base_font_size
-			: settings.base_font_size));
+			(mf->old_font ? mf->old_font : "none"),
+			(mf->old_font_size
+			 ? atoi(mf->old_font_size) + settings.base_font_size
+			 : settings.base_font_size) - 1);
 	str = g_string_append(str, tmp_str->str);
 
 	/* show key in html widget  */
@@ -578,10 +443,9 @@ void main_entry_display(gpointer data, gchar * mod_name,
 					mod_name, key);
 		} else {
 			g_string_printf(tmp_str,
-					"<a href=\"xiphos.url?action=showModInfo&value=%s&module=%s\">"
-					"<font color=\"%s\">[%s]</a></font>[%s] ",
-					backend->
-					module_description(mod_name),
+					"<a href=\"passagestudy.jsp?action=showModInfo&value=%s&module=%s\">"
+					"<font color=\"%s\">[%s]</a></font>[%s]<br />",
+					backend->module_description(mod_name),
 					mod_name,
 					settings.link_color,
 					mod_name, key);
@@ -601,16 +465,7 @@ void main_entry_display(gpointer data, gchar * mod_name,
 	g_string_printf(tmp_str, " %s", "</font></body></html>");
 	str = g_string_append(str, tmp_str->str);
 
-#ifdef USE_GTKMOZEMBED
-	if (str->len)
-		gecko_html_write(html, str->str, str->len);
-	gecko_html_close(html);
-#else
-	if (str->len)
-		gtk_html_load_from_string(html, str->str, str->len);
-	gtk_html_set_editable(html, was_editable);
-#endif
-
+	HtmlOutput(str->str, html_widget, mf, NULL);
 	free_font(mf);
 	g_string_free(str, TRUE);
 	g_string_free(tmp_str, TRUE);
