@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * search_dialog.cc - glue  (: very sticky :)
  *
- * Copyright (C) 2004-2009 Xiphos Developer Team
+ * Copyright (C) 2004-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -72,8 +72,6 @@ static BackEnd *backendSearch = NULL;
 
 static gboolean is_running = FALSE;
 extern int search_dialog;
-static GList *get_current_list(void);
-static gchar *get_modlist_string(GList * mods);
 static GList *get_custom_list_from_name(const gchar * label);
 static void add_ranges(void);
 static void add_modlist(void);
@@ -81,8 +79,6 @@ static void add_modlist(void);
 gboolean terminate_search;	// also accessed from search_dialog.c.
 gboolean search_active;		// also accessed from search_dialog.c.
 
-int drag_module_type;
-
 static GList *list_of_finds;
 static GList *list_for_bookmarking = NULL;
 
@@ -115,7 +111,7 @@ gboolean main_export_current_adv_search (GString * str, gboolean html, gboolean
 
 	tmp = g_list_first(list_for_bookmarking);
 	if (html)
-		str = g_string_append(str, "<html><body>");
+		str = g_string_append(str, "<html><head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\" /></head><body>");
 	while (tmp) {
 		verses = (GList*) tmp->data;
 
@@ -707,7 +703,7 @@ void main_delete_module(GtkTreeView *treeview)
 	if (gui_yes_no_dialog(str, (char *)GTK_STOCK_DIALOG_WARNING)) {
 		gtk_list_store_remove(list_store, &selected);
 
-		mods = get_current_list();
+		mods = get_current_list(treeview);
 		mod_list = get_modlist_string(mods);
 
 		selection = gtk_tree_view_get_selection
@@ -741,43 +737,34 @@ void main_add_mod_to_list(GtkWidget * tree_widget, gchar * mod_name)
 	GList *mods = NULL;
 	GtkTreeSelection *selection_modules_lists;
 
-	model_modules_lists =
-	    gtk_tree_view_get_model(GTK_TREE_VIEW(search1.module_lists));
+	model_modules_lists = gtk_tree_view_get_model(GTK_TREE_VIEW(search1.module_lists));
 	store_modules_lists = GTK_LIST_STORE(model_modules_lists);
 
 	selection_modules_lists = gtk_tree_view_get_selection
 	    (GTK_TREE_VIEW(search1.module_lists));
 
-	model_mods =
-	    gtk_tree_view_get_model(GTK_TREE_VIEW(tree_widget));
+	model_mods = gtk_tree_view_get_model(GTK_TREE_VIEW(tree_widget));
 	list_store = GTK_LIST_STORE(model_mods);
 	mod_description = backendSearch->module_description(mod_name);
 
-			gtk_list_store_append(list_store, &iter);
-			gtk_list_store_set(list_store, &iter,
-					   0, mod_description,
-					   1, mod_name, -1);
-			mods = get_current_list();
-			mod_list = get_modlist_string(mods);
+	gtk_list_store_append(list_store, &iter);
+	gtk_list_store_set(list_store, &iter,
+			   0, mod_description,
+			   1, mod_name, -1);
+	mods = get_current_list(GTK_TREE_VIEW(search1.listview_modules));
+	mod_list = get_modlist_string(mods);
 
-			if (mod_list) {
-				gtk_tree_selection_get_selected
-	   			       (selection_modules_lists, NULL,
-					          &selected_modules_lists);
+	if (mod_list) {
+		gtk_tree_selection_get_selected
+  			       (selection_modules_lists, NULL,
+			          &selected_modules_lists);
 
-				gtk_list_store_set(store_modules_lists,
-						   &selected_modules_lists,
-						   1, mod_list, -1);
-				g_free(mod_list);
-			}
-			++search1.module_count;
-}
-
-void main_drag_drop_display_in_main(const char * uri)
-{
-#if 0
-	gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_comm_book),
-#endif /* 0 */
+		gtk_list_store_set(store_modules_lists,
+				   &selected_modules_lists,
+				   1, mod_list, -1);
+		g_free(mod_list);
+	}
+	++search1.module_count;
 }
 
 
@@ -849,7 +836,7 @@ void main_mod_selection_changed(GtkTreeSelection * selection,
 			gtk_list_store_set(list_store, &iter,
 					   0, mod_description,
 					   1, mod, -1);
-			mods = get_current_list();
+			mods = get_current_list(GTK_TREE_VIEW(search1.listview_modules));
 			mod_list = get_modlist_string(mods);
 
 			if (mod_list) {
@@ -958,13 +945,6 @@ void main_finds_verselist_selection_changed(GtkTreeSelection * selection,
 
 	if (verse_selected)
 		g_free(verse_selected);
-	drag_module_type = backendSearch->module_type(module);
-	if (drag_module_type == TEXT_TYPE) {
-		// now find verse spec's `:'; then SPC to end key.
-		buf = strchr(buf+1, ':');
-		buf = strchr(buf, ' ');
-		*buf = '\0';
-	}
 	const gchar *temp_key = main_url_encode(key);
 	verse_selected = g_strdup_printf("sword://%s/%s", module, temp_key);
 	if (is_double_click)
@@ -1017,7 +997,7 @@ void main_selection_modules_lists_changed(GtkTreeSelection *
 					    selection, gpointer data)
 {
 	gchar *name, *modules;
-	GList *tmp = NULL;
+	GList *tmp = NULL, *tmp2;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	GtkListStore *list_store;
@@ -1044,7 +1024,7 @@ void main_selection_modules_lists_changed(GtkTreeSelection *
 				      (GTK_ENTRY
 				       (search1.entry_list_name)));
 
-	tmp = g_list_first(tmp);
+	tmp = tmp2 = g_list_first(tmp);
 	while (tmp != NULL) {
 		gtk_list_store_append(list_store, &iter);
 		gtk_list_store_set(list_store, &iter,
@@ -1055,53 +1035,15 @@ void main_selection_modules_lists_changed(GtkTreeSelection *
 		g_free((gchar *) tmp->data);
 		tmp = g_list_next(tmp);
 	}
-	g_list_free(tmp);
+	g_list_free(tmp2);
 
 	if (!GTK_TOGGLE_BUTTON(search1.rb_current_module)->active)
 		main_add_modlist_to_label();
 	g_free(name);
 	g_free(modules);
-
 }
 
 
-/******************************************************************************
- * Name
- *
- *
- * Synopsis
- *   #include "gui/search_dialog.h"
- *
- *
- *
- * Description
- *
- *
- * Return value
- *
- */
-
-gchar *get_modlist_string(GList * mods)
-{
-	gchar *rv;
-	GString *str;
-
-	str = g_string_new("");
-
-	while (mods != NULL) {
-		str = g_string_append(str, (gchar *) mods->data);
-		mods = g_list_next(mods);
-		if (mods != NULL)
-			str = g_string_append_c(str, ',');
-	}
-	g_list_free(mods);
-	rv = g_strdup(str->str);
-	g_string_free(str, TRUE);
-	return rv;
-}
-
-
-
 /******************************************************************************
  * Name
  *   add_modlist_to_label
@@ -1123,7 +1065,7 @@ void main_add_modlist_to_label(void)
 	GList *mods = NULL;
 	gchar *mod_list, *str;
 
-	mods = get_current_list();
+	mods = get_current_list(GTK_TREE_VIEW(search1.listview_modules));
 	mod_list = get_modlist_string(mods);
 	if (strlen(mod_list) > 60)
 		str = g_strdup_printf("<b>%s</b>%60.60s...",
@@ -1223,46 +1165,6 @@ static GList *get_current_search_mod(void)
 }
 
 
-/******************************************************************************
- * Name
- *   get_current_list
- *
- * Synopsis
- *   #include "gui/search_dialog.h"
- *
- *   GList *get_current_list(void)
- *
- * Description
- *
- *
- * Return value
- *   GList *
- */
-
-static GList *get_current_list(void)
-{
-	GList *items = NULL;
-	gchar *buf;
-	GtkTreeModel *model;
-	GtkTreeIter iter;
-
-	model =
-	    gtk_tree_view_get_model(GTK_TREE_VIEW
-				    (search1.listview_modules));
-	if (gtk_tree_model_get_iter_first(model, &iter)) {
-		do {
-			gtk_tree_model_get(model, &iter, 1, &buf, -1);
-			items =
-			    g_list_append(items,
-					  (gchar *) g_strdup(buf));
-
-		} while (gtk_tree_model_iter_next(model, &iter));
-	}
-	return items;
-}
-
-
-
 /******************************************************************************
  * Name
  *   get_custom_list_from_name
@@ -1392,10 +1294,10 @@ char *main_get_search_rendered_text(char *module_name, char *key)
 static
 void _clear_find_lists(void)
 {
-	GList *tmp = NULL;
-	gchar *tmp_buf = NULL;
+	GList *tmp, *base;
+	gchar *tmp_buf;
 
-	list_of_finds = g_list_first(list_of_finds);
+	base = list_of_finds = g_list_first(list_of_finds);
 	while (list_of_finds) {
 		tmp = (GList*) list_of_finds->data;
 		while (tmp) {
@@ -1404,10 +1306,12 @@ void _clear_find_lists(void)
 			if (tmp_buf) g_free(tmp_buf);
 			tmp = g_list_next(tmp);
 		}
+		if (list_of_finds->data)
+			g_list_free((GList*)list_of_finds->data);
 		list_of_finds = g_list_next(list_of_finds);
 	}
-	if (list_of_finds)
-		g_list_free(list_of_finds);
+	if (base)
+		g_list_free(base);
 	list_of_finds = NULL;
 }
 
@@ -1484,10 +1388,15 @@ void main_do_dialog_search(void)
 
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(search1.notebook), 1);
 	search_type =
-	    GTK_TOGGLE_BUTTON(search1.rb_regexp)->active ? 0 :
-	    GTK_TOGGLE_BUTTON(search1.rb_exact_phrase)->active ? -1 :
-	    GTK_TOGGLE_BUTTON(search1.rb_words)->active ? -2 :
-	    GTK_TOGGLE_BUTTON(search1.rb_optimized)->active ? -4 : -3;
+	    (GTK_TOGGLE_BUTTON(search1.rb_regexp)->active
+	     ? 0
+	     : (GTK_TOGGLE_BUTTON(search1.rb_exact_phrase)->active
+		? -1
+		: (GTK_TOGGLE_BUTTON(search1.rb_words)->active
+		   ? -2
+		   : (GTK_TOGGLE_BUTTON(search1.rb_optimized)->active
+		      ? -4
+		      : -3 /* fallthrough to attribute */ ))));
 	GS_message(("search_type = %d", search_type));
 
 	search_params =
@@ -1500,11 +1409,7 @@ void main_do_dialog_search(void)
 		if (GTK_TOGGLE_BUTTON(search1.rb_strongs)->active) {
 			search_params |= SEARCHFLAG_MATCHWHOLEENTRY;
 			attribute_search_string = g_strdup_printf(
-#ifdef SWORD_MULTIVERSE
 					"Word//Lemma./%s",
-#else
-					"Word//Lemma/%s",
-#endif
 					search_string);
 		} else if (GTK_TOGGLE_BUTTON(search1.rb_morphs)->active) {
 			search_params |= SEARCHFLAG_MATCHWHOLEENTRY;
@@ -1526,7 +1431,7 @@ void main_do_dialog_search(void)
 				GTK_BIN(search1.combo_list)->child));
 		search_mods = get_custom_list_from_name(name);
 	} else if (GTK_TOGGLE_BUTTON(search1.rb_mod_list)->active) {
-		search_mods = get_current_list();
+		search_mods = get_current_list(GTK_TREE_VIEW(search1.listview_modules));
 	} else
 		search_mods = get_current_search_mod();
 	search_mods = g_list_first(search_mods);
@@ -1692,7 +1597,6 @@ void main_open_search_dialog(void)
 		/* add one to module count */
 		++search1.module_count;
 
-		search1.show_in_main = FALSE;
 		is_running = TRUE;
 	} else
 		gdk_window_raise(GTK_WIDGET(search1.dialog)->window);
@@ -1732,7 +1636,7 @@ void main_dialog_search_percent_update(char percent, void *userData)
 	if (terminate_search) {
 		backendSearch->terminate_search();
 		// this is WAY WRONG but at least it cleans up the dying window. */
-		_clear_find_lists();
+		// _clear_find_lists();  why would i have ever done this here?  oy.
 		is_running = FALSE;
 	} else {
 		/* update search dialog progress */
