@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * search_sidebar.cc - glue  (: very sticky :)
  *
- * Copyright (C) 2004-2009 Xiphos Developer Team
+ * Copyright (C) 2004-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -207,11 +207,17 @@ void main_do_sidebar_search(gpointer user_data)
 	if (strlen(search_string) < 1)
 		return;
 
+	/* text -vs- commentary search selection. */
 	if (GTK_TOGGLE_BUTTON(ss.radiobutton_search_text)->active) {
 		strcpy(settings.sb_search_mod,
 		       settings.MainWindowModule);
 	}
 	else if (GTK_TOGGLE_BUTTON(ss.radiobutton_search_comm)->active) {
+		if (!settings.CommWindowModule ||
+		    (strlen(settings.CommWindowModule) == 0)) {
+			gui_generic_warning(_("There is no commentary module."));
+			return;
+		}
 		strcpy(settings.sb_search_mod,settings.CommWindowModule);
 	}
 
@@ -350,13 +356,9 @@ void main_search_sidebar_fill_bounds_combos(void)
 
 	if (backendSearch->module_has_testament(module_name, 1)) {
 		while (i < key.BMAX[0]) {
-#ifdef SWORD_MULTIVERSE
 			key.Testament(1);
 			key.Book(i+1);
 			book = strdup((const char *) key.getBookName());
-#else
-			book = strdup((const char *) key.books[0][i].name);
-#endif
 			gtk_combo_box_append_text(GTK_COMBO_BOX(ss.entryUpper), book);
 			gtk_combo_box_append_text(GTK_COMBO_BOX(ss.entryLower), book);
 			++i;
@@ -367,13 +369,9 @@ void main_search_sidebar_fill_bounds_combos(void)
 	i = 0;
 	if (backendSearch->module_has_testament(module_name, 2)) {
 		while (i < key.BMAX[1]) {
-#ifdef SWORD_MULTIVERSE
 			key.Testament(2);
 			key.Book(i+1);
 			book = strdup((const char *) key.getBookName());
-#else
-			book = strdup((const char *) key.books[1][i].name);
-#endif
 			gtk_combo_box_append_text(GTK_COMBO_BOX(ss.entryUpper), book);
 			gtk_combo_box_append_text(GTK_COMBO_BOX(ss.entryLower), book);
 			++i;
