@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * settings.c - Guess what?
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@
 
 #include "gui/bookmarks.h"
 #include "gui/dialog.h"
+#include "gui/gui.h"
 #include "gui/mod_mgr.h"
 #include "gui/utilities.h"
 #include "gui/preferences_dialog.h"
@@ -55,9 +56,7 @@
 /******************************************************************************
  * defines
  */
-#define GS_DIR ".xiphos"
-
-#define GS_NET_PERMISSION	_("Welcome to Xiphos.\n\nThere are no Bible modules installed. In order to initialize, Xiphos needs you to install at least one Bible.\n\nWith your permission, Xiphos will invoke the Module Manager so that you may install from Crosswire:\n1. Configure remote install.\n2. Connect.\n3. Select a Bible text of your language preference.\n4. Click `install'.\nClose the Module Manager when you are done.\n\nWarning: If you live in a persecuted country, use with care.\n\nMay Xiphos invoke the Module Manager so that you may install a Bible?")
+#define XI_DIR ".xiphos"
 
 /******************************************************************************
  * globals
@@ -110,12 +109,10 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 	}
 
 	/* set gSwordDir to $home + .xiphos */
-	settings.gSwordDir = g_new(char, strlen(settings.homedir) +
-				   strlen(GS_DIR) + 2);
-	sprintf(settings.gSwordDir, "%s/%s", settings.homedir, GS_DIR);
+	settings.gSwordDir = g_strdup_printf("%s/%s", settings.homedir, XI_DIR);
 
 	/* if gSwordDir does not exist, create it. */
-	if (access(settings.gSwordDir, F_OK) == -1) {
+	if (g_access(settings.gSwordDir, F_OK) == -1) {
 		if ((Mkdir(settings.gSwordDir, S_IRWXU)) != 0) {
 			char msg[300];
 			gui_init(argc, argv);
@@ -129,7 +126,7 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 
 	/* if .sword does not exist create it */
 	sword_dir = g_strdup_printf("%s/%s", settings.homedir, DOTSWORD);
-	if (access(sword_dir, F_OK) == -1) {
+	if (g_access(sword_dir, F_OK) == -1) {
 		if ((Mkdir(sword_dir, S_IRWXU)) != 0) {
 			gui_init(argc, argv);
 			gui_generic_warning(_("can not create " DOTSWORD));
@@ -138,7 +135,7 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 	g_free(sword_dir);
 	/* if .sword/mods.d does not exist create it */
 	sword_dir = g_strdup_printf("%s/%s", settings.homedir, DOTSWORD "/mods.d");
-	if (access(sword_dir, F_OK) == -1) {
+	if (g_access(sword_dir, F_OK) == -1) {
 		if ((Mkdir(sword_dir, S_IRWXU)) != 0) {
 			gui_init(argc, argv);
 			gui_generic_warning(_("can not create " DOTSWORD "/mods.d"));
@@ -147,7 +144,7 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 	g_free(sword_dir);
 	/* if .sword/modules does not exist create it */
 	sword_dir = g_strdup_printf("%s/%s", settings.homedir, DOTSWORD "/modules");
-	if (access(sword_dir, F_OK) == -1) {
+	if (g_access(sword_dir, F_OK) == -1) {
 		if ((Mkdir(sword_dir, S_IRWXU)) != 0) {
 			gui_init(argc, argv);
 			gui_generic_warning(_("can not create " DOTSWORD "/modules"));
@@ -188,7 +185,7 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 
 	/* if settings.xml does not exist create it */
 	if (buf_says_empty ||
-	    (access(settings.fnconfigure, F_OK) == -1) ||
+	    (g_access(settings.fnconfigure, F_OK) == -1) ||
 	    new_configs) {
 		/* must be first run */
 		GS_print((buf_says_empty
@@ -205,52 +202,27 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 	/* ensure that the user has a bible with which to work */
 	if (settings.havebible == 0) {
 		gui_init(argc, argv);
-		if (gui_yes_no_dialog(GS_NET_PERMISSION, NULL)) {
-			main_shutdown_list();
-			gui_open_mod_mgr_initial_run();
-			main_init_lists();
-			if (settings.havebible == 0) {
-				gui_generic_warning
-				    (_("There are still no Bibles installed.\nEvidently, you declined to install any.\n\nWithout any Bible modules to display,\nXiphos cannot proceed,\nand will now exit."));
-				exit(1);
-			} else
-				gui_generic_warning
-				    (_("Bible module installation complete."));
-		} else {
+		main_shutdown_list();
+		gui_open_mod_mgr_initial_run();
+		main_init_lists();
+		if (settings.havebible == 0) {
 			gui_generic_warning
-			    (_("Without any Bible modules to display,\nXiphos cannot proceed,\nand will now exit."));
+			    (_("There are no Bibles installed.\nEvidently, you declined to install any.\n\nWithout any Bible modules to display,\nXiphos cannot proceed,\nand will now exit."));
 			exit(1);
 		}
+		gui_generic_warning(_("Bible module installation complete."));
 	}
 
 	/* check for template.pad file for studypad */
-	tmp = g_new(char, strlen(settings.gSwordDir) +
-				     strlen("template.pad") + 2);
-	sprintf(tmp, "%s/%s", settings.gSwordDir,
-		"template.pad");
-
-	/* if template.pad does not exist create it */
-	if ((access(tmp, F_OK) == -1)) {
-		g_file_set_contents(tmp, " ", strlen(" "), NULL);
-	}
-
-	/* check for template.pad file for studypad */
-	/* set fnconfigure to gSwordDir and settings.xml */
-	tmp = g_new(char, strlen(settings.gSwordDir) +
-				     strlen("template.pad") + 2);
-	sprintf(tmp, "%s/%s", settings.gSwordDir,
-		"template.pad");
-
-	/* if template.pad does not exist create it */
-	if ((access(tmp, F_OK) == -1)) {
-		g_file_set_contents(tmp, " ", strlen(" "), NULL);
+	tmp = g_strdup_printf("%s/%s", settings.gSwordDir, "template.pad");
+	if ((g_access(tmp, F_OK) == -1)) {
+		g_file_set_contents(tmp, " ", 1, NULL);
 	}
+	g_free(tmp);
 
 	load_settings_structure();
 
-	/*
-	 * if the user had forced a locale, we must set it now.
-	 */
+	/* if the user had forced a locale, we must set it now. */
 	if (settings.special_locale && strcmp(settings.special_locale, NONE)) {
 		g_setenv("LANG", settings.special_locale, TRUE);
 		gchar *test = setlocale(LC_ALL, settings.special_locale);
@@ -303,12 +275,10 @@ int init_bookmarks(int new_bookmarks)
 	settings.load_xml_bookmarks = FALSE;
 
 	/* set bookmarks dir to settings.gSwordDir + /bookmarks */
-	settings.swbmDir = g_new(char, strlen(settings.gSwordDir) +
-				 strlen("/bookmarks") + 2);
-	sprintf(settings.swbmDir, "%s/%s", settings.gSwordDir, "bookmarks");
+	settings.swbmDir = g_strdup_printf("%s/%s", settings.gSwordDir, "bookmarks");
 
 	/* if .xiphos-2.0/bookmarks does not exist create it */
-	if (access(settings.swbmDir, F_OK) == -1) {
+	if (g_access(settings.swbmDir, F_OK) == -1) {
 		if ((Mkdir(settings.swbmDir, S_IRWXU)) == -1) {
 			g_warning("can't create bookmarks dir");
 			return 0;
@@ -316,10 +286,8 @@ int init_bookmarks(int new_bookmarks)
 	}
 
 	/* set removed dir to settings.swbmDir + /removed */
-	removed = g_new(char, strlen(settings.swbmDir) +
-				 strlen("/removed") + 2);
-	sprintf(removed, "%s/%s", settings.swbmDir, "removed");
-	if (access(removed, F_OK) == -1) {
+	removed = g_strdup_printf("%s/%s", settings.swbmDir, "removed");
+	if (g_access(removed, F_OK) == -1) {
 		if ((Mkdir(removed, S_IRWXU)) == -1) {
 			g_warning("can't create removed dir");
 			//return 0;
@@ -330,11 +298,9 @@ int init_bookmarks(int new_bookmarks)
 		xml_new_bookmark_file();
 
 	/* check for xml bookmarks */
-	file_buf = g_new(char, strlen(settings.swbmDir) +
-			 strlen("/bookmarks.xml") + 2);
-	sprintf(file_buf, "%s/bookmarks.xml", settings.swbmDir);
+	file_buf = g_strdup_printf("%s/bookmarks.xml", settings.swbmDir);
 
-	if (access(file_buf, F_OK) == 0) {
+	if (g_access(file_buf, F_OK) == 0) {
 		settings.load_xml_bookmarks = TRUE;
 	}
 	g_free(file_buf);
@@ -346,13 +312,9 @@ int init_bookmarks(int new_bookmarks)
 
 	/* check for Bibletime bookmarks */
 	settings.have_bibletime = FALSE;
-	file_buf = g_new(char, strlen(settings.homedir) +
-			 strlen
-			 ("/.kde/share/apps/bibletime/bookmarks.xml") +
-			 2);
-	sprintf(file_buf, "%s/.kde/share/apps/bibletime/bookmarks.xml",
-		settings.homedir);
-	if (access(file_buf, F_OK) == 0) {
+	file_buf = g_strdup_printf("%s/%s", settings.homedir,
+				   ".bibletime/bookmarks.xml");
+	if (g_access(file_buf, F_OK) == 0) {
 		settings.have_bibletime = TRUE;
 	}
 
@@ -384,7 +346,7 @@ int init_bookmarks(int new_bookmarks)
 
 void load_settings_structure(void)
 {
-	char *buf = NULL;
+	char *buf = NULL, *parallels;
 
 	settings.gs_version = VERSION;
 	if ((settings.MainWindowModule = xml_get_value("modules", "bible")) == NULL) {
@@ -393,11 +355,39 @@ void load_settings_structure(void)
 	}
 	settings.CommWindowModule = xml_get_value("modules", "comm");
 	settings.DictWindowModule = xml_get_value("modules", "dict");
-	settings.parallel1Module = xml_get_value("modules", "int1");
-	settings.parallel2Module = xml_get_value("modules", "int2");
-	settings.parallel3Module = xml_get_value("modules", "int3");
-	settings.parallel4Module = xml_get_value("modules", "int4");
-	settings.parallel5Module = xml_get_value("modules", "int5");
+
+	parallels = xml_get_value("modules", "parallels");
+	/* if no parallels are known, convert old fixed parallel set */
+	if (!parallels || (*parallels == '\0')) {
+		char intN[] = "intN", *oldparallel, i, *newhold;
+
+		g_free(parallels);	/* in case it was real but empty */
+		parallels = g_strdup("");
+		for (i = '1'; i <= '5'; ++i) {	/* the old set */
+			intN[3] = i;
+			oldparallel = xml_get_value("modules", intN);
+			if (oldparallel && *oldparallel) {
+				newhold = g_strconcat(parallels, oldparallel,
+						      ",", NULL);
+				g_free(parallels);
+				parallels = newhold;
+				g_free(oldparallel);
+				xml_remove_node("modules", intN, NULL); /* ? */
+			}
+		}
+
+		/* trim off the last comma */
+		if (*parallels) {
+			*(parallels + strlen(parallels) - 1) = '\0';
+			xml_set_new_element("modules", "parallels", parallels);
+		}
+	}
+	if (parallels && *parallels)
+		settings.parallel_list = g_strsplit(parallels, ",", -1);
+	else
+		settings.parallel_list = NULL;
+	g_free(parallels);
+
 	settings.personalcommentsmod = xml_get_value("modules", "percomm");
 	settings.devotionalmod = xml_get_value("modules", "devotional");
 	settings.book_mod = xml_get_value("modules", "book");
@@ -460,16 +450,8 @@ void load_settings_structure(void)
 		xml_add_new_item_to_section("modmgr", "mod_mgr_remote_source_index", "0");
 		settings.mod_mgr_remote_source_index = 0;
 	}
-	if ((buf = xml_get_value("modmgr", "mod_mgr_intro")))
-		settings.mod_mgr_intro = atoi(buf);
-	else {
-		xml_add_new_item_to_section("modmgr", "mod_mgr_intro", "0");
-		settings.mod_mgr_intro = 0;
-	}
-
-	/* end mod mgr stuff */
-
 
+	/* current verse & keys */
 	settings.currentverse = xml_get_value("keys", "verse");
 	settings.dictkey = xml_get_value("keys", "dictionary");
 
@@ -493,6 +475,7 @@ void load_settings_structure(void)
 		settings.tab_page = 0;
 	}
 
+	/* layout */
 	settings.sidebar_width = atoi((buf = xml_get_value("layout", "shortcutbar"))
 				      ? buf : "100");
 	if ((buf = xml_get_value("layout", "vltoppaneheight")))
@@ -501,15 +484,60 @@ void load_settings_structure(void)
 		xml_add_new_item_to_section("layout", "vltoppaneheight", "210");
 		settings.verselist_toppane_height = 210;
 	}
-	if ((buf = xml_get_value("layout", "sidebar_notebook_hight")))
-		settings.sidebar_notebook_hight = atoi(buf);
+	if ((buf = xml_get_value("layout", "sidebar_notebook_height")))
+		settings.sidebar_notebook_height = atoi(buf);
 	else {
-		xml_add_new_item_to_section("layout", "sidebar_notebook_hight", "300");
-		settings.sidebar_notebook_hight = 250;
+		if ((buf = xml_get_value("layout", "sidebar_notebook_hight"))) { /* backward compatible */
+			settings.sidebar_notebook_height = atoi(buf);
+			xml_remove_node("layout", "sidebar_notebook_hight", 0);
+		} else
+			settings.sidebar_notebook_height = 250;
+		buf = g_strdup_printf("%d", settings.sidebar_notebook_height);
+		xml_add_new_item_to_section("layout", "sidebar_notebook_height", buf);
+		g_free(buf);
 	}
-	settings.gs_hight = atoi((buf = xml_get_value("layout", "hight")) ? buf : "500");
-	settings.gs_width = atoi((buf = xml_get_value("layout", "width")) ? buf : "500");
 
+	/* whether to open the parallel page at startup */
+	if ((buf = xml_get_value("layout", "parallelopen")))
+		settings.parallelpage = atoi(buf);
+	else {
+		xml_add_new_item_to_section("layout", "parallelopen", "0");
+		settings.parallelpage = 0;
+	}
+
+	/* main and parallel window geometry */
+	if ((buf = xml_get_value("layout", "height")))
+		settings.gs_height = atoi(buf);
+	else {
+		if ((buf = xml_get_value("layout", "hight"))) {	/* backward compatible */
+			settings.gs_height = atoi(buf);
+			xml_remove_node("layout", "hight", 0);
+		} else
+			settings.gs_height = 500;
+		buf = g_strdup_printf("%d", settings.gs_height);
+		xml_add_new_item_to_section("layout", "height", buf);
+		g_free(buf);
+	}
+	if ((buf = xml_get_value("layout", "width")))
+		settings.gs_width = atoi(buf);
+	else{
+		xml_add_new_item_to_section("layout", "width", "500");
+		settings.gs_width = 500;
+	}
+	if ((buf = xml_get_value("layout", "parallel_height")))
+		settings.parallel_height = atoi(buf);
+	else {
+		xml_add_new_item_to_section("layout", "parallel_height", "361");
+		settings.parallel_height = 361;
+	}
+	if ((buf = xml_get_value("layout", "parallel_width")))
+		settings.parallel_width = atoi(buf);
+	else{
+		xml_add_new_item_to_section("layout", "parallel_width", "500");
+		settings.parallel_width = 657;
+	}
+
+	/* main window placement */
 	if ((buf = xml_get_value("layout", "app_x")))
 		settings.app_x = atoi(buf);
 	else {
@@ -523,25 +551,50 @@ void load_settings_structure(void)
 		settings.app_y = 40;
 	}
 
+	/* parallel window placement */
+	if ((buf = xml_get_value("layout", "parallel_x")))
+		settings.parallel_x = atoi(buf);
+	else {
+		xml_add_new_item_to_section("layout", "parallel_x", "200");
+		settings.parallel_x = 40;
+	}
+	if ((buf = xml_get_value("layout", "parallel_y")))
+		settings.parallel_y = atoi(buf);
+	else{
+		xml_add_new_item_to_section("layout", "parallel_y", "200");
+		settings.parallel_y = 40;
+	}
+
 	settings.biblepane_width = atoi((buf = xml_get_value("layout", "textpane"))
 					? buf : "0");
-	settings.upperpane_hight = atoi((buf = xml_get_value("layout", "uperpane"))
-					? buf : "0");
 
-	if ((buf = xml_get_value("layout", "biblehight")))
-		settings.biblepane_hight = atoi(buf);
+	if ((buf = xml_get_value("layout", "bibleheight")))
+		settings.biblepane_height = atoi(buf);
 	else {
-		xml_add_new_item_to_section("layout", "biblehight", "340");
-		settings.biblepane_hight = 250;
+		if ((buf = xml_get_value("layout", "biblehight"))) {	/* backward compatible */
+			settings.biblepane_height = atoi(buf);
+			xml_remove_node("layout", "biblehight", 0);
+		} else
+			settings.biblepane_height = 250;
+		buf = g_strdup_printf("%d", settings.biblepane_height);
+		xml_add_new_item_to_section("layout", "bibleheight", buf);
+		g_free(buf);
 	}
 
-	if ((buf = xml_get_value("layout", "commentaryhight")))
-		settings.commpane_hight = atoi(buf);
+	if ((buf = xml_get_value("layout", "commentaryheight")))
+		settings.commpane_height = atoi(buf);
 	else {
-		xml_add_new_item_to_section("layout", "commentaryhight", "240");
-		settings.commpane_hight = 240;
+		if ((buf = xml_get_value("layout", "commentaryhight"))) { /* backward compatible */
+			settings.commpane_height = atoi(buf);
+			xml_remove_node("layout", "commentaryhight", 0);
+		} else
+			settings.commpane_height = 240;
+		buf = g_strdup_printf("%d", settings.commpane_height);
+		xml_add_new_item_to_section("layout", "commentaryheight", buf);
+		g_free(buf);
 	}
 
+	/* font sizes */
 	if ((buf = xml_get_value("fontsize", "versenum"))) {
 		settings.verse_num_font_size_str = buf;
 		settings.verse_num_font_size = atoi(buf);
@@ -565,6 +618,7 @@ void load_settings_structure(void)
 #endif /* WIN32 */
 	}
 
+	/* colors */
 	settings.bible_text_color = xml_get_value("HTMLcolors", "text_fg");
 	settings.bible_bg_color =
 	    xml_get_value("HTMLcolors", "background");
@@ -589,7 +643,6 @@ void load_settings_structure(void)
 	}
 
 	/*  parallel ops  */
-
 	if ((buf = xml_get_value("parallel", "Strong_s_Numbers")))
 		settings.parallel_strongs = atoi(buf);
 	else {
@@ -621,8 +674,8 @@ void load_settings_structure(void)
 	if ((buf = xml_get_value("parallel", "Footnotes")))
 		settings.parallel_footnotes = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "Footnotes", "0");
-		settings.parallel_footnotes = 0;
+		xml_add_new_item_to_section("parallel", "Footnotes", "1");
+		settings.parallel_footnotes = 1;
 	}
 
 	if ((buf = xml_get_value("parallel", "Cross-references")))
@@ -642,8 +695,8 @@ void load_settings_structure(void)
 	if ((buf = xml_get_value("parallel", "Words_of_Christ_in_Red")))
 		settings.parallel_red_words = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "Words_of_Christ_in_Red", "0");
-		settings.parallel_red_words = 0;
+		xml_add_new_item_to_section("parallel", "Words_of_Christ_in_Red", "1");
+		settings.parallel_red_words = 1;
 	}
 
 	if ((buf = xml_get_value("parallel", "Morpheme_Segmentation")))
@@ -656,8 +709,8 @@ void load_settings_structure(void)
 	if ((buf = xml_get_value("parallel", "Headings")))
 		settings.parallel_headings = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "Headings", "0");
-		settings.parallel_headings = 0;
+		xml_add_new_item_to_section("parallel", "Headings", "1");
+		settings.parallel_headings = 1;
 	}
 
 	if ((buf = xml_get_value("parallel", "Lemmas")))
@@ -695,10 +748,6 @@ void load_settings_structure(void)
 		settings.parallel_greekaccents = 1;
 	}
 
-	if ((buf = xml_get_value("parallel", "parallel")))
-		settings.parallelpage = atoi(buf);
-
-
 	/*  Misc stuff  */
 
 	settings.showtexts = atoi((buf = xml_get_value("misc", "showtexts")) ? buf : "1");
@@ -714,8 +763,8 @@ void load_settings_structure(void)
 	if (xml_get_value("misc", "show_side_preview"))
 		settings.show_previewer_in_sidebar = atol(xml_get_value("misc", "show_side_preview"));
 	else {
-		xml_add_new_item_to_section("misc", "show_side_preview", "0");
-		settings.show_previewer_in_sidebar = 0;
+		xml_add_new_item_to_section("misc", "show_side_preview", "1");
+		settings.show_previewer_in_sidebar = 1;
 	}
 
 	if (xml_get_value("misc", "showparatab"))
@@ -760,11 +809,18 @@ void load_settings_structure(void)
 		settings.versehighlight = 0;
 	}
 
-	if ((buf = xml_get_value("misc", "doublespace")))
-		settings.doublespace = atoi(buf);
+	if ((buf = xml_get_value("misc", "annotatehighlight")))
+		settings.annotate_highlight = atoi(buf);
 	else {
-		xml_add_new_item_to_section("misc", "doublespace", "0");
-		settings.doublespace = 0;
+		xml_add_new_item_to_section("misc", "annotatehighlight", "1");
+		settings.annotate_highlight = 1;
+	}
+
+	if ((buf = xml_get_value("misc", "xrefsinverselist")))
+		settings.xrefs_in_verse_list = atoi(buf);
+	else {
+		xml_add_new_item_to_section("misc", "xrefsinverselist", "1");
+		settings.xrefs_in_verse_list = 1;
 	}
 
 	if ((buf = xml_get_value("misc", "chapter-scroll"))) {
@@ -812,11 +868,14 @@ void load_settings_structure(void)
 		settings.prayerlist = 1;
 	}
 
-
+#if 1
+	settings.browsing = 1;	/* unconditional - no longer toggle-able. */
+#else
 	if ((buf = xml_get_value("tabs", "browsing"))) {
 		settings.browsing =  atoi(buf);
 	} else {
 		xml_add_new_item_to_section("tabs","browsing","1");
 		settings.browsing = 1;
 	}
+#endif
 }
