@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * utilities.c - support functions
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -137,7 +137,6 @@ void main_display_verse_list_in_sidebar(gchar * key,
 					gchar * verse_list)
 {
 	GList *tmp = NULL;
-	gint i = 0;
 	GtkTreeModel *model;
 	GtkListStore *list_store;
 	GtkTreeSelection *selection;
@@ -172,25 +171,35 @@ void main_display_verse_list_in_sidebar(gchar * key,
 
 	strcpy(sidebar.mod_name, module_name);
 
-	if (verse_list[0] == 'S' && verse_list[1] == 'e'
-	    && verse_list[2] == 'e') {
+	if (!strncmp(verse_list, "See ", 4))
 		verse_list += 4;
-	}
-	i = 0;
-	tmp = backend->parse_verse_list(verse_list, key);
-	while (tmp != NULL) {
-		gtk_list_store_append(list_store, &iter);
-		gtk_list_store_set(list_store, &iter, 0,
-				   (const char *) tmp->data, -1);
-		++i;
+	
+	if ((*verse_list != '/') &&
+	    ((tmp = backend->parse_verse_list(verse_list, key)) != NULL)) {
+		// normal verse list.
+		while (tmp != NULL) {
+			gtk_list_store_append(list_store, &iter);
+			gtk_list_store_set(list_store, &iter, 0,
+					   (const char *) tmp->data, -1);
 
-		list_item = g_new(RESULTS,1);
+			list_item = g_new(RESULTS, 1);
+			list_item->module = g_strdup(module_name);
+			list_item->key = g_strdup((const char *) tmp->data);
+			list_of_verses = g_list_append(list_of_verses,
+						       (RESULTS *) list_item);
+
+			tmp = g_list_next(tmp);
+		}
+	} else {
+		// not normal verse list.  probably a genbook or dict key.
+		gtk_list_store_append(list_store, &iter);
+		gtk_list_store_set(list_store, &iter, 0, verse_list, -1);
+
+		list_item = g_new(RESULTS, 1);
 		list_item->module = g_strdup(module_name);
-		list_item->key = g_strdup((const char *) tmp->data);
+		list_item->key = g_strdup((const char *) verse_list);
 		list_of_verses = g_list_append(list_of_verses,
 					       (RESULTS *) list_item);
-
-		tmp = g_list_next(tmp);
 	}
 
 	selection = gtk_tree_view_get_selection
@@ -356,6 +365,8 @@ void main_create_pixbufs(void)
 }
 
 
+#ifdef ALLOW_BIBLE_NAVIGATION_FROM_SIDEBAR_TREE
+
 /******************************************************************************
  * Name
  *  main_add_verses_to_chapter
@@ -372,7 +383,6 @@ void main_create_pixbufs(void)
  * Return value
  *   void
  */
-#if 0
 static void add_verses_to_chapter(GtkTreeModel * model,
 				  GtkTreeIter iter, const gchar * key)
 {
@@ -419,7 +429,6 @@ static void add_verses_to_chapter(GtkTreeModel * model,
 }
 
 
-
 /******************************************************************************
  * Name
  *  main_add_chapters_to_book
@@ -510,13 +519,9 @@ static void add_books_to_bible(GtkTreeModel * model, GtkTreeIter iter,
 			   COL_OPEN_PIXBUF, pixbufs->pixbuf_opened, -1);
 	if (backend->module_has_testament(mod_name, 1)) {
 		while (j < key.BMAX[0]) {
-#ifdef SWORD_MULTIVERSE
 			key.Testament(1);
 			key.Book(j+1);
 			buf = strdup((gchar *) key.getBookName());
-#else
-			buf = strdup((gchar *) key.books[0][j].name);
-#endif
 			gchar *key = g_strdup_printf("book://%s/%s 1:1",
 						     mod_name, buf);
 			gtk_tree_store_append(GTK_TREE_STORE(model),
@@ -539,13 +544,9 @@ static void add_books_to_bible(GtkTreeModel * model, GtkTreeIter iter,
 	j = 0;
 	if (backend->module_has_testament(mod_name, 2)) {
 		while (j < key.BMAX[1]) {
-#ifdef SWORD_MULTIVERSE
 			key.Testament(2);
 			key.Book(j+1);
 			buf = strdup((gchar *) key.getBookName());
-#else
-			buf = strdup((gchar *) key.books[1][j].name);
-#endif
 			gchar *key = g_strdup_printf("book://%s/%s 1:1",
 						     mod_name, buf);
 			gtk_tree_store_append(GTK_TREE_STORE(model),
@@ -566,7 +567,7 @@ static void add_books_to_bible(GtkTreeModel * model, GtkTreeIter iter,
 		}
 	}
 }
-#endif
+#endif /* ALLOW_BIBLE_NAVIGATION_FROM_SIDEBAR_TREE */
 
 #ifdef USE_TREEVIEW_PATH
 gboolean main_expand_treeview_to_path (GtkTreeModel *model, GtkTreeIter iter)
@@ -633,9 +634,6 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 	gchar *mod = NULL;
 	gchar *key = NULL;
 	GtkTreePath *path;
-	/*  *** until after 3.1 ***
-	gchar *path_str = NULL;
-	*/
 
 	static int old_page = 0;
 
@@ -643,9 +641,10 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 			   &mod, 4, &key, -1);
 	if (!cap)
 		return;
+
 	if (!g_utf8_collate(cap, _("Parallel View"))) {
 		if (settings.dockedInt) {
-			gtk_notebook_set_current_page (GTK_NOTEBOOK
+			gtk_notebook_set_current_page(GTK_NOTEBOOK
 					      (widgets.
 					       notebook_bible_parallel),
 					      1);
@@ -660,7 +659,6 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 				GTK_NOTEBOOK (widgets.notebook_main),
 				widgets.parallel_tab));
 		}
-
 	}
 
 	if (!g_utf8_collate(cap, _("Standard View"))) {
@@ -706,7 +704,9 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 					       notebook_bible_parallel),
 					      0);
 		// MainWindowModule is set in main_bible_display(), not here.
-		/*if (!gtk_tree_model_iter_has_child
+
+#ifdef ALLOW_BIBLE_NAVIGATION_FROM_SIDEBAR_TREE
+		if (!gtk_tree_model_iter_has_child
 		    (GTK_TREE_MODEL(model), &selected)
 		    && !key)
 			add_books_to_bible(model, selected, mod);
@@ -718,7 +718,7 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 		    (GTK_TREE_MODEL(model), &selected)
 		    && strstr(key, "chapter:"))
 			add_verses_to_chapter(model, selected, key);
-		*/
+#endif
 
 		if (!GTK_CHECK_MENU_ITEM(widgets.viewtexts_item)->active) {
 			GTK_CHECK_MENU_ITEM(widgets.viewtexts_item)->active = 1;
@@ -730,8 +730,8 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 			main_url_handler(key, TRUE);
 		else
 			main_display_bible(mod, settings.currentverse);
-
 		break;
+
 	case COMMENTARY_TYPE:
 	case PERCOM_TYPE:
 		gtk_notebook_set_current_page(GTK_NOTEBOOK
@@ -745,18 +745,18 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 			on_show_commentary_activate
 			    (GTK_MENU_ITEM(widgets.viewcomms_item), NULL);
 		}
-
 		main_display_commentary(mod, settings.currentverse);
 		break;
+
 	case DICTIONARY_TYPE:
 		if (!GTK_CHECK_MENU_ITEM(widgets.viewdicts_item)->active) {
 			GTK_CHECK_MENU_ITEM(widgets.viewdicts_item)->active = 1;
 			on_show_dictionary_lexicon_activate
 			    (GTK_MENU_ITEM(widgets.viewcomms_item), NULL);
 		}
-
 		main_display_dictionary(mod, settings.dictkey);
 		break;
+
 	case BOOK_TYPE:
 	case PRAYERLIST_TYPE:
 		GS_message(("key %s", (key ? key : "-null-")));
@@ -770,24 +770,21 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 		if (!gtk_tree_model_iter_has_child
 		    (GTK_TREE_MODEL(model), &selected)
 		    && !key) {
-			add_children_to_tree(model,
-					     selected,
-					     mod,
-					     0);
+			add_children_to_tree(model, selected, mod, 0);
 		}
 		if (!gtk_tree_model_iter_has_child
 		    (GTK_TREE_MODEL(model), &selected)
 		    && backend->treekey_has_children(key ? atoi(key) : 0)) {
-			add_children_to_tree(model,
-					     selected, mod, atol(key));
+			add_children_to_tree(model, selected, mod, atol(key));
 		}
 
-		/*  *** until after 3.1 ***
-		path_str = gtk_tree_path_to_string (path);
-		//GS_message (("path: %s", path_str));
+#ifdef USE_TREEVIEW_PATH
+		gchar *path_str = gtk_tree_path_to_string (path);
+		GS_message (("path: %s", path_str));
 		gui_save_treeview_path_string (path_str, mod);
 		g_free (path_str);
-		*/
+#endif /* USE_TREEVIEW_PATH */
+
 		gtk_tree_view_expand_row(GTK_TREE_VIEW
 					 (sidebar.module_list), path,
 					 FALSE);
@@ -804,14 +801,9 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 		main_setup_navbar_book(mod, (key ? atoi(key) : 0));
 		break;
 	}
-	if (cap)
-		g_free(cap);
-	if (mod)
-		g_free(mod);
-	if (key)
-		g_free(key);
-
-
+	g_free(cap);
+	g_free(mod);
+	g_free(key);
 }
 
 
@@ -974,10 +966,12 @@ void main_load_module_tree(GtkWidget * tree)
 	GtkTreeIter text;
 	GtkTreeIter commentary;
 	GtkTreeIter dictionary;
+	GtkTreeIter glossary;
 	GtkTreeIter devotional;
 	GtkTreeIter book;
 	GtkTreeIter map;
 	GtkTreeIter image;
+	GtkTreeIter cult;
 	GtkTreeIter prayerlist;
 	GtkTreeIter child_iter;
 	GList *tmp = NULL;
@@ -1034,6 +1028,15 @@ void main_load_module_tree(GtkWidget * tree)
 			   COL_MODULE, NULL,
 			   COL_OFFSET, _("Dictionaries"), -1);
 
+	/*  Glossaries folders */
+	gtk_tree_store_append(store, &glossary, NULL);
+	gtk_tree_store_set(store, &glossary,
+			   COL_OPEN_PIXBUF, pixbufs->pixbuf_opened,
+			   COL_CLOSED_PIXBUF, pixbufs->pixbuf_closed,
+			   COL_CAPTION, _("Glossaries"),
+			   COL_MODULE, NULL,
+			   COL_OFFSET, _("Glossaries"), -1);
+
 	/*  Devotionals folders */
 	gtk_tree_store_append(store, &devotional, NULL);
 	gtk_tree_store_set(store, &devotional,
@@ -1070,6 +1073,15 @@ void main_load_module_tree(GtkWidget * tree)
 			   COL_MODULE, NULL,
 			   COL_OFFSET, _("Images"), -1);
 
+	/*  Cult/Unorthodox/Questionable folders */
+	gtk_tree_store_append(store, &cult, NULL);
+	gtk_tree_store_set(store, &cult,
+			   COL_OPEN_PIXBUF, pixbufs->pixbuf_opened,
+			   COL_CLOSED_PIXBUF, pixbufs->pixbuf_closed,
+			   COL_CAPTION, _("Cult/Unorthodox"),
+			   COL_MODULE, NULL,
+			   COL_OFFSET, _("Cult/Unorthodox"), -1);
+
 	/*  Prayer lists folder */
 	if (settings.prayerlist) {
 		gtk_tree_store_append(store, &prayerlist, NULL);
@@ -1085,9 +1097,9 @@ void main_load_module_tree(GtkWidget * tree)
 
 	language_make_list(tmp, store,
 			   text, commentary, map, image,
-			   devotional, dictionary, book,
+			   devotional, dictionary, glossary, book, cult,
 			   NULL, NULL,
-			   language_add_folders);
+			   language_add_folders, FALSE);
 
 	// fast-n-loose w/known string values to avoid pointless strcmp costs.
 	// TEXT_MODS => 'B' ("Biblical Texts")
@@ -1102,7 +1114,12 @@ void main_load_module_tree(GtkWidget * tree)
 	while (tmp2 != NULL) {
 		info = (MOD_MGR *) tmp2->data;
 
-		if (info->type[0] == 'B') {
+		if (info->is_cult) {
+			add_module_to_language_folder(GTK_TREE_MODEL(store),
+						      cult, info->language,
+						      info->name);
+		}
+		else if (info->type[0] == 'B') {
 			add_module_to_language_folder(GTK_TREE_MODEL(store),
 						      text, info->language,
 						      info->name);
@@ -1127,6 +1144,11 @@ void main_load_module_tree(GtkWidget * tree)
 						      devotional, info->language,
 						      info->name);
 		}
+		else if (info->is_glossary) {
+			add_module_to_language_folder(GTK_TREE_MODEL(store),
+						      glossary, info->language,
+						      info->name);
+		}
 		else if (info->type[0] == 'L') {
 			add_module_to_language_folder(GTK_TREE_MODEL(store),
 						      dictionary, info->language,
