@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * sword.cc - glue
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -57,6 +57,8 @@ extern "C" {
 #include "gui/xiphos.h"
 #include "gui/sidebar.h"
 #include "gui/utilities.h"
+#include "gui/cipher_key_dialog.h"
+#include "gui/main_menu.h"
 
 #include "main/display.hh"
 #include "main/lists.h"
@@ -68,8 +70,9 @@ extern "C" {
 #include "main/sword.h"
 #include "main/url.hh"
 #include "main/xml.h"
-
 #include "main/parallel_view.h"
+#include "main/modulecache.hh"
+
 #include "backend/sword_main.hh"
 #include "backend/gs_stringmgr.h"
 
@@ -89,7 +92,6 @@ extern GtkWidget *spb_verse;
 extern GtkWidget *cbe_freeform_lookup;
 extern gboolean shift_key_pressed;
 
-gboolean style_display = TRUE;
 char *sword_locale = NULL;
 gboolean companion_activity = FALSE;
 
@@ -173,9 +175,9 @@ void main_chapter_heading(char * mod_name)
  *   void
  */
 
-void main_save_note(	const gchar * module_name,
-			const gchar * key_str,
-			const gchar * note_str )
+void main_save_note(const gchar * module_name,
+		    const gchar * key_str,
+		    const gchar * note_str)
 {
 	// Massage encoded spaces ("%20") back to real spaces.
 	// This is a sick. unreliable hack that should be removed
@@ -215,7 +217,8 @@ void main_save_note(	const gchar * module_name,
  *   void
  */
 
-void main_delete_note(	const gchar * module_name, const gchar * key_str)
+void main_delete_note(const gchar * module_name,
+		      const gchar * key_str)
 {
 	backend->set_module_key(module_name, key_str);
 	GS_message(("note module %s\nnote key %s\n",
@@ -245,7 +248,7 @@ void main_delete_note(	const gchar * module_name, const gchar * key_str)
  *   void
  */
 
-void main_set_module_unlocked(char * mod_name, char * key)
+void main_set_module_unlocked(const char * mod_name, char * key)
 {
 	SWMgr *mgr = backend->get_mgr();
 	mgr->setCipherKey(mod_name, key);
@@ -268,9 +271,9 @@ void main_set_module_unlocked(char * mod_name, char * key)
  *   void
  */
 
-void main_save_module_key(char * mod_name, char * key)
+void main_save_module_key(const char * mod_name, char * key)
 {
-	backend->save_module_key(mod_name, key);
+	backend->save_module_key((char *) mod_name, key);
 }
 
 
@@ -598,6 +601,11 @@ const char *main_get_language_map(const char *language) {
 	return languageMap[language].c_str();
 }
 
+char **main_get_module_language_list(void)
+{
+	return backend->get_module_language_list();
+}
+
 
 /******************************************************************************
  * Name
@@ -638,10 +646,9 @@ char *set_sword_locale(const char *sys_locale)
 	}
 
 	// either we were given a null sys_locale, or it didn't match anything.
-	char *err = g_strdup_printf("%s `%s'.\n%s.",
-				    _("No matching locale found for"),
+	char *err = g_strdup_printf(_("No matching locale found for `%s'.\n%s"),
 				    sys_locale,
-				    _("Book names and menus may not be translated"));
+				    _("Book names and menus may not be translated."));
 	gui_generic_warning(err);
 	g_free(err);
 	return NULL;
@@ -751,6 +758,8 @@ void main_dictionary_entry_changed(char * mod_name)
 	xml_set_value("Xiphos", "keys", "dictionary", key);
 	settings.dictkey = xml_get_value("keys", "dictionary");
 
+	main_check_unlock(mod_name, TRUE);
+
 	backend->set_module_key(mod_name, key);
 	backend->display_mod->Display();
 
@@ -810,6 +819,8 @@ GtkWidget *main_dictionary_drop_down_new(char * mod_name, char * old_key)
 	xml_set_value("Xiphos", "keys", "dictionary", key);
 	settings.dictkey = xml_get_value("keys", "dictionary");
 
+	main_check_unlock(mod_name, TRUE);
+
 	backend->set_module_key(mod_name, key);
 	backend->display_mod->Display();
 
@@ -878,12 +889,13 @@ void main_dictionary_button_clicked(gint direction)
 	g_free(key);
 }
 
-void main_display_book(const char * mod_name, const char * key)     //, unsigned long offset)
+void main_display_book(const char * mod_name,
+		       const char * key)
 {
 	if (!settings.havebook || !mod_name)
 		return;
 
-	if (key == NULL)  // && offset == -1)
+	if (key == NULL)
 		key = "0";
 
 	GS_message(("main_display_book\nmod_name: %s\nkey: %s", mod_name, key));
@@ -917,6 +929,8 @@ void main_display_book(const char * mod_name, const char * key)     //, unsigned
 		backend->set_treekey(settings.book_offset);
 	}
 
+	main_check_unlock(mod_name, TRUE);
+
 	backend->display_mod->Display();
 	main_setup_navbar_book(settings.book_mod, settings.book_offset);
 	//if (settings.browsing)
@@ -933,7 +947,8 @@ void main_display_book(const char * mod_name, const char * key)     //, unsigned
 				      settings.showdicts);
 }
 
-void main_display_commentary(const char * mod_name, const char * key)
+void main_display_commentary(const char * mod_name,
+			     const char * key)
 {
 	if (!settings.havecomm || !settings.comm_showing)
 		return;
@@ -973,6 +988,8 @@ void main_display_commentary(const char * mod_name, const char * key)
 		if (companion) g_free(companion);
 	}
 
+	main_check_unlock(mod_name, TRUE);
+
 	backend->set_module_key(mod_name, key);
 	backend->display_mod->Display();
 
@@ -990,7 +1007,8 @@ void main_display_commentary(const char * mod_name, const char * key)
 				      settings.showdicts);
 }
 
-void main_display_dictionary(const char * mod_name, const char * key)
+void main_display_dictionary(const char * mod_name,
+			     const char * key)
 {
 	const gchar *old_key;
 
@@ -1060,7 +1078,8 @@ void main_display_dictionary(const char * mod_name, const char * key)
 }
 
 
-void main_display_bible(const char * mod_name, const char * key)
+void main_display_bible(const char * mod_name,
+			const char * key)
 {
 	gchar *file = NULL;
 	gchar *style = NULL;
@@ -1129,18 +1148,14 @@ void main_display_bible(const char * mod_name, const char * key)
 
 	file = g_strdup_printf("%s/modops.conf", settings.gSwordDir);
 	style = get_conf_file_item(file, mod_name, "style");
-	if ((style) && strcmp(style,"verse"))
-		settings.versestyle = FALSE;
-	else
+	if ((style) && !strcmp(style,"verse"))
 		settings.versestyle = TRUE;
+	else
+		settings.versestyle = FALSE;
 	g_free(style);
 	g_free(file);
 
-	style_display = FALSE;
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
-				       (widgets.versestyle_item),
-				       settings.versestyle);
-	style_display = TRUE;
+	main_check_unlock(mod_name, TRUE);
 
 	if (backend->module_has_testament(mod_name,
 				backend->get_key_testament(key))) {
@@ -1250,13 +1265,13 @@ void main_display_devotional(void)
 
 
 	text = backend->get_render_text(settings.devotionalmod, buf);
-//	g_message("modname: %s\nloctime: %s\ntext: %s",settings.devotionalmod, buf, text);
+	
 	if (text) {
 		main_entry_display(settings.show_previewer_in_sidebar
 				     ? sidebar.html_viewer_widget
 				     : widgets.html_previewer_text,
 			      settings.devotionalmod, text, buf, TRUE);
-		free(text);
+		g_free(text);
 	}
 }
 
@@ -1457,7 +1472,64 @@ int main_is_mod_rtol(const char * module_name)
 
 int main_has_cipher_tag(char *mod_name)
 {
-	return (backend->get_config_entry(mod_name, (char *)"CipherKey") != NULL);
+	gchar *cipherkey = backend->get_config_entry(mod_name, (char *)"CipherKey");
+	int retval = (cipherkey != NULL);
+	g_free(cipherkey);
+	return retval;
+}
+
+
+#define	CIPHER_INTRO	\
+_("<b>Locked Module.</b>\n\n<u>You are opening a module which requires a <i>key</i>.</u>\n\nThe module is locked, meaning that the content is encrypted by its publisher, and you must enter its key in order for the content to become useful.  This key should have been received by you on the web page which confirmed your purchase, or perhaps sent via email after purchase.\n\nPlease enter the key in the dialog.")
+
+/******************************************************************************
+ * Name
+ *  main_check_unlock
+ *
+ * Synopsis
+ *   #include "main/.h"
+ *
+ *   int main_check_unlock(const char *mod_name)
+ *
+ * Description
+ *
+ *
+ * Return value
+ *   int
+ */
+
+void main_check_unlock(const char *mod_name, gboolean conditional)
+{
+	gchar *cipher_old, *cipher_key;
+
+	cipher_old = main_get_mod_config_entry(mod_name, "CipherKey");
+
+	/* if forced by the unlock menu item, or it's present but empty... */
+	if (!conditional ||					
+	    ((cipher_old != NULL) && (*cipher_old == '\0'))) {
+
+		if (conditional) {
+			GtkWidget *dialog;
+			dialog = gtk_message_dialog_new_with_markup
+			    (NULL,	/* no need for a parent window */
+			     GTK_DIALOG_DESTROY_WITH_PARENT,
+			     GTK_MESSAGE_INFO,
+			     GTK_BUTTONS_OK,
+			     CIPHER_INTRO);
+			g_signal_connect_swapped(dialog, "response",
+						 G_CALLBACK(gtk_widget_destroy),
+						 dialog);
+			gtk_widget_show(dialog);
+		}
+
+		cipher_key = gui_add_cipher_key(mod_name, cipher_old);
+		if (cipher_key) {
+			ModuleCacheErase(mod_name);
+			redisplay_to_realign();
+			g_free(cipher_key);
+		}
+	}
+	g_free(cipher_old);
 }
 
 
