@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * sword.h - glue
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -76,8 +76,8 @@ GtkWidget *main_dictionary_drop_down_new(char * mod_name, char * old_key);
 char *main_get_path_to_mods(void);
 const char *main_get_sword_version(void);
 void main_shutdown_backend(void);
-void main_set_module_unlocked(char * mod_name, char * key);
-void main_save_module_key(char * mod_name, char * key);
+void main_set_module_unlocked(const char * mod_name, char * key);
+void main_save_module_key(const char * mod_name, char * key);
 gchar *main_update_nav_controls(const gchar * key);
 char *main_get_active_pane_key(void);
 char *main_get_active_pane_module(void);
@@ -97,6 +97,7 @@ void main_dictionary_button_clicked(gint direction);
 const char *main_get_module_language(const char *module_name);
 int main_check_for_global_option(char * mod_name, char * option);
 int main_has_cipher_tag(char *mod_name);
+void main_check_unlock(const char *mod_name, gboolean conditional);
 int main_is_module(char * mod_name);
 int main_has_search_framework(char *mod_name);
 int main_optimal_search(char *mod_name);
@@ -120,6 +121,7 @@ void main_flush_widgets_content(void);
 gboolean main_is_Bible_key(gchar *key);
 const char* main_get_osisref_from_key(const char *module, const char *key);
 const char *main_get_language_map(const char *language);
+char **main_get_module_language_list(void);
 void main_init_language_map(void);
 
 #ifdef __cplusplus
