@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * sword_treekey.cc - treekey stuff for book editor
  *
- * Copyright (C) 2008-2009 Xiphos Developer Team
+ * Copyright (C) 2008-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -324,19 +324,3 @@ void main_load_book_tree_in_editor (GtkTreeView * treeview, char *book)
 	gtk_tree_store_append (GTK_TREE_STORE (store), &parent, NULL);
 	load_treeview (store, &parent, root);
 }
-
-
-
-void add_prayer_list_sections (RawGenBook * book, TreeKeyIdx * treeKey)
-{
-	appendChild (treeKey, _("Growth"));
-	setEntryText (book, _("<b>For Growth</b><br>"));
-	appendSibbling (treeKey, _("Salvation"));
-	setEntryText (book, _("<b>For Salvation</b><br>"));
-	appendSibbling (treeKey, _("Health"));
-	setEntryText (book, _("<b>For Health</b><br>"));
-	appendSibbling (treeKey, "Misc");
-	setEntryText (book, _("<b>Miscellaneous</b><br>"));
-
-	treeKey->parent ();
-}
