@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * url.cc - support functions
  *
- * Copyright (C) 2004-2009 Xiphos Developer Team
+ * Copyright (C) 2004-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@
 #include <swmodule.h>
 
 #include <gtk/gtk.h>
+#include <glib/gstdio.h>
 
 #include "editor/slib-editor.h"
 
@@ -170,7 +171,7 @@ static gint show_separate_image(const gchar * filename, gboolean clicked)
 		int i;
 
 		for (i = 0; display_progs[i]; i++) {
-			if (access(display_progs[i], X_OK) == 0)
+			if (g_access(display_progs[i], X_OK) == 0)
 				break;
 		}
 		if (display_progs[i] == NULL) {
@@ -364,7 +365,7 @@ static gint show_strongs(const gchar * stype, const gchar * svalue,
 
 	}*/
 
-	if (!strcmp(settings.MainWindowModule,"NASB")) {
+	if (!strncmp(settings.MainWindowModule, "NASB", 4)) {
 		if (!strcmp(stype,"Greek"))
 			modbuf = "NASGreek";
 		else
@@ -423,10 +424,9 @@ static gint show_note(const gchar * module, const gchar * passage,
 	gchar *buf = NULL;
 	gchar *work_buf = NULL;
 	GString *str = g_string_new(NULL);
-	GList *tmp = NULL;
-	RESULTS *list_item;
+	GList *vlist = NULL, *chaser = NULL;
 
-	if (!in_url)
+	if (!in_url || !svalue || !*svalue)
 		return 1;
 
 	if (!backend->is_module((gchar*)module))
@@ -486,50 +486,40 @@ static gint show_note(const gchar * module, const gchar * passage,
 		tmpbuf = backend->get_entry_attribute("Footnote",
 						      (gchar*)svalue,
 						      "refList");
-		list_of_verses = g_list_first(list_of_verses);
-		if (list_of_verses) {
-			GList *chaser = list_of_verses;
-			while (chaser) {
-				list_item = (RESULTS*)chaser->data;
-				g_free(list_item->module);
-				g_free(list_item->key);
-				g_free(list_item);
+		if (settings.xrefs_in_verse_list) {
+			main_display_verse_list_in_sidebar(settings.
+							   currentverse,
+							   (gchar*)module,
+							   tmpbuf);
+			g_free(tmpbuf);
+		} else {
+			vlist = chaser = backend->parse_verse_list(tmpbuf, settings.currentverse);
+			while (chaser != NULL) {
+				buf = g_strdup_printf(
+				    "<a href=\"sword://%s/%s\">"
+				    "<font color=\"%s\">%s,</font></a><br/>",
+				    (gchar*)module,
+				    (const char *) chaser->data,
+				    settings.bible_text_color,
+				    (const char *) chaser->data);
+				str = g_string_append(str, buf);
+				g_free(buf);
+				g_free((char *)chaser->data);
 				chaser = g_list_next(chaser);
 			}
-			g_list_free(list_of_verses);
-			list_of_verses = NULL;
-		}
+			g_list_free(vlist);
+			g_free(tmpbuf);
 
-		tmp = backend->parse_verse_list(tmpbuf, settings.currentverse);
-		while (tmp != NULL) {
-			buf = g_strdup_printf(
-				"<a href=\"sword://%s/%s\">"
-				"<font color=\"%s\">%s,</font></a><br>",
-				(gchar*)module,
-				(const char *) tmp->data,
-				settings.bible_text_color,
-				(const char *) tmp->data);
-			str = g_string_append(str,buf);
-			if (buf) g_free(buf);
-			buf = NULL;
-			//++i;
-			g_free((char *) tmp->data);
-			tmp = g_list_next(tmp);
-		}
-		g_list_free(tmp);
+			buf = g_strdup_printf("<a href=\"sword://%s/%s\">"
+					      "<font color=\"%s\">%s%s</font></a><br/>",
+					      (gchar*)module,
+					      settings.currentverse,
+					      settings.bible_text_color,
+					      _("Back to "),
+					      settings.currentverse);
+			str = g_string_append(str, buf);
+			g_free(buf);
 
-		buf = g_strdup_printf("<a href=\"sword://%s/%s\">"
-				      "<font color=\"%s\">%s%s</font></a><br>",
-				      (gchar*)module,
-				      settings.currentverse,
-				      settings.bible_text_color,
-				      _("Back to "),
-				      settings.currentverse);
-		str = g_string_append(str,buf);
-		if (buf) g_free(buf);
-
-		if (tmpbuf) g_free(tmpbuf);
-		if (str) {
 			main_information_viewer((gchar*)module,
 						str->str,
 						(gchar*)svalue,
@@ -544,7 +534,7 @@ static gint show_note(const gchar * module, const gchar * passage,
 		vkey->AutoNormalize(oldAutoNorm);
 	if (work_buf)
 		g_free(work_buf);
-	g_string_free(str, 1);
+	g_string_free(str, TRUE);
 	return 1;
 }
 
@@ -601,7 +591,6 @@ static gint show_ref(const gchar * module, const gchar * list, gboolean clicked)
 static int show_module_and_key(const char * module, const char * key,
 					const char * stype, gboolean clicked)
 {
-	gchar *tmpkey = NULL;
 	gint mod_type;
 
 	if (module && (strlen((char*)module) < 3) &&
@@ -784,6 +773,17 @@ gint sword_uri(const gchar * url, gboolean clicked)
 		    work_buf[MODULE],
 		    (work_buf[KEY] ? work_buf[KEY] : "-null-")));
 
+	if (tmpkey && strpbrk(tmpkey, "-;,")) {	// >1 verse marked
+		main_display_verse_list_in_sidebar
+		    (settings.currentverse,
+		     (work_buf[MODULE] && *work_buf[MODULE]
+		      ? work_buf[MODULE]
+		      : settings.MainWindowModule),
+		     tmpkey);
+		handling_uri = FALSE;
+		return 1;
+	}
+
 	verse_count = 1; //backend->is_Bible_key(mykey, settings.currentverse);
 	if (backend->is_module(work_buf[MODULE])) {
 		mod_type = backend->module_type(work_buf[MODULE]);
@@ -960,7 +960,9 @@ gint main_url_handler(const gchar * url, gboolean clicked)
 
 			// need localized key, not the osisref that we've got.
 			ModMap::iterator it = backend->get_mgr()->Modules.find
-						((module && *module) ? module : "KJV");
+						((module && *module)
+						 ? module
+						 : settings.MainWindowModule);
 			SWModule *m = (*it).second;
 			VerseKey *vk = (VerseKey *)m->getKey();
 			*vk = passage;
@@ -980,9 +982,6 @@ gint main_url_handler(const gchar * url, gboolean clicked)
 			module = g_strdup(m_url.getParameterValue("module"));
 			if (!strcmp(stype, "scripRef"))
 				show_ref(module, svalue, clicked);
-			if (!strcmp(stype, "swordURL")) {
-				// do nothing?
-			}
 			if (module) g_free(module);
 		}
 
