@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * xml.c -
  *
- * Copyright (C) 2000-2009 Xiphos Developer Team
+ * Copyright (C) 2000-2010 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include <config.h>
 #endif
 
+#include <unistd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <libxml/parser.h>
@@ -31,6 +32,7 @@
 #include "main/settings.h"
 #include "main/sword.h"
 #include "main/xml.h"
+#include "gui/dialog.h"
 
 struct _bookmark_data {
 	gchar *caption;
@@ -498,9 +500,6 @@ int xml_create_settings_file(char *path)
 
 	section_node = xmlNewChild(root_node, NULL,
 				   (const xmlChar *) "editor", NULL);
-	xmlNewTextChild(section_node, NULL, (const xmlChar *) "UsePercommDialog", (const xmlChar *) "1");
-	xmlNewTextChild(section_node, NULL, (const xmlChar *) "UseStudyPad", (const xmlChar *) "1");
-	xmlNewTextChild(section_node, NULL, (const xmlChar *) "UseStudypadDialog", (const xmlChar *) "1");
 	xmlNewTextChild(section_node, NULL, (const xmlChar *) "spell_language", (const xmlChar *) "unknown");
 
 	section_node = xmlNewChild(root_node, NULL, (const xmlChar *) "locale", NULL);
@@ -511,7 +510,6 @@ int xml_create_settings_file(char *path)
 	xmlNewTextChild(section_node, NULL, (const xmlChar *) "mod_mgr_destination", (const xmlChar *) "0");
 	xmlNewTextChild(section_node, NULL, (const xmlChar *) "mod_mgr_local_source_index", (const xmlChar *) "0");
 	xmlNewTextChild(section_node, NULL, (const xmlChar *) "mod_mgr_remote_source_index", (const xmlChar *) "0");
-	xmlNewTextChild(section_node, NULL, (const xmlChar *) "mod_mgr_intro", (const xmlChar *) "0");
 
 	section_node = xmlNewChild(root_node, NULL, (const xmlChar *) "fontsize", NULL);
 	xmlNewTextChild(section_node, NULL, (const xmlChar *) "versenum", (const xmlChar *) "+0");
@@ -519,14 +517,14 @@ int xml_create_settings_file(char *path)
 
 
 	section_node = xmlNewChild(root_node, NULL, (const xmlChar *) "HTMLcolors", NULL);
-	xmlNewTextChild(section_node, NULL, (const xmlChar *) "background", (const xmlChar *) "#FFFFFF");
-	xmlNewTextChild(section_node, NULL, (const xmlChar *) "text_fg", (const xmlChar *) "#000000");
-	xmlNewTextChild(section_node, NULL, (const xmlChar *) "versenum",(const xmlChar *)  "#0000CF");
-	xmlNewTextChild(section_node, NULL, (const xmlChar *) "currentverse", (const xmlChar *) "#339766");
-	xmlNewTextChild(section_node, NULL, (const xmlChar *) "link", (const xmlChar *) "#878787");
-	xmlNewTextChild(section_node, NULL, (const xmlChar *) "found", (const xmlChar *) "#D02898");
-	xmlNewTextChild(section_node, NULL, (const xmlChar *) "highlight_fg", (const xmlChar *)"#FFFF00");
-	xmlNewTextChild(section_node, NULL, (const xmlChar *) "highlight_bg", (const xmlChar *)"#060680");
+	xmlNewTextChild(section_node, NULL, (const xmlChar *) "background", (const xmlChar *) "#FFFFFF");	/* white */
+	xmlNewTextChild(section_node, NULL, (const xmlChar *) "text_fg", (const xmlChar *) "#000000");		/* black */
+	xmlNewTextChild(section_node, NULL, (const xmlChar *) "versenum",(const xmlChar *)  "#0000CF");		/* blue */
+	xmlNewTextChild(section_node, NULL, (const xmlChar *) "currentverse", (const xmlChar *) "#339766");	/* green */
+	xmlNewTextChild(section_node, NULL, (const xmlChar *) "link", (const xmlChar *) "#878787");		/* grey */
+	xmlNewTextChild(section_node, NULL, (const xmlChar *) "found", (const xmlChar *) "#D02898");		/* ? */
+	xmlNewTextChild(section_node, NULL, (const xmlChar *) "highlight_fg", (const xmlChar *)"#FFFF00");	/* yellow */
+	xmlNewTextChild(section_node, NULL, (const xmlChar *) "highlight_bg", (const xmlChar *)"#060680");	/* navy */
 
 
 	section_node =
@@ -550,17 +548,24 @@ int xml_create_settings_file(char *path)
 
 
 	section_node = xmlNewChild(root_node, NULL, (const xmlChar *)"layout", NULL);
-	xmlNewTextChild(section_node, NULL, (const xmlChar *)"hight", (const xmlChar *)"480");
+	xmlNewTextChild(section_node, NULL, (const xmlChar *)"height", (const xmlChar *)"480");
 	xmlNewTextChild(section_node, NULL,(const xmlChar *) "width", (const xmlChar *)"640");
 	xmlNewTextChild(section_node, NULL, (const xmlChar *)"app_x", (const xmlChar *)"40");
 	xmlNewTextChild(section_node, NULL,(const xmlChar *) "app_y", (const xmlChar *)"40");
+
+	xmlNewTextChild(section_node, NULL, (const xmlChar *)"parallelopen", (const xmlChar *)"0");
+	xmlNewTextChild(section_node, NULL, (const xmlChar *)"parallel_height", (const xmlChar *)"361");
+	xmlNewTextChild(section_node, NULL,(const xmlChar *) "parallel_width", (const xmlChar *)"657");
+	xmlNewTextChild(section_node, NULL, (const xmlChar *)"parallel_x", (const xmlChar *)"200");
+	xmlNewTextChild(section_node, NULL,(const xmlChar *) "parallel_y", (const xmlChar *)"200");
+
 	xmlNewTextChild(section_node, NULL, (const xmlChar *)"textpane", (const xmlChar *)"240");
 	xmlNewTextChild(section_node, NULL, (const xmlChar *)"shortcutbar", (const xmlChar *)"158");
 	xmlNewTextChild(section_node, NULL, (const xmlChar *)"uperpane", (const xmlChar *)"210");
 	xmlNewTextChild(section_node, NULL, (const xmlChar *)"vltoppaneheight", (const xmlChar *)"210");
-	xmlNewTextChild(section_node, NULL, (const xmlChar *)"sidebar_notebook_hight", (const xmlChar *)"250");
-	xmlNewTextChild(section_node, NULL, (const xmlChar *)"biblehight", (const xmlChar *)"250");
-	xmlNewTextChild(section_node, NULL, (const xmlChar *)"commentaryhight", (const xmlChar *)"240");
+	xmlNewTextChild(section_node, NULL, (const xmlChar *)"sidebar_notebook_height", (const xmlChar *)"250");
+	xmlNewTextChild(section_node, NULL, (const xmlChar *)"bibleheight", (const xmlChar *)"250");
+	xmlNewTextChild(section_node, NULL, (const xmlChar *)"commentaryheight", (const xmlChar *)"240");
 
 	section_node = xmlNewChild(root_node, NULL, (const xmlChar *)"lexicons", NULL);
 	xmlNewTextChild(section_node, NULL, (const xmlChar *)"indictpane", (const xmlChar *)"1");
@@ -586,7 +591,8 @@ int xml_create_settings_file(char *path)
 	xmlNewTextChild(section_node, NULL, (const xmlChar *)"showversenum", (const xmlChar *)"1");
 	xmlNewTextChild(section_node, NULL, (const xmlChar *)"readaloud", (const xmlChar *)"0");
 	xmlNewTextChild(section_node, NULL, (const xmlChar *)"versehighlight", (const xmlChar *)"0");
-	xmlNewTextChild(section_node, NULL, (const xmlChar *)"doublespace", (const xmlChar *)"0");
+	xmlNewTextChild(section_node, NULL, (const xmlChar *)"annotatehighlight", (const xmlChar *)"1");
+	xmlNewTextChild(section_node, NULL, (const xmlChar *)"xrefsinverselist", (const xmlChar *)"1");
 
 	section_node = xmlNewChild(root_node, NULL, (const xmlChar *)"modules", NULL);
 	tmp = get_list(GBS_LIST);
@@ -609,32 +615,18 @@ int xml_create_settings_file(char *path)
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"dict", (const xmlChar *)(gchar*)tmp->data);
 	else
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"dict", NULL);
+
 	tmp = get_list(TEXT_LIST);
-	if (tmp)
-		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int1", (const xmlChar *)(gchar*)tmp->data);
+	if (tmp)			/* default parallels list set to 1 bible. */
+		xmlNewTextChild(section_node, NULL, (const xmlChar *)"parallels", (const xmlChar *)(gchar*)tmp->data);
 	else
-		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int1", NULL);
-	if ((tmp = g_list_next(tmp)) != NULL)
-		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int2",(const xmlChar *)(gchar*)tmp->data);
-	else
-		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int2", NULL);
-	if ((tmp = g_list_next(tmp)) != NULL)
-		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int3", (const xmlChar *)(gchar*)tmp->data);
-	else
-		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int3", NULL);
-	if ((tmp = g_list_next(tmp)) != NULL)
-		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int4", (const xmlChar *)(gchar*)tmp->data);
-	else
-		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int4", NULL);
-	if ((tmp = g_list_next(tmp)) != NULL)
-		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int5", (const xmlChar *)(gchar*)tmp->data);
-	else
-		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int5", NULL);
-	tmp = get_list(TEXT_LIST);
+		xmlNewTextChild(section_node, NULL, (const xmlChar *)"parallels", NULL);
+
 	if (tmp)
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"bible", (const xmlChar *)(gchar*)tmp->data);
 	else
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"bible", NULL);
+
 	tmp = get_list(PERCOMM_LIST);
 	if (tmp)
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"percomm", (const xmlChar *)(gchar*)tmp->data);
@@ -798,6 +790,11 @@ static xmlNodePtr xml_find_item(xmlNodePtr parent, const char *item,
 
 	while (cur != NULL) {
 		if (!xmlStrcmp(cur->name, (const xmlChar *) item)) {
+			/* no label means any (i.e. first) element matches */
+			if (!label)
+				return cur;
+
+			/* otherwise we must find the label match. */
 			prop_label = xmlGetProp(cur, (const xmlChar *)"label");
 			if (!xmlStrcmp
 			    (prop_label, (const xmlChar *) label)) {
@@ -902,6 +899,37 @@ void xml_set_list_item(const char *section, const char *item, const char *label,
 	}
 }
 
+/******************************************************************************
+ * Name
+ *   xml_set_list_item
+ *
+ * Synopsis
+ *   #include "main/xml.h"
+ *
+ *   void xml_set_list_item(char * section, char * item, char * label,
+ *				char * value)
+ *
+ * Description
+ *
+ *
+ * Return value
+ *   void
+ */
+
+void xml_set_new_element(const char *section, const char *item, const char *content)
+{
+	xmlNodePtr cur = NULL;
+	xmlNodePtr new = NULL;
+
+	if ((cur = xml_find_section("Xiphos", section)) == NULL) {
+		xmlNodePtr root_node = xmlDocGetRootElement(xml_settings_doc);
+		cur = xmlNewChild(root_node, NULL, (const xmlChar *) section, NULL);
+	}
+
+	if (cur)
+		new = xmlNewChild(cur, NULL, (const xmlChar *) item, (const xmlChar *) content);
+}
+
 /******************************************************************************
  * Name
  *   xml_set_section_ptr
@@ -1178,7 +1206,7 @@ void xml_save_settings_doc(char *name)
 	g_free(backup_name);
 
 	/* save the new one. */
-	xmlSaveFormatFile(name, xml_settings_doc,1);
+	xmlSaveFormatFile(name, xml_settings_doc, 1);
 
 	/* did it save properly? */
 	if (((retval = stat(name, &buf)) < 0) ||
